@@ -85,7 +85,7 @@ AbstractCommand::AbstractCommand
  const SocketHandle& s,
  const SharedHandle<SocketRecvBuffer>& socketRecvBuffer,
  bool incNumConnection)
-  : Command(cuid), checkPoint_(global::wallclock),
+  : Command(cuid), checkPoint_(global::wallclock()),
     timeout_(requestGroup->getTimeout()),
     requestGroup_(requestGroup),
     req_(req), fileEntry_(fileEntry), e_(e), socket_(s),
@@ -93,7 +93,7 @@ AbstractCommand::AbstractCommand
     checkSocketIsReadable_(false), checkSocketIsWritable_(false),
     nameResolverCheck_(false),
     incNumConnection_(incNumConnection),
-    serverStatTimer_(global::wallclock)
+    serverStatTimer_(global::wallclock())
 {
   if(socket_ && socket_->isOpen()) {
     setReadCheckSocket(socket_);
@@ -184,8 +184,8 @@ bool AbstractCommand::execute() {
       if(req_ && fileEntry_->getLength() > 0 &&
          e_->getRequestGroupMan()->getMaxOverallDownloadSpeedLimit() == 0 &&
          requestGroup_->getMaxDownloadSpeedLimit() == 0 &&
-         serverStatTimer_.difference(global::wallclock) >= 10) {
-        serverStatTimer_ = global::wallclock;
+         serverStatTimer_.difference(global::wallclock()) >= 10) {
+        serverStatTimer_ = global::wallclock();
         std::vector<std::pair<size_t, std::string> > usedHosts;
         if(getOption()->getAsBool(PREF_SELECT_LEAST_USED_HOST)) {
           getDownloadEngine()->getRequestGroupMan()->getUsedHosts(usedHosts);
@@ -209,7 +209,7 @@ bool AbstractCommand::execute() {
 #endif // ENABLE_ASYNC_DNS
        (!checkSocketIsReadable_ && !checkSocketIsWritable_ &&
         !nameResolverCheck_)) {
-      checkPoint_ = global::wallclock;
+      checkPoint_ = global::wallclock();
       if(getPieceStorage()) {
         if(!req_ || req_->getMaxPipelinedRequest() == 1 ||
            // Why the following condition is necessary? That's because
@@ -263,7 +263,7 @@ bool AbstractCommand::execute() {
       throw DL_RETRY_EX(fmt(MSG_NETWORK_PROBLEM,
                             socket_->getSocketError().c_str()));
     } else {
-      if(checkPoint_.difference(global::wallclock) >= timeout_) {
+      if(checkPoint_.difference(global::wallclock()) >= timeout_) {
         // timeout triggers ServerStat error state.
         SharedHandle<ServerStat> ss =
           e_->getRequestGroupMan()->getOrCreateServerStat(req_->getHost(),
@@ -320,7 +320,7 @@ bool AbstractCommand::execute() {
     req_->addTryCount();
     req_->resetRedirectCount();
     req_->resetUri();
-    const unsigned int maxTries = getOption()->getAsInt(PREF_MAX_TRIES);
+    const int maxTries = getOption()->getAsInt(PREF_MAX_TRIES);
     bool isAbort = maxTries != 0 && req_->getTryCount() >= maxTries;
     if(isAbort) {
       A2_LOG_INFO(fmt(MSG_MAX_TRY,
@@ -339,7 +339,7 @@ bool AbstractCommand::execute() {
       tryReserved();
       return true;
     } else {
-      Timer wakeTime(global::wallclock);
+      Timer wakeTime(global::wallclock());
       wakeTime.advance(getOption()->getAsInt(PREF_RETRY_WAIT));
       req_->setWakeTime(wakeTime);
       return prepareForRetry(0);
@@ -440,8 +440,8 @@ void AbstractCommand::onAbort() {
         // Local file exists, but given servers(or at least contacted
         // ones) doesn't support resume. Let's restart download from
         // scratch.
-        A2_LOG_NOTICE(fmt("CUID#%lld - Failed to resume download."
-                          " Download from scratch.",
+        A2_LOG_NOTICE(fmt(_("CUID#%lld - Failed to resume download."
+                            " Download from scratch."),
                           getCuid()));
         A2_LOG_DEBUG(fmt("CUID#%lld - Gathering URIs that has CANNOT_RESUME"
                          " error",
@@ -543,35 +543,72 @@ void AbstractCommand::setWriteCheckSocketIf
 }
 
 namespace {
-// Returns proxy option value for the given protocol.
-const std::string& getProxyOptionFor
-(const std::string& proxyPref, const SharedHandle<Option>& option)
+// Constructs proxy URI, merging username and password if they are
+// defined.
+std::string makeProxyUri
+(const Pref* proxyPref,
+ const Pref* proxyUser,
+ const Pref* proxyPasswd,
+ const Option* option)
 {
-  if(option->defined(proxyPref)) {
-    return option->get(proxyPref);
+  uri::UriStruct us;
+  if(uri::parse(us, option->get(proxyPref))) {
+    if(option->defined(proxyUser)) {
+      us.username = option->get(proxyUser);
+    }
+    if(option->defined(proxyPasswd)) {
+      us.password = option->get(proxyPasswd);
+      us.hasPassword = true;
+    }
+    return uri::construct(us);
   } else {
-    return option->get(PREF_ALL_PROXY);
+    return "";
   }
 }
 } // namespace
 
 namespace {
+// Returns proxy option value for the given protocol.
+std::string getProxyOptionFor
+(const Pref* proxyPref,
+ const Pref* proxyUser,
+ const Pref* proxyPasswd,
+ const Option* option)
+{
+  std::string uri = makeProxyUri(proxyPref, proxyUser, proxyPasswd, option);
+  if(uri.empty()) {
+    return makeProxyUri(PREF_ALL_PROXY, PREF_ALL_PROXY_USER,
+                        PREF_ALL_PROXY_PASSWD, option);
+  } else {
+    return uri;
+  }
+}
+} // namespace
+
 // Returns proxy URI for given protocol.  If no proxy URI is defined,
 // then returns an empty string.
-const std::string& getProxyUri
-(const std::string& protocol, const SharedHandle<Option>& option)
+std::string getProxyUri
+(const std::string& protocol, const Option* option)
 {
   if(protocol == Request::PROTO_HTTP) {
-    return getProxyOptionFor(PREF_HTTP_PROXY, option);
+    return getProxyOptionFor(PREF_HTTP_PROXY,
+                             PREF_HTTP_PROXY_USER,
+                             PREF_HTTP_PROXY_PASSWD,
+                             option);
   } else if(protocol == Request::PROTO_HTTPS) {
-    return getProxyOptionFor(PREF_HTTPS_PROXY, option);
+    return getProxyOptionFor(PREF_HTTPS_PROXY,
+                             PREF_HTTPS_PROXY_USER,
+                             PREF_HTTPS_PROXY_PASSWD,
+                             option);
   } else if(protocol == Request::PROTO_FTP) {
-    return getProxyOptionFor(PREF_FTP_PROXY, option);
+    return getProxyOptionFor(PREF_FTP_PROXY,
+                             PREF_FTP_PROXY_USER,
+                             PREF_FTP_PROXY_PASSWD,
+                             option);
   } else {
     return A2STR::NIL;
   }
 }
-} // namespace
 
 namespace {
 // Returns true if proxy is defined for the given protocol. Otherwise
@@ -579,62 +616,38 @@ namespace {
 bool isProxyRequest
 (const std::string& protocol, const SharedHandle<Option>& option)
 {
-  const std::string& proxyUri = getProxyUri(protocol, option);
-  uri::UriStruct us;
-  return !proxyUri.empty() && uri::parse(us, proxyUri);
+  std::string proxyUri = getProxyUri(protocol, option.get());
+  return !proxyUri.empty();
 }
 } // namespace
 
-namespace {
-class DomainMatch {
-private:
-  std::string hostname_;
-public:
-  DomainMatch(const std::string& hostname):hostname_(hostname) {}
-
-  bool operator()(const std::string& domain) const
-  {
-    if(util::startsWith(domain, A2STR::DOT_C)) {
-      return util::endsWith(hostname_, domain);
-    } else {
-      return util::endsWith(hostname_, A2STR::DOT_C+domain);
-    }
-  }
-};
-} // namespace
-
 namespace {
 bool inNoProxy(const SharedHandle<Request>& req,
                const std::string& noProxy)
 {
-  std::vector<std::string> entries;
-  util::split(noProxy, std::back_inserter(entries), ",", true);
+  std::vector<Scip> entries;
+  util::splitIter(noProxy.begin(), noProxy.end(), std::back_inserter(entries),
+                  ',', true);
   if(entries.empty()) {
     return false;
   }
-  DomainMatch domainMatch(A2STR::DOT_C+req->getHost());
-  for(std::vector<std::string>::const_iterator i = entries.begin(),
+  for(std::vector<Scip>::const_iterator i = entries.begin(),
         eoi = entries.end(); i != eoi; ++i) {
-    std::string::size_type slashpos = (*i).find('/');
-    if(slashpos == std::string::npos) {
-      if(util::isNumericHost(*i)) {
-        if(req->getHost() == *i) {
-          return true;
-        }
-      } else if(domainMatch(*i)) {
+    std::string::const_iterator slashpos =
+      std::find((*i).first, (*i).second, '/');
+    if(slashpos == (*i).second) {
+      if(util::noProxyDomainMatch
+         (req->getHost(), std::string((*i).first, (*i).second))) {
         return true;
       }
     } else {
-      if(!util::isNumericHost(req->getHost())) {
-        // TODO We don't resolve hostname here.  More complete
-        // implementation is that we should first resolve
-        // hostname(which may result in several IP addresses) and
-        // evaluates against all of them
-        continue;
-      }
-      std::string ip = (*i).substr(0, slashpos);
+      // TODO We don't resolve hostname here.  More complete
+      // implementation is that we should first resolve
+      // hostname(which may result in several IP addresses) and
+      // evaluates against all of them
+      std::string ip((*i).first, slashpos);
       uint32_t bits;
-      if(!util::parseUIntNoThrow(bits, (*i).substr(slashpos+1))) {
+      if(!util::parseUIntNoThrow(bits, std::string(slashpos+1, (*i).second))) {
         continue;
       }
       if(util::inSameCidrBlock(ip, req->getHost(), bits)) {
@@ -658,7 +671,7 @@ SharedHandle<Request> AbstractCommand::createProxyRequest() const
   if(inNoProxy(req_, getOption()->get(PREF_NO_PROXY))) {
     return proxyRequest;
   }
-  std::string proxy = getProxyUri(req_->getProtocol(), getOption());
+  std::string proxy = getProxyUri(req_->getProtocol(), getOption().get());
   if(!proxy.empty()) {
     proxyRequest.reset(new Request());
     if(proxyRequest->setUri(proxy)) {
@@ -869,7 +882,7 @@ void AbstractCommand::createSocket()
   socket_.reset(new SocketCore());
 }
 
-size_t AbstractCommand::calculateMinSplitSize() const
+int32_t AbstractCommand::calculateMinSplitSize() const
 {
   if(req_ && req_->isPipeliningEnabled()) {
     return getDownloadContext()->getPieceLength();
