@@ -87,7 +87,7 @@ private:
   bool incNumConnection_;
   Timer serverStatTimer_;
 
-  size_t calculateMinSplitSize() const;
+  int32_t calculateMinSplitSize() const;
   void useFasterRequest(const SharedHandle<Request>& fasterRequest);
 #ifdef ENABLE_ASYNC_DNS
   void setNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver);
@@ -243,6 +243,11 @@ public:
   bool execute();
 };
 
+// Returns proxy URI for given protocol.  If no proxy URI is defined,
+// then returns an empty string.
+std::string getProxyUri
+(const std::string& protocol, const Option* option);
+
 } // namespace aria2
 
 #endif // D_ABSTRACT_COMMAND_H
