@@ -40,10 +40,6 @@
 #include <cstring>
 #include <cassert>
 
-#ifdef __MINGW32__
-# include <windows.h>
-#endif // __MINGW32__
-
 #include "File.h"
 #include "util.h"
 #include "message.h"
@@ -58,8 +54,7 @@ namespace aria2 {
 AbstractDiskWriter::AbstractDiskWriter(const std::string& filename)
   : filename_(filename),
     fd_(-1),
-    readOnly_(false),
-    directIOAllowed_(false)
+    readOnly_(false)
 {}
 
 AbstractDiskWriter::~AbstractDiskWriter()
@@ -67,7 +62,7 @@ AbstractDiskWriter::~AbstractDiskWriter()
   closeFile();
 }
 
-void AbstractDiskWriter::openFile(uint64_t totalLength)
+void AbstractDiskWriter::openFile(off_t totalLength)
 {
   try {
     openExistingFile(totalLength);
@@ -82,13 +77,13 @@ void AbstractDiskWriter::openFile(uint64_t totalLength)
 
 void AbstractDiskWriter::closeFile()
 {
-  if(fd_ >= 0) {
+  if(fd_ != -1) {
     close(fd_);
     fd_ = -1;
   }
 }
 
-void AbstractDiskWriter::openExistingFile(uint64_t totalLength)
+void AbstractDiskWriter::openExistingFile(off_t totalLength)
 {
   int flags = O_BINARY;
   if(readOnly_) {
@@ -96,8 +91,8 @@ void AbstractDiskWriter::openExistingFile(uint64_t totalLength)
   } else {
     flags |= O_RDWR;
   }
-
-  while((fd_ = open(filename_.c_str(), flags, OPEN_MODE)) == -1 &&
+  while((fd_ = a2open(utf8ToWChar(filename_).c_str(),
+                      flags, OPEN_MODE)) == -1 &&
         errno == EINTR);
   if(fd_ < 0) {
     int errNum = errno;
@@ -115,8 +110,9 @@ void AbstractDiskWriter::createFile(int addFlags)
   assert(!filename_.empty());
   util::mkdirs(File(filename_).getDirname());
 
-  while((fd_ = open(filename_.c_str(), O_CREAT|O_RDWR|O_TRUNC|O_BINARY|addFlags,
-                    OPEN_MODE)) == -1 && errno == EINTR);
+  while((fd_ = a2open(utf8ToWChar(filename_).c_str(),
+                      O_CREAT|O_RDWR|O_TRUNC|O_BINARY|addFlags,
+                      OPEN_MODE)) == -1 && errno == EINTR);
   if(fd_ < 0) {
     int errNum = errno;
     throw DL_ABORT_EX3
@@ -201,7 +197,7 @@ ssize_t AbstractDiskWriter::readData(unsigned char* data, size_t len, off_t offs
   return ret;
 }
 
-void AbstractDiskWriter::truncate(uint64_t length)
+void AbstractDiskWriter::truncate(off_t length)
 {
   if(fd_ == -1) {
     throw DL_ABORT_EX("File not opened.");
@@ -227,7 +223,7 @@ void AbstractDiskWriter::truncate(uint64_t length)
 #endif
 }
 
-void AbstractDiskWriter::allocate(off_t offset, uint64_t length)
+void AbstractDiskWriter::allocate(off_t offset, off_t length)
 {
 #ifdef  HAVE_SOME_FALLOCATE
   if(fd_ == -1) {
@@ -276,31 +272,11 @@ void AbstractDiskWriter::allocate(off_t offset, uint64_t length)
 #endif // HAVE_SOME_FALLOCATE
 }
 
-uint64_t AbstractDiskWriter::size()
+off_t AbstractDiskWriter::size()
 {
   return File(filename_).size();
 }
 
-void AbstractDiskWriter::enableDirectIO()
-{
-#ifdef ENABLE_DIRECT_IO
-  if(directIOAllowed_) {
-    int flg;
-    while((flg = fcntl(fd_, F_GETFL)) == -1 && errno == EINTR);
-    while(fcntl(fd_, F_SETFL, flg|O_DIRECT) == -1 && errno == EINTR);
-  }
-#endif // ENABLE_DIRECT_IO
-}
-
-void AbstractDiskWriter::disableDirectIO()
-{
-#ifdef ENABLE_DIRECT_IO
-  int flg;
-  while((flg = fcntl(fd_, F_GETFL)) == -1 && errno == EINTR);
-  while(fcntl(fd_, F_SETFL, flg&(~O_DIRECT)) == -1 && errno == EINTR);
-#endif // ENABLE_DIRECT_IO
-}
-
 void AbstractDiskWriter::enableReadOnly()
 {
   readOnly_ = true;
