@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ABSTRACT_PROXY_REQUEST_COMMAND_H_
-#define _D_ABSTRACT_PROXY_REQUEST_COMMAND_H_
+#ifndef D_ABSTRACT_PROXY_REQUEST_COMMAND_H
+#define D_ABSTRACT_PROXY_REQUEST_COMMAND_H
 
 #include "AbstractCommand.h"
 
@@ -43,16 +43,17 @@ class HttpConnection;
 class SocketCore;
 
 class AbstractProxyRequestCommand : public AbstractCommand {
+private:
+  SharedHandle<Request> proxyRequest_;
+
+  SharedHandle<HttpConnection> httpConnection_;
 protected:
-  SharedHandle<Request> _proxyRequest;
-
-  SharedHandle<HttpConnection> httpConnection;
-
-  std::string _connectedHostname;
-  std::string _connectedAddr;
-  uint16_t _connectedPort;
-
   virtual bool executeInternal();
+
+  const SharedHandle<HttpConnection>& getHttpConnection() const
+  {
+    return httpConnection_;
+  }
 public:
   AbstractProxyRequestCommand(cuid_t cuid,
                               const SharedHandle<Request>& req,
@@ -65,16 +66,8 @@ public:
   virtual ~AbstractProxyRequestCommand();
 
   virtual Command* getNextCommand() = 0;
-
-  void setConnectedAddr
-  (const std::string& hostname, const std::string& addr, uint16_t port)
-  {
-    _connectedHostname = hostname;
-    _connectedAddr = addr;
-    _connectedPort = port;
-  }
 };
 
 } // namespace aria2
 
-#endif // _D_ABSTRACT_PROXY_REQUEST_COMMAND_H_
+#endif // D_ABSTRACT_PROXY_REQUEST_COMMAND_H
