@@ -38,7 +38,6 @@
 
 #include "A2STR.h"
 #include "SimpleRandomizer.h"
-#include "util.h"
 #include "a2algo.h"
 
 namespace aria2 {
@@ -49,6 +48,8 @@ const std::string AnnounceList::STOPPED("stopped");
 
 const std::string AnnounceList::COMPLETED("completed");
 
+AnnounceList::AnnounceList():currentTrackerInitialized_(false) {}
+
 AnnounceList::AnnounceList
 (const std::vector<std::vector<std::string> >& announceList):
   currentTrackerInitialized_(false) {
@@ -61,6 +62,8 @@ AnnounceList::AnnounceList
   resetIterator();
 }
 
+AnnounceList::~AnnounceList() {}
+
 void AnnounceList::reconfigure
 (const std::vector<std::vector<std::string> >& announceList)
 {
@@ -79,7 +82,8 @@ void AnnounceList::reconfigure
 void AnnounceList::reconfigure(const std::string& url) {
   std::deque<std::string> urls;
   urls.push_back(url);
-  tiers_.push_back(SharedHandle<AnnounceTier>(new AnnounceTier(urls)));
+  SharedHandle<AnnounceTier> tier(new AnnounceTier(urls));
+  tiers_.push_back(tier);
   resetIterator();
 }
 
@@ -261,4 +265,9 @@ bool AnnounceList::currentTierAcceptsCompletedEvent() const
   }
 }
 
+size_t AnnounceList::countTier() const
+{
+  return tiers_.size();
+}
+
 } // namespace aria2
