@@ -48,12 +48,8 @@
 namespace aria2 {
 
 class AsyncNameResolver {
-#ifdef HAVE_LIBCARES1_5
-  friend void callback(void* arg, int status, int timeouts, struct hostent* host);
-#else
-  friend void callback(void* arg, int status, struct hostent* host);
-#endif // HAVE_LIBCARES1_5
-
+  friend void callback
+  (void* arg, int status, int timeouts, struct hostent* host);
 public:
   enum STATUS {
     STATUS_READY,
@@ -70,7 +66,12 @@ private:
   std::string error_;
   std::string hostname_;
 public:
-  AsyncNameResolver(int family);
+  AsyncNameResolver
+  (int family
+#ifdef HAVE_ARES_ADDR_NODE
+   , ares_addr_node* servers
+#endif // HAVE_ARES_ADDR_NODE
+   );
 
   ~AsyncNameResolver();
 
@@ -116,6 +117,13 @@ public:
 
 };
 
+#ifdef HAVE_ARES_ADDR_NODE
+
+ares_addr_node* parseAsyncDNSServers(const std::string& serversOpt);
+
+#endif // HAVE_ARES_ADDR_NODE
+
+
 } // namespace aria2
 
 #endif // D_ASYNC_NAME_RESOLVER_H
