@@ -64,17 +64,21 @@ AuthConfigFactory::createAuthConfig
 
     if(op->getAsBool(PREF_HTTP_AUTH_CHALLENGE)) {
       if(!request->getUsername().empty()) {
-        updateBasicCred(BasicCred(request->getUsername(),
-                                  request->getPassword(),
-                                  request->getHost(), request->getDir(), true));
+        SharedHandle<BasicCred> bc(new BasicCred(request->getUsername(),
+                                                 request->getPassword(),
+                                                 request->getHost(),
+                                                 request->getPort(),
+                                                 request->getDir(), true));
+        updateBasicCred(bc);
         return createAuthConfig(request->getUsername(), request->getPassword());
       }
-      std::deque<BasicCred>::const_iterator i =
-        findBasicCred(request->getHost(), request->getDir());
+      BasicCredSet::iterator i =
+        findBasicCred(request->getHost(), request->getPort(),
+                      request->getDir());
       if(i == basicCreds_.end()) {
         return SharedHandle<AuthConfig>();
       } else {
-        return createAuthConfig((*i).user_, (*i).password_);
+        return createAuthConfig((*i)->user_, (*i)->password_);
       }
     } else {
       if(!request->getUsername().empty()) {
@@ -167,49 +171,50 @@ void AuthConfigFactory::setNetrc(const SharedHandle<Netrc>& netrc)
   netrc_ = netrc;
 }
 
-void AuthConfigFactory::updateBasicCred(const BasicCred& basicCred)
+void AuthConfigFactory::updateBasicCred
+(const SharedHandle<BasicCred>& basicCred)
 {
-  std::deque<BasicCred>::iterator i =
-    std::lower_bound(basicCreds_.begin(), basicCreds_.end(), basicCred);
-
-  if(i != basicCreds_.end() && (*i) == basicCred) {
-    (*i) = basicCred;
+  BasicCredSet::iterator i = basicCreds_.lower_bound(basicCred);
+  if(i != basicCreds_.end() && *(*i) == *basicCred) {
+    *(*i) = *basicCred;
   } else {
     basicCreds_.insert(i, basicCred);
   }
 }
 
 bool AuthConfigFactory::activateBasicCred
-(const std::string& host, const std::string& path, const Option* op)
+(const std::string& host,
+ uint16_t port,
+ const std::string& path,
+ const Option* op)
 {
-
-  std::deque<BasicCred>::iterator i = findBasicCred(host, path);
+  BasicCredSet::iterator i = findBasicCred(host, port, path);
   if(i == basicCreds_.end()) {
     SharedHandle<AuthConfig> authConfig =
       createHttpAuthResolver(op)->resolveAuthConfig(host);
     if(!authConfig) {
       return false;
     } else {
-      BasicCred bc(authConfig->getUser(), authConfig->getPassword(),
-                   host, path, true);
-      i = std::lower_bound(basicCreds_.begin(), basicCreds_.end(), bc);
-      basicCreds_.insert(i, bc);
+      SharedHandle<BasicCred> bc
+        (new BasicCred(authConfig->getUser(), authConfig->getPassword(),
+                       host, port, path, true));
+      basicCreds_.insert(bc);
       return true;
     }
   } else {
-    (*i).activate();
+    (*i)->activate();
     return true;
   }
 }
 
 AuthConfigFactory::BasicCred::BasicCred
 (const std::string& user, const std::string& password,
- const std::string& host, const std::string& path,
+ const std::string& host, uint16_t port, const std::string& path,
  bool activated):
   user_(user), password_(password),
-  host_(host), path_(path), activated_(activated)
+  host_(host), port_(port), path_(path), activated_(activated)
 {
-  if(!util::endsWith(path_, "/")) {
+  if(path_.empty() || path_[path_.size()-1] != '/') {
     path_ += "/";
   }
 }
@@ -226,28 +231,27 @@ bool AuthConfigFactory::BasicCred::isActivated() const
 
 bool AuthConfigFactory::BasicCred::operator==(const BasicCred& cred) const
 {
-  return host_ == cred.host_ && path_ == cred.path_;
+  return host_ == cred.host_ && port_ == cred.port_ && path_ == cred.path_;
 }
 
 bool AuthConfigFactory::BasicCred::operator<(const BasicCred& cred) const
 {
-  int c = host_.compare(cred.host_);
-  if(c == 0) {
-    return path_ > cred.path_;
-  } else {
-    return c < 0;
-  }
+  return host_ < cred.host_ ||
+    (!(cred.host_ < host_) && (port_ < cred.port_ ||
+                               (!(cred.port_ < port_) && path_ > cred.path_)));
 }
 
-std::deque<AuthConfigFactory::BasicCred>::iterator
-AuthConfigFactory::findBasicCred(const std::string& host,
-                                 const std::string& path)
+AuthConfigFactory::BasicCredSet::iterator
+AuthConfigFactory::findBasicCred
+(const std::string& host,
+ uint16_t port,
+ const std::string& path)
 {
-  BasicCred bc("", "", host, path);
-  std::deque<BasicCred>::iterator i =
-    std::lower_bound(basicCreds_.begin(), basicCreds_.end(), bc);
-  for(; i != basicCreds_.end() && (*i).host_ == host; ++i) {
-    if(util::startsWith(bc.path_, (*i).path_)) {
+  SharedHandle<BasicCred> bc(new BasicCred("", "", host, port, path));
+  BasicCredSet::iterator i = basicCreds_.lower_bound(bc);
+  for(; i != basicCreds_.end() && (*i)->host_ == host && (*i)->port_ == port;
+      ++i) {
+    if(util::startsWith(bc->path_, (*i)->path_)) {
       return i;
     }
   }
