@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_CANCEL_MESSAGE_H_
-#define _D_BT_CANCEL_MESSAGE_H_
+#ifndef D_BT_CANCEL_MESSAGE_H
+#define D_BT_CANCEL_MESSAGE_H
 
 #include "RangeBtMessage.h"
 
@@ -45,18 +45,18 @@ typedef SharedHandle<BtCancelMessage> BtCancelMessageHandle;
 
 class BtCancelMessage : public RangeBtMessage {
 public:
-  BtCancelMessage(size_t index = 0, uint32_t begin = 0, size_t length = 0)
-    :RangeBtMessage(ID, NAME, index, begin, length) {}
+  BtCancelMessage(size_t index = 0, int32_t begin = 0, int32_t length = 0);
 
   static const int8_t ID = 8;
 
   static const std::string NAME;
 
-  static BtCancelMessageHandle create(const unsigned char* data, size_t dataLength);
+  static BtCancelMessageHandle create
+  (const unsigned char* data, size_t dataLength);
 
   virtual void doReceivedAction();
 };
 
 } // namespace aria2
 
-#endif // _D_BT_CANCEL_MESSAGE_H_
+#endif // D_BT_CANCEL_MESSAGE_H
