@@ -47,15 +47,17 @@
 #include "File.h"
 #include "bittorrent_helper.h"
 #include "DlAbortEx.h"
-#include "StringFormat.h"
+#include "fmt.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
-BtDependency::BtDependency(const WeakHandle<RequestGroup>& dependant,
-                           const SharedHandle<RequestGroup>& dependee):
-  dependant_(dependant),
-  dependee_(dependee),
-  logger_(LogFactory::getInstance()) {}
+BtDependency::BtDependency
+(RequestGroup* dependant,
+ const SharedHandle<RequestGroup>& dependee)
+  : dependant_(dependant),
+    dependee_(dependee)
+{}
 
 BtDependency::~BtDependency() {}
 
@@ -72,14 +74,27 @@ void copyValues(const SharedHandle<FileEntry>& d,
 }
 } // namespace
 
+namespace {
+struct EntryCmp {
+  bool operator()
+  (const SharedHandle<FileEntry>& lhs,
+   const SharedHandle<FileEntry>& rhs) const
+  {
+    return lhs->getOriginalName() < rhs->getOriginalName();
+  }
+};
+} // namespace
+
 bool BtDependency::resolve()
 {
+  if(!dependee_) {
+    return true;
+  }
   if(dependee_->getNumCommand() == 0 && dependee_->downloadFinished()) {
     SharedHandle<RequestGroup> dependee = dependee_;
     // cut reference here
     dependee_.reset();
     SharedHandle<DownloadContext> context(new DownloadContext());
-    context->setDir(dependant_->getDownloadContext()->getDir());
     try {
       SharedHandle<DiskAdaptor> diskAdaptor =
         dependee->getPieceStorage()->getDiskAdaptor();
@@ -89,12 +104,14 @@ bool BtDependency::resolve()
         SharedHandle<TorrentAttribute> attrs =
           bittorrent::getTorrentAttrs(dependee->getDownloadContext());
         bittorrent::loadFromMemory
-          (bittorrent::metadata2Torrent(content, attrs), context, "default");
+          (bittorrent::metadata2Torrent(content, attrs), context,
+           dependant_->getOption(), "default");
         // We don't call bittorrent::adjustAnnounceUri() because it
         // has already been called with attrs.
       } else {
         bittorrent::loadFromMemory
-          (content, context, File(dependee->getFirstFilePath()).getBasename());
+          (content, context, dependant_->getOption(),
+           File(dependee->getFirstFilePath()).getBasename());
         bittorrent::adjustAnnounceUri(bittorrent::getTorrentAttrs(context),
                                       dependant_->getOption());
       }
@@ -109,53 +126,49 @@ bool BtDependency::resolve()
          dependantFileEntries[0]->getOriginalName().empty()) {
         copyValues(fileEntries[0], dependantFileEntries[0]);
       } else {
-        std::for_each(fileEntries.begin(), fileEntries.end(),
-                      std::bind2nd(mem_fun_sh(&FileEntry::setRequested),false));
+        std::vector<SharedHandle<FileEntry> > destFiles;
+        destFiles.reserve(fileEntries.size());
+        for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
+              fileEntries.begin(), eoi = fileEntries.end(); i != eoi; ++i) {
+          (*i)->setRequested(false);
+          destFiles.push_back(*i);
+        }
+        std::sort(destFiles.begin(), destFiles.end(), EntryCmp());
         // Copy file path in dependant_'s FileEntries to newly created
         // context's FileEntries to endorse the path structure of
         // dependant_.  URIs and singleHostMultiConnection are also copied.
-        std::vector<SharedHandle<FileEntry> >::const_iterator ctxFilesEnd =
-          fileEntries.end();
         for(std::vector<SharedHandle<FileEntry> >::const_iterator s =
               dependantFileEntries.begin(), eoi = dependantFileEntries.end();
             s != eoi; ++s){
           std::vector<SharedHandle<FileEntry> >::const_iterator d =
-            fileEntries.begin();
-          for(; d != ctxFilesEnd; ++d) {
-            if((*d)->getOriginalName() == (*s)->getOriginalName()) {
-              break;
-            }
-          }
-          if(d == ctxFilesEnd) {
+            std::lower_bound(destFiles.begin(), destFiles.end(), *s,
+                             EntryCmp());
+          if(d == destFiles.end() ||
+             (*d)->getOriginalName() != (*s)->getOriginalName()) {
             throw DL_ABORT_EX
-              (StringFormat("No entry %s in torrent file",
-                            (*s)->getOriginalName().c_str()).str());
+              (fmt("No entry %s in torrent file",
+                   (*s)->getOriginalName().c_str()));
+          } else {
+            copyValues(*d, *s);
           }
-          copyValues(*d, *s);
         }
       }
     } catch(RecoverableException& e) {
-      logger_->error(EX_EXCEPTION_CAUGHT, e);
-      if(logger_->info()) {
-        logger_->info("BtDependency for GID#%s failed. Go without Bt.",
-                      util::itos(dependant_->getGID()).c_str());
-      }
+      A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, e);
+      A2_LOG_INFO(fmt("BtDependency for GID#%lld failed. Go without Bt.",
+                      dependant_->getGID()));
       return true;
     }
-    if(logger_->info()) {
-      logger_->info("Dependency resolved for GID#%s",
-                    util::itos(dependant_->getGID()).c_str());
-    }
+    A2_LOG_INFO(fmt("Dependency resolved for GID#%lld",
+                    dependant_->getGID()));
     dependant_->setDownloadContext(context);
     return true;
   } else if(dependee_->getNumCommand() == 0) {
     // dependee_'s download failed.
     // cut reference here
     dependee_.reset();
-    if(logger_->info()) {
-      logger_->info("BtDependency for GID#%s failed. Go without Bt.",
-                    util::itos(dependant_->getGID()).c_str());
-    }
+    A2_LOG_INFO(fmt("BtDependency for GID#%lld failed. Go without Bt.",
+                    dependant_->getGID()));
     return true;
   } else {
     return false;
