@@ -57,7 +57,7 @@ BtLeecherStateChoke::PeerEntry::PeerEntry(const SharedHandle<Peer>& peer):
   // peer must be interested to us and sent block in the last 30 seconds
   regularUnchoker_
   (peer->peerInterested() &&
-   peer->getLastDownloadUpdate().difference(global::wallclock) < 30) {}
+   peer->getLastDownloadUpdate().difference(global::wallclock()) < 30) {}
 
 BtLeecherStateChoke::PeerEntry::PeerEntry(const PeerEntry& c)
   : peer_(c.peer_),
@@ -91,7 +91,7 @@ const SharedHandle<Peer>& BtLeecherStateChoke::PeerEntry::getPeer() const
   return peer_;
 }
 
-unsigned int BtLeecherStateChoke::PeerEntry::getDownloadSpeed() const
+int BtLeecherStateChoke::PeerEntry::getDownloadSpeed() const
 {
   return downloadSpeed_;
 }
@@ -178,7 +178,7 @@ void BtLeecherStateChoke::regularUnchoke(std::vector<PeerEntry>& peerEntries)
   std::vector<PeerEntry>::iterator peerIter = peerEntries.begin();
   for(;peerIter != rest && count; ++peerIter, --count) {
     (*peerIter).disableChokingRequired();
-    A2_LOG_INFO(fmt("RU: %s, dlspd=%u",
+    A2_LOG_INFO(fmt("RU: %s, dlspd=%d",
                     (*peerIter).getPeer()->getIPAddress().c_str(),
                     (*peerIter).getDownloadSpeed()));
     if((*peerIter).getPeer()->optUnchoking()) {
@@ -208,7 +208,7 @@ BtLeecherStateChoke::executeChoke
 (const std::vector<SharedHandle<Peer> >& peerSet)
 {
   A2_LOG_INFO(fmt("Leecher state, %d choke round started", round_));
-  lastRound_ = global::wallclock;
+  lastRound_ = global::wallclock();
 
   std::vector<PeerEntry> peerEntries;
   std::transform(peerSet.begin(), peerSet.end(),
@@ -239,13 +239,3 @@ const Timer& BtLeecherStateChoke::getLastRound() const
 }
 
 } // namespace aria2
-
-namespace std {
-template<>
-void swap<aria2::BtLeecherStateChoke::PeerEntry>
-(aria2::BtLeecherStateChoke::PeerEntry& a,
- aria2::BtLeecherStateChoke::PeerEntry& b)
-{
-  a.swap(b);
-}
-} // namespace std;
