@@ -36,29 +36,24 @@
 #define D_BT_PIECE_MESSAGE_VALIDATOR_H
 
 #include "BtMessageValidator.h"
-#include "BtPieceMessage.h"
-#include "bittorrent_helper.h"
 
 namespace aria2 {
 
+class BtPieceMessage;
+
 class BtPieceMessageValidator : public BtMessageValidator {
 private:
   const BtPieceMessage* message_;
   size_t numPiece_;
-  size_t pieceLength_;
+  int32_t pieceLength_;
 public:
   BtPieceMessageValidator(const BtPieceMessage* message,
                           size_t numPiece,
-                          size_t pieceLength):
-    message_(message),
-    numPiece_(numPiece),
-    pieceLength_(pieceLength) {}
+                          int32_t pieceLength);
 
-  virtual void validate()
-  {
-    bittorrent::checkIndex(message_->getIndex(), numPiece_);
-    bittorrent::checkBegin(message_->getBegin(), pieceLength_);
-  }
+  ~BtPieceMessageValidator();
+
+  virtual void validate();
 };
 
 typedef SharedHandle<BtPieceMessageValidator> BtPieceMessageValidatorHandle;
