@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -43,6 +43,11 @@ namespace aria2 {
 
 const std::string BtRequestMessage::NAME("request");
 
+BtRequestMessage::BtRequestMessage
+(size_t index, int32_t begin, int32_t length, size_t blockIndex):
+  RangeBtMessage(ID, NAME, index, begin, length),
+  blockIndex_(blockIndex) {}
+
 SharedHandle<BtRequestMessage> BtRequestMessage::create
 (const unsigned char* data, size_t dataLength)
 {
@@ -51,36 +56,40 @@ SharedHandle<BtRequestMessage> BtRequestMessage::create
 
 void BtRequestMessage::doReceivedAction()
 {
-  if(pieceStorage->hasPiece(getIndex()) &&
-     (!peer->amChoking() ||
-      (peer->amChoking() && peer->isInAmAllowedIndexSet(getIndex())))) {
-    BtMessageHandle msg = messageFactory->createPieceMessage(getIndex(),
-							     getBegin(),
-							     getLength());
-    dispatcher->addMessageToQueue(msg);
+  if(isMetadataGetMode()) {
+    return;
+  }
+  if(getPieceStorage()->hasPiece(getIndex()) &&
+     (!getPeer()->amChoking() ||
+      (getPeer()->amChoking() &&
+       getPeer()->isInAmAllowedIndexSet(getIndex())))) {
+    BtMessageHandle msg =
+      getBtMessageFactory()->createPieceMessage
+      (getIndex(), getBegin(), getLength());
+    getBtMessageDispatcher()->addMessageToQueue(msg);
   } else {
-    if(peer->isFastExtensionEnabled()) {
-      BtMessageHandle msg = messageFactory->createRejectMessage(getIndex(),
-								getBegin(),
-								getLength());
-      dispatcher->addMessageToQueue(msg);
+    if(getPeer()->isFastExtensionEnabled()) {
+      BtMessageHandle msg =
+        getBtMessageFactory()->createRejectMessage
+        (getIndex(), getBegin(), getLength());
+      getBtMessageDispatcher()->addMessageToQueue(msg);
     }
   }
 }
 
 void BtRequestMessage::onQueued()
 {
-  RequestSlot requestSlot(getIndex(), getBegin(), getLength(), _blockIndex,
-			  pieceStorage->getPiece(getIndex()));
-  dispatcher->addOutstandingRequest(requestSlot);
+  RequestSlot requestSlot(getIndex(), getBegin(), getLength(), blockIndex_,
+                          getPieceStorage()->getPiece(getIndex()));
+  getBtMessageDispatcher()->addOutstandingRequest(requestSlot);
 }
 
 void BtRequestMessage::onAbortOutstandingRequestEvent
 (const BtAbortOutstandingRequestEvent& event)
 {
   if(getIndex() == event.getPiece()->getIndex() &&
-     !invalidate && !sendingInProgress) {
-    invalidate = true;
+     !isInvalidate() && !isSendingInProgress()) {
+    setInvalidate(true);
   }
 }
 
