@@ -58,7 +58,7 @@ private:
     size_t outstandingUpload_;
     Timer lastAmUnchoking_;
     bool recentUnchoking_;
-    unsigned int uploadSpeed_;
+    int uploadSpeed_;
     
     const static time_t TIME_FRAME = 20;
   public:
@@ -74,7 +74,7 @@ private:
 
     const SharedHandle<Peer>& getPeer() const { return peer_; }
 
-    unsigned int getUploadSpeed() const { return uploadSpeed_; }
+    int getUploadSpeed() const { return uploadSpeed_; }
 
     void disableOptUnchoking();
   };
@@ -103,7 +103,6 @@ public:
   const Timer& getLastRound() const { return lastRound_; }
 
   friend void swap(PeerEntry& a, PeerEntry& b);
-  friend void std::swap<PeerEntry>(PeerEntry& a, PeerEntry& b);
 };
 
 void swap
@@ -112,11 +111,4 @@ void swap
 
 } // namespace aria2
 
-namespace std {
-template<>
-void swap<aria2::BtSeederStateChoke::PeerEntry>
-(aria2::BtSeederStateChoke::PeerEntry& a,
- aria2::BtSeederStateChoke::PeerEntry& b);
-} // namespace std
-
 #endif // D_BT_SEEDER_STATE_CHOKE_H
