@@ -32,23 +32,20 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_SETUP_H_
-#define _D_BT_SETUP_H_
+#ifndef D_BT_SETUP_H
+#define D_BT_SETUP_H
 
 #include "common.h"
 #include <vector>
 
 namespace aria2 {
 
-class Logger;
 class RequestGroup;
 class DownloadEngine;
 class Option;
 class Command;
 
 class BtSetup {
-private:
-  Logger* _logger;
 public:
   BtSetup();
 
@@ -60,4 +57,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_BT_SETUP_H_
+#endif // D_BT_SETUP_H
