@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_CUID_COUNTER_H_
-#define _D_CUID_COUNTER_H_
+#ifndef D_CUID_COUNTER_H
+#define D_CUID_COUNTER_H
 
 #include "common.h"
 #include "Command.h"
@@ -42,21 +42,13 @@ namespace aria2 {
 
 class CUIDCounter {
 private:
-  cuid_t _count;
+  cuid_t count_;
 public:
-  CUIDCounter():_count(0) {}
-
-  ~CUIDCounter() {}
-
-  cuid_t newID()
-  {
-    if(_count == INT64_MAX) {
-      _count = 0;
-    }
-    return ++_count;
-  }
+  CUIDCounter();
+  ~CUIDCounter();
+  cuid_t newID();
 };
 
-}
+} // namespace aria2
 
-#endif // _D_CUID_COUNTER_H_
+#endif // D_CUID_COUNTER_H
