@@ -56,7 +56,7 @@ void CheckIntegrityEntry::validateChunk()
   validator_->validateChunk();
 }
 
-uint64_t CheckIntegrityEntry::getTotalLength()
+off_t CheckIntegrityEntry::getTotalLength()
 {
   if(!validator_) {
     return 0;
@@ -94,10 +94,6 @@ void CheckIntegrityEntry::proceedFileAllocation
   } else {
     entry->prepareForNextAction(commands, e);
   }
-  // Disable directIO when fallocation() is going to be used.
-  if(getRequestGroup()->getOption()->get(PREF_FILE_ALLOCATION) == V_FALLOC) {
-    entry->disableDirectIO();
-  }
 }
 
 void CheckIntegrityEntry::setValidator
