@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_CHUNK_CHECKSUM_H_
-#define _D_CHUNK_CHECKSUM_H_
+#ifndef D_CHUNK_CHECKSUM_H
+#define D_CHUNK_CHECKSUM_H
 
 #include "common.h"
 
@@ -41,85 +41,54 @@
 #include <vector>
 
 #include "SharedHandle.h"
-#include "A2STR.h"
 
 namespace aria2 {
 
 class ChunkChecksum {
 private:
-  std::string _algo;
-  std::vector<std::string> _checksums;
-  size_t _checksumLength;
+  std::string hashType_;
+  std::vector<std::string> pieceHashes_;
+  int32_t pieceLength_;
 public:
-  ChunkChecksum():_checksumLength(0) {}    
+  ChunkChecksum();
 
-  ChunkChecksum(const std::string& algo,
-                const std::vector<std::string>& checksums,
-                size_t checksumLength):
-    _algo(algo),
-    _checksums(checksums),
-    _checksumLength(checksumLength) {}
+  ChunkChecksum
+  (const std::string& hashType,
+   const std::vector<std::string>& pieceHashes,
+   int32_t pieceLength);
 
-  bool validateChunk(const std::string& actualChecksum,
-                     size_t checksumIndex) const
-  {
-    if(checksumIndex < _checksums.size()) {
-      return actualChecksum == getChecksum(checksumIndex);
-    } else {
-      return false;
-    }
-  }
+  bool validateChunk(const std::string& actualDigest,
+                     size_t index) const;
 
-  uint64_t getEstimatedDataLength() const
-  {
-    return ((uint64_t)_checksumLength)*_checksums.size();
-  }
+  off_t getEstimatedDataLength() const;
 
-  size_t countChecksum() const
-  {
-    return _checksums.size();
-  }
+  size_t countPieceHash() const;
 
-  const std::string& getChecksum(size_t index) const
-  {
-    if(index < _checksums.size()) {
-      return _checksums[index];
-    } else {
-      return A2STR::NIL;
-    }
-  }
+  const std::string& getPieceHash(size_t index) const;
   
-  const std::vector<std::string>& getChecksums() const
+  void setPieceHashes(const std::vector<std::string>& pieceHashes);
+  const std::vector<std::string>& getPieceHashes() const
   {
-    return _checksums;
+    return pieceHashes_;
   }
 
-  size_t getChecksumLength() const
+  void setHashType(const std::string& hashType);
+  const std::string& getHashType() const
   {
-    return _checksumLength;
+    return hashType_;
   }
 
-  const std::string& getAlgo() const
+  int32_t getPieceLength() const
   {
-    return _algo;
+    return pieceLength_;
   }
 
-  void setAlgo(const std::string& algo)
+  void setPieceLength(int32_t length)
   {
-    _algo = algo;
-  }
-
-  void setChecksumLength(size_t length)
-  {
-    _checksumLength = length;
-  }
-
-  void setChecksums(const std::vector<std::string>& mds)
-  {
-    _checksums = mds;
+    pieceLength_ = length;
   }
 };
 
 } // namespace aria2
 
-#endif // _D_CHUNK_CHECKSUM_H_
+#endif // D_CHUNK_CHECKSUM_H
