@@ -61,6 +61,7 @@
 #include "DownloadContext.h"
 #include "wallclock.h"
 #include "FileEntry.h"
+#include "console.h"
 #ifdef ENABLE_BITTORRENT
 # include "bittorrent_helper.h"
 # include "PeerStorage.h"
@@ -100,7 +101,7 @@ void printProgress
  const SizeFormatter& sizeFormatter)
 {
   TransferStat stat = rg->calculateStat();
-  unsigned int eta = 0;
+  int eta = 0;
   if(rg->getTotalLength() > 0 && stat.getDownloadSpeed() > 0) {
     eta = (rg->getTotalLength()-rg->getCompletedLength())/stat.getDownloadSpeed();
   }
@@ -139,11 +140,10 @@ void printProgress
     << "CN:"
     << rg->getNumConnection();
 #ifdef ENABLE_BITTORRENT
-  SharedHandle<PeerStorage> ps =
-    e->getBtRegistry()->get(rg->getGID()).peerStorage_;
-  if(ps) {
+  const SharedHandle<BtObject>& btObj = e->getBtRegistry()->get(rg->getGID());
+  if(btObj) {
     std::vector<SharedHandle<Peer> > peers;
-    ps->getActivePeers(peers);
+    btObj->peerStorage->getActivePeers(peers);
     o << " " << "SEED:"
       << countSeeder(peers.begin(), peers.end());
   }
@@ -185,15 +185,17 @@ public:
   void operator()(const SharedHandle<RequestGroup>& rg)
   {
     const char SEP_CHAR = '-';
-    printProgress(std::cout, rg, e_, sizeFormatter_);
+    std::stringstream o;
+    printProgress(o, rg, e_, sizeFormatter_);
     const std::vector<SharedHandle<FileEntry> >& fileEntries =
       rg->getDownloadContext()->getFileEntries();
-    std::cout << "\n"
-              << "FILE: ";
+    o << "\n"
+      << "FILE: ";
     writeFilePath(fileEntries.begin(), fileEntries.end(),
-                  std::cout, rg->inMemoryDownload());
-    std::cout << "\n"
-              << std::setfill(SEP_CHAR) << std::setw(cols_) << SEP_CHAR << "\n";
+                  o, rg->inMemoryDownload());
+    o << "\n"
+      << std::setfill(SEP_CHAR) << std::setw(cols_) << SEP_CHAR << "\n";
+    global::cout()->write(o.str().c_str());
   }
 };
 } // namespace
@@ -207,7 +209,8 @@ void printProgressSummary
   const char SEP_CHAR = '=';
   time_t now;
   time(&now);
-  std::cout << " *** Download Progress Summary";
+  std::stringstream o;
+  o << " *** Download Progress Summary";
   {
     time_t now;
     struct tm* staticNowtmPtr;
@@ -218,11 +221,12 @@ void printProgressSummary
       if(lfptr) {
         *lfptr = '\0';
       }
-      std::cout << " as of " << buf;
+      o << " as of " << buf;
     }
   }
-  std::cout << " *** " << "\n"
-            << std::setfill(SEP_CHAR) << std::setw(cols) << SEP_CHAR << "\n";
+  o << " *** " << "\n"
+    << std::setfill(SEP_CHAR) << std::setw(cols) << SEP_CHAR << "\n";
+  global::cout()->write(o.str().c_str());
   std::for_each(groups.begin(), groups.end(),
                 PrintSummary(cols, e, sizeFormatter));
 }
@@ -243,10 +247,10 @@ ConsoleStatCalc::ConsoleStatCalc(time_t summaryInterval, bool humanReadable):
 void
 ConsoleStatCalc::calculateStat(const DownloadEngine* e)
 {
-  if(cp_.differenceInMillis(global::wallclock)+A2_DELTA_MILLIS < 1000) {
+  if(cp_.differenceInMillis(global::wallclock())+A2_DELTA_MILLIS < 1000) {
     return;
   }
-  cp_ = global::wallclock;
+  cp_ = global::wallclock();
   const SizeFormatter& sizeFormatter = *sizeFormatter_.get();
 
 #ifdef __MINGW32__
@@ -267,17 +271,19 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
     }
 #endif // HAVE_TERMIOS_H
 #endif // !__MINGW32__
-    std::cout << '\r' << std::setfill(' ') << std::setw(cols) << ' ' << '\r';
+    std::string line(cols, ' ');
+    global::cout()->printf("\r%s\r", line.c_str());
   }
   std::ostringstream o;
   if(e->getRequestGroupMan()->countRequestGroup() > 0) {
     if((summaryInterval_ > 0) &&
-       lastSummaryNotified_.differenceInMillis(global::wallclock)+
+       lastSummaryNotified_.differenceInMillis(global::wallclock())+
        A2_DELTA_MILLIS >= summaryInterval_*1000) {
-      lastSummaryNotified_ = global::wallclock;
+      lastSummaryNotified_ = global::wallclock();
       printProgressSummary(e->getRequestGroupMan()->getRequestGroups(), cols, e,
                            sizeFormatter);
-      std::cout << "\n";
+      global::cout()->write("\n");
+      global::cout()->flush();
     }
   }
   if(!readoutVisibility_) {
@@ -362,17 +368,14 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
 #endif // ENABLE_MESSAGE_DIGEST
   std::string readout = o.str();
   if(isTTY) {
-    std::string::iterator last = readout.begin();
     if(truncate_ && readout.size() > cols) {
-      std::advance(last, cols);
-    } else {
-      last = readout.end();
+      readout[cols] = '\0';
     }
-    std::copy(readout.begin(), last, std::ostream_iterator<char>(std::cout));
-    std::cout << std::flush;
+    global::cout()->write(readout.c_str());
+    global::cout()->flush();
   } else {
-    std::copy(readout.begin(), readout.end(), std::ostream_iterator<char>(std::cout));
-    std::cout << std::endl;
+    global::cout()->write(readout.c_str());
+    global::cout()->write("\n");
   }
 }
 
