@@ -45,6 +45,9 @@
 #include "Option.h"
 #include "RequestGroupMan.h"
 #include "FileEntry.h"
+#include "SocketRecvBuffer.h"
+#include "LogFactory.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
@@ -53,7 +56,9 @@ CreateRequestCommand::CreateRequestCommand(cuid_t cuid,
                                            DownloadEngine* e):
   AbstractCommand
   (cuid, SharedHandle<Request>(), SharedHandle<FileEntry>(), requestGroup, e,
-   SharedHandle<SocketCore>(), false)
+   SharedHandle<SocketCore>(),
+   SharedHandle<SocketRecvBuffer>(),
+   false)
 {
   setStatus(Command::STATUS_ONESHOT_REALTIME);
   disableReadCheckSocket();
@@ -89,7 +94,15 @@ bool CreateRequestCommand::executeInternal()
     if(getSegmentMan()) {
       getSegmentMan()->ignoreSegmentFor(getFileEntry());
     }
-    throw DL_ABORT_EX("No URI available.");
+    // In this case, the error might be already set in RequestGroup,
+    // so use it here.
+    throw DL_ABORT_EX2("No URI available.",
+                       getRequestGroup()->getLastErrorCode());
+  } else if(getRequest()->getWakeTime() > global::wallclock()) {
+    A2_LOG_DEBUG("This request object is still sleeping.");
+    getFileEntry()->poolRequest(getRequest());
+    getDownloadEngine()->addCommand(this);
+    return false;
   }
 
   Command* command =
