@@ -41,41 +41,45 @@
 #include "DHTNodeLookupEntry.h"
 #include "util.h"
 #include "Logger.h"
+#include "LogFactory.h"
+#include "DHTMessageCallback.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 DHTBucketRefreshTask::DHTBucketRefreshTask():
-  _forceRefresh(false) {}
+  forceRefresh_(false) {}
 
 DHTBucketRefreshTask::~DHTBucketRefreshTask() {}
 
 void DHTBucketRefreshTask::startup()
 {
   std::vector<SharedHandle<DHTBucket> > buckets;
-  _routingTable->getBuckets(buckets);
+  getRoutingTable()->getBuckets(buckets);
   for(std::vector<SharedHandle<DHTBucket> >::iterator i = buckets.begin(),
         eoi = buckets.end(); i != eoi; ++i) {
-    if(_forceRefresh || (*i)->needsRefresh()) {
+    if(forceRefresh_ || (*i)->needsRefresh()) {
       (*i)->notifyUpdate();
       unsigned char targetID[DHT_ID_LENGTH];
       (*i)->getRandomNodeID(targetID);
       SharedHandle<DHTNodeLookupTask> task(new DHTNodeLookupTask(targetID));
-      task->setRoutingTable(_routingTable);
-      task->setMessageDispatcher(_dispatcher);
-      task->setMessageFactory(_factory);
-      task->setTaskQueue(_taskQueue);
-      task->setLocalNode(_localNode);
+      task->setRoutingTable(getRoutingTable());
+      task->setMessageDispatcher(getMessageDispatcher());
+      task->setMessageFactory(getMessageFactory());
+      task->setTaskQueue(getTaskQueue());
+      task->setLocalNode(getLocalNode());
 
-      _logger->info("Dispating bucket refresh. targetID=%s", util::toHex(targetID, DHT_ID_LENGTH).c_str());
-      _taskQueue->addPeriodicTask1(task);
+      A2_LOG_INFO(fmt("Dispating bucket refresh. targetID=%s",
+                      util::toHex(targetID, DHT_ID_LENGTH).c_str()));
+      getTaskQueue()->addPeriodicTask1(task);
     }
   }
-  _finished = true;
+  setFinished(true);
 }
 
 void DHTBucketRefreshTask::setForceRefresh(bool forceRefresh)
 {
-  _forceRefresh = forceRefresh;
+  forceRefresh_ = forceRefresh;
 }
 
 } // namespace aria2
