@@ -76,10 +76,10 @@ SharedHandle<DHTMessage> DHTMessageReceiver::receiveMessage()
       return SharedHandle<DHTMessage>();
     }
     bool isReply = false;
-    SharedHandle<ValueBase> decoded = bencode2::decode(data, length);
-    const Dict* dict = asDict(decoded);
+    SharedHandle<ValueBase> decoded = bencode2::decode(data, data+length);
+    const Dict* dict = downcast<Dict>(decoded);
     if(dict) {
-      const String* y = asString(dict->get(DHTMessage::Y));
+      const String* y = downcast<String>(dict->get(DHTMessage::Y));
       if(y) {
         if(y->s() == DHTResponseMessage::R || y->s() == DHTUnknownMessage::E) {
           isReply = true;
