@@ -52,7 +52,6 @@ class DHTMessageCallback;
 class DHTRoutingTable;
 class DHTMessageFactory;
 class DHTMessageTrackerEntry;
-class Logger;
 
 class DHTMessageTracker {
 private:
@@ -62,8 +61,6 @@ private:
 
   SharedHandle<DHTMessageFactory> factory_;
 
-  Logger* logger_;
-
   void handleTimeoutEntry(const SharedHandle<DHTMessageTrackerEntry>& entry);
 public:
   DHTMessageTracker();
