@@ -48,33 +48,27 @@
 #include "util.h"
 #include "a2functional.h"
 #include "wallclock.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-DHTPeerAnnounceStorage::DHTPeerAnnounceStorage():
-  logger_(LogFactory::getInstance()) {}
+DHTPeerAnnounceStorage::DHTPeerAnnounceStorage() {}
 
 DHTPeerAnnounceStorage::~DHTPeerAnnounceStorage() {}
 
-namespace {
-class InfoHashLess
+bool DHTPeerAnnounceStorage::InfoHashLess::operator()
+  (const SharedHandle<DHTPeerAnnounceEntry>& lhs,
+   const SharedHandle<DHTPeerAnnounceEntry>& rhs)
 {
-public:
-  bool operator()(const SharedHandle<DHTPeerAnnounceEntry>& lhs,
-                  const SharedHandle<DHTPeerAnnounceEntry>& rhs)
-  {
-    return memcmp(lhs->getInfoHash(), rhs->getInfoHash(), DHT_ID_LENGTH) < 0;
-  }
-};
-} // namespace
+  return memcmp(lhs->getInfoHash(), rhs->getInfoHash(), DHT_ID_LENGTH) < 0;
+}
 
 SharedHandle<DHTPeerAnnounceEntry>
 DHTPeerAnnounceStorage::getPeerAnnounceEntry(const unsigned char* infoHash)
 {
   SharedHandle<DHTPeerAnnounceEntry> entry(new DHTPeerAnnounceEntry(infoHash));
 
-  std::deque<SharedHandle<DHTPeerAnnounceEntry> >::iterator i = 
-    std::lower_bound(entries_.begin(), entries_.end(), entry, InfoHashLess());
+  DHTPeerAnnounceEntrySet::iterator i = entries_.lower_bound(entry);
 
   if(i != entries_.end() &&
      memcmp(infoHash, (*i)->getInfoHash(), DHT_ID_LENGTH) == 0) {
@@ -89,11 +83,9 @@ void
 DHTPeerAnnounceStorage::addPeerAnnounce(const unsigned char* infoHash,
                                         const std::string& ipaddr, uint16_t port)
 {
-  if(logger_->debug()) {
-    logger_->debug("Adding %s:%u to peer announce list: infoHash=%s",
+  A2_LOG_DEBUG(fmt("Adding %s:%u to peer announce list: infoHash=%s",
                    ipaddr.c_str(), port,
-                   util::toHex(infoHash, DHT_ID_LENGTH).c_str());
-  }
+                   util::toHex(infoHash, DHT_ID_LENGTH).c_str()));
   getPeerAnnounceEntry(infoHash)->addPeerAddrEntry(PeerAddrEntry(ipaddr, port));
 }
 
@@ -109,11 +101,8 @@ void DHTPeerAnnounceStorage::getPeers(std::vector<SharedHandle<Peer> >& peers,
 {
   SharedHandle<DHTPeerAnnounceEntry> entry(new DHTPeerAnnounceEntry(infoHash));
 
-  std::deque<SharedHandle<DHTPeerAnnounceEntry> >::iterator i = 
-    std::lower_bound(entries_.begin(), entries_.end(), entry, InfoHashLess());
-  if(i != entries_.end() &&
-     memcmp(infoHash, (*i)->getInfoHash(), DHT_ID_LENGTH) == 0 &&
-     !(*i)->empty()) {
+  DHTPeerAnnounceEntrySet::iterator i = entries_.find(entry);
+  if(i != entries_.end()) {
     (*i)->getPeers(peers);
   }
 }
@@ -131,37 +120,35 @@ public:
 
 void DHTPeerAnnounceStorage::handleTimeout()
 {
-  if(logger_->debug()) {
-    logger_->debug("Now purge peer announces(%lu entries) which are timed out.",
-                   static_cast<unsigned long>(entries_.size()));
-  }
+  A2_LOG_DEBUG(fmt("Now purge peer announces(%lu entries) which are timed out.",
+                   static_cast<unsigned long>(entries_.size())));
   std::for_each(entries_.begin(), entries_.end(), RemoveStalePeerAddrEntry());
-  entries_.erase(std::remove_if(entries_.begin(), entries_.end(),
-                                mem_fun_sh(&DHTPeerAnnounceEntry::empty)),
-                 entries_.end());
-  if(logger_->debug()) {
-    logger_->debug("Currently %lu peer announce entries",
-                   static_cast<unsigned long>(entries_.size()));
+  for(DHTPeerAnnounceEntrySet::iterator i = entries_.begin(),
+        eoi = entries_.end(); i != eoi;) {
+    if((*i)->empty()) {
+      entries_.erase(i++);
+    } else {
+      ++i;
+    }
   }
+  A2_LOG_DEBUG(fmt("Currently %lu peer announce entries",
+                   static_cast<unsigned long>(entries_.size())));
 }
 
 void DHTPeerAnnounceStorage::announcePeer()
 {
-  if(logger_->debug()) {
-    logger_->debug("Now announcing peer.");
-  }
-  for(std::deque<SharedHandle<DHTPeerAnnounceEntry> >::iterator i =
+  A2_LOG_DEBUG("Now announcing peer.");
+  for(DHTPeerAnnounceEntrySet::iterator i =
         entries_.begin(), eoi = entries_.end(); i != eoi; ++i) {
     if((*i)->getLastUpdated().
-       difference(global::wallclock) >= DHT_PEER_ANNOUNCE_INTERVAL) {
+       difference(global::wallclock()) >= DHT_PEER_ANNOUNCE_INTERVAL) {
       (*i)->notifyUpdate();
       SharedHandle<DHTTask> task =
         taskFactory_->createPeerAnnounceTask((*i)->getInfoHash());
       taskQueue_->addPeriodicTask2(task);
-      if(logger_->debug()) {
-        logger_->debug("Added 1 peer announce: infoHash=%s",
-                       util::toHex((*i)->getInfoHash(), DHT_ID_LENGTH).c_str());
-      }
+      A2_LOG_DEBUG
+        (fmt("Added 1 peer announce: infoHash=%s",
+             util::toHex((*i)->getInfoHash(), DHT_ID_LENGTH).c_str()));
     }
   }
 }
