@@ -35,7 +35,6 @@
 #include "DHTResponseMessage.h"
 #include "DHTNode.h"
 #include "util.h"
-#include "bencode.h"
 #include "a2functional.h"
 
 namespace aria2 {
@@ -49,14 +48,14 @@ DHTResponseMessage::DHTResponseMessage(const SharedHandle<DHTNode>& localNode,
 
 DHTResponseMessage::~DHTResponseMessage() {}
 
-std::string DHTResponseMessage::getType() const
+const std::string& DHTResponseMessage::getType() const
 {
   return R;
 }
 
-void DHTResponseMessage::fillMessage(BDE& msgDict)
+void DHTResponseMessage::fillMessage(Dict* msgDict)
 {
-  msgDict[R] = getResponse();
+  msgDict->put(R, getResponse());
 }
 
 bool DHTResponseMessage::isReply() const
@@ -66,20 +65,14 @@ bool DHTResponseMessage::isReply() const
 
 std::string DHTResponseMessage::toString() const
 {
-  std::string s = strconcat
-    ("dht response ", getMessageType(),
-     " TransactionID=", util::toHex(_transactionID),
-     " Remote:", _remoteNode->getIPAddress(),
-     ":", util::uitos(_remoteNode->getPort()),
-     ", id=", util::toHex(_remoteNode->getID(), DHT_ID_LENGTH),
-     ", ");
-  if(!_version.empty()) {
-    s += "v=";
-    s += util::torrentPercentEncode(_version);
-    s += ", ";
-  }
-  s += toStringOptional();
-  return s;
+  return fmt("dht response %s TransactionID=%s Remote:%s(%u), id=%s, v=%s, %s",
+             getMessageType().c_str(),
+             util::toHex(getTransactionID()).c_str(),
+             getRemoteNode()->getIPAddress().c_str(),
+             getRemoteNode()->getPort(),
+             util::toHex(getRemoteNode()->getID(), DHT_ID_LENGTH).c_str(),
+             util::torrentPercentEncode(getVersion()).c_str(),
+             toStringOptional().c_str());
 }
 
 } // namespace aria2
