@@ -32,14 +32,17 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_RESPONSE_MESSAGE_H_
-#define _D_DHT_RESPONSE_MESSAGE_H_
+#ifndef D_DHT_RESPONSE_MESSAGE_H
+#define D_DHT_RESPONSE_MESSAGE_H
 
 #include "DHTAbstractMessage.h"
 #include "A2STR.h"
+#include "ValueBase.h"
 
 namespace aria2 {
 
+class DHTMessageCallback;
+
 class DHTResponseMessage:public DHTAbstractMessage {
 protected:
   virtual std::string toStringOptional() const { return A2STR::NIL; }
@@ -50,19 +53,21 @@ public:
 
   virtual ~DHTResponseMessage();
 
-  virtual std::string getType() const;
+  virtual const std::string& getType() const;
 
-  virtual void fillMessage(BDE& msgDict);
+  virtual void fillMessage(Dict* msgDict);
 
-  virtual BDE getResponse() = 0;
+  virtual SharedHandle<Dict> getResponse() = 0;
   
   virtual bool isReply() const;
 
   virtual std::string toString() const;
 
+  virtual void accept(DHTMessageCallback* callback) = 0;
+
   static const std::string R;
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_RESPONSE_MESSAGE_H_
+#endif // D_DHT_RESPONSE_MESSAGE_H
