@@ -36,7 +36,7 @@
 
 #include <cstring>
 #include <cassert>
-#include <istream>
+#include <cstdio>
 #include <utility>
 
 #include "DHTNode.h"
@@ -48,6 +48,8 @@
 #include "fmt.h"
 #include "util.h"
 #include "array_fun.h"
+#include "LogFactory.h"
+#include "BufferedFile.h"
 
 namespace aria2 {
 
@@ -56,27 +58,30 @@ DHTRoutingTableDeserializer::DHTRoutingTableDeserializer(int family):
 
 DHTRoutingTableDeserializer::~DHTRoutingTableDeserializer() {}
 
+#define READ_CHECK(fp, ptr, count)                              \
+  if(fp.read((ptr), (count)) != (count)) {                      \
+    throw DL_ABORT_EX("Failed to load DHT routing table.");     \
+  }
+
 namespace {
-void readBytes(unsigned char* buf, size_t buflen,
-               std::istream& in, size_t readlen)
+void readBytes(BufferedFile& fp,
+               unsigned char* buf, size_t buflen,
+               size_t readlen)
 {
   assert(readlen <= buflen);
-  in.read(reinterpret_cast<char*>(buf), readlen);
+  READ_CHECK(fp, buf, readlen);
 }
 } // namespace
 
-#define CHECK_STREAM(in, length)                                        \
-  if(in.gcount() != length) {                                           \
-    throw DL_ABORT_EX                                                   \
-      (fmt("Failed to load DHT routing table. cause:%s",                \
-           "Unexpected EOF"));                                          \
-  }                                                                     \
-  if(!in) {                                                             \
-    throw DL_ABORT_EX("Failed to load DHT routing table.");             \
-  }
-
-void DHTRoutingTableDeserializer::deserialize(std::istream& in)
+void DHTRoutingTableDeserializer::deserialize(const std::string& filename)
 {
+  A2_LOG_INFO(fmt("Loading DHT routing table from %s.",
+                  filename.c_str()));
+  BufferedFile fp(filename, BufferedFile::READ);
+  if(!fp) {
+    throw DL_ABORT_EX(fmt("Failed to load DHT routing table from %s",
+                          filename.c_str()));
+  }
   char header[8];
   memset(header, 0, sizeof(header));
   // magic
@@ -109,15 +114,15 @@ void DHTRoutingTableDeserializer::deserialize(std::istream& in)
   array_wrapper<unsigned char, 255> buf;
 
   // header
-  readBytes(buf, buf.size(), in, 8);
-  CHECK_STREAM(in, 8);
+  readBytes(fp, buf, buf.size(), 8);
   if(memcmp(header, buf, 8) == 0) {
     version = 3;
   } else if(memcmp(headerCompat, buf, 8) == 0) {
     version = 2;
   } else {
     throw DL_ABORT_EX
-      (fmt("Failed to load DHT routing table. cause:%s",
+      (fmt("Failed to load DHT routing table from %s. cause:%s",
+           filename.c_str(),
            "bad header"));
   }
   
@@ -125,37 +130,29 @@ void DHTRoutingTableDeserializer::deserialize(std::istream& in)
   uint64_t temp64;
   // time
   if(version == 2) {
-    in.read(reinterpret_cast<char*>(&temp32), sizeof(temp32));
-    CHECK_STREAM(in, sizeof(temp32));
+    READ_CHECK(fp, &temp32, sizeof(temp32));
     serializedTime_.setTimeInSec(ntohl(temp32));
     // 4bytes reserved
-    readBytes(buf, buf.size(), in, 4);
-    CHECK_STREAM(in, 4);
+    readBytes(fp, buf, buf.size(), 4);
   } else {
-    in.read(reinterpret_cast<char*>(&temp64), sizeof(temp64));
-    CHECK_STREAM(in, sizeof(temp64));
+    READ_CHECK(fp, &temp64, sizeof(temp64));
     serializedTime_.setTimeInSec(ntoh64(temp64));
   }
   
   // localnode
   // 8bytes reserved
-  readBytes(buf, buf.size(), in, 8);
-  CHECK_STREAM(in, 8);
+  readBytes(fp, buf, buf.size(), 8);
   // localnode ID
-  readBytes(buf, buf.size(), in, DHT_ID_LENGTH);
-  CHECK_STREAM(in, DHT_ID_LENGTH);
+  readBytes(fp, buf, buf.size(), DHT_ID_LENGTH);
   SharedHandle<DHTNode> localNode(new DHTNode(buf));
   // 4bytes reserved
-  readBytes(buf, buf.size(), in, 4);
-  CHECK_STREAM(in, 4);
+  readBytes(fp, buf, buf.size(), 4);
 
   // number of nodes
-  in.read(reinterpret_cast<char*>(&temp32), sizeof(temp32));
-  CHECK_STREAM(in, sizeof(temp32));
+  READ_CHECK(fp, &temp32, sizeof(temp32));
   uint32_t numNodes = ntohl(temp32);
   // 4bytes reserved
-  readBytes(buf, buf.size(), in, 4);
-  CHECK_STREAM(in, 4);
+  readBytes(fp, buf, buf.size(), 4);
 
   std::vector<SharedHandle<DHTNode> > nodes;
   // nodes
@@ -163,50 +160,44 @@ void DHTRoutingTableDeserializer::deserialize(std::istream& in)
   for(size_t i = 0; i < numNodes; ++i) {
     // 1byte compact peer info length
     uint8_t peerInfoLen;
-    in >> peerInfoLen;
+    READ_CHECK(fp, &peerInfoLen, sizeof(peerInfoLen));
     if(peerInfoLen != compactlen) {
       // skip this entry
-      readBytes(buf, buf.size(), in, 7+48);
-      CHECK_STREAM(in, 7+48);
+      readBytes(fp, buf, buf.size(), 7+48);
       continue;
     }
     // 7bytes reserved
-    readBytes(buf, buf.size(), in, 7);
-    CHECK_STREAM(in, 7);
+    readBytes(fp, buf, buf.size(), 7);
     // compactlen bytes compact peer info
-    readBytes(buf, buf.size(), in, compactlen);
-    CHECK_STREAM(in, compactlen);
+    readBytes(fp, buf, buf.size(), compactlen);
     if(memcmp(zero, buf, compactlen) == 0) {
       // skip this entry
-      readBytes(buf, buf.size(), in, 48-compactlen);
-      CHECK_STREAM(in, 48-compactlen);
+      readBytes(fp, buf, buf.size(), 48-compactlen);
       continue;
     }
     std::pair<std::string, uint16_t> peer =
       bittorrent::unpackcompact(buf, family_);
     if(peer.first.empty()) {
       // skip this entry
-      readBytes(buf, buf.size(), in, 48-compactlen);
-      CHECK_STREAM(in, 48-compactlen);
+      readBytes(fp, buf, buf.size(), 48-compactlen);
       continue;
     }
     // 24-compactlen bytes reserved
-    readBytes(buf, buf.size(), in, 24-compactlen);
+    readBytes(fp, buf, buf.size(), 24-compactlen);
     // node ID
-    readBytes(buf, buf.size(), in, DHT_ID_LENGTH);
-    CHECK_STREAM(in, DHT_ID_LENGTH);
+    readBytes(fp, buf, buf.size(), DHT_ID_LENGTH);
 
     SharedHandle<DHTNode> node(new DHTNode(buf));
     node->setIPAddress(peer.first);
     node->setPort(peer.second);
     // 4bytes reserved
-    readBytes(buf, buf.size(), in, 4);
-    CHECK_STREAM(in, 4);
+    readBytes(fp, buf, buf.size(), 4);
 
     nodes.push_back(node);
   }
   localNode_ = localNode;
   nodes_ = nodes;
+  A2_LOG_INFO("DHT routing table was loaded successfully");
 }
 
 } // namespace aria2
