@@ -41,7 +41,6 @@
 namespace aria2 {
 
 class DownloadContext;
-class BtRuntime;
 class PeerStorage;
 class DHTTask;
 class DHTNode;
@@ -53,7 +52,7 @@ public:
 
   virtual SharedHandle<DHTTask>
   createPingTask(const SharedHandle<DHTNode>& remoteNode,
-                 size_t numRetry = 0) = 0;
+                 int numRetry = 0) = 0;
 
   virtual SharedHandle<DHTTask>
   createNodeLookupTask(const unsigned char* targetID) = 0;
@@ -62,7 +61,7 @@ public:
 
   virtual SharedHandle<DHTTask>
   createPeerLookupTask(const SharedHandle<DownloadContext>& ctx,
-                       const SharedHandle<BtRuntime>& btRuntime,
+                       uint16_t tcpPort,
                        const SharedHandle<PeerStorage>& peerStorage) = 0;
   
   virtual SharedHandle<DHTTask>
