@@ -47,107 +47,113 @@
 #include "a2functional.h"
 #include "SimpleRandomizer.h"
 #include "array_fun.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-DefaultBtRequestFactory::DefaultBtRequestFactory():
-  cuid(0),
-  _logger(LogFactory::getInstance())
-{
-  if(_logger->debug()) {
-    _logger->debug("DefaultBtRequestFactory::instantiated");
-  }
-}
+DefaultBtRequestFactory::DefaultBtRequestFactory()
+  : dispatcher_(0),
+    messageFactory_(0),
+    cuid_(0)
+{}
 
-DefaultBtRequestFactory::~DefaultBtRequestFactory()
-{
-  if(_logger->debug()) {
-    _logger->debug("DefaultBtRequestFactory::deleted");
-  }
-}
+DefaultBtRequestFactory::~DefaultBtRequestFactory() {}
 
 void DefaultBtRequestFactory::addTargetPiece(const SharedHandle<Piece>& piece)
 {
-  pieces.push_back(piece);
+  pieces_.push_back(piece);
 }
 
+namespace {
 class AbortCompletedPieceRequest
 {
 private:
-  WeakHandle<BtMessageDispatcher> _dispatcher;
+  BtMessageDispatcher* dispatcher_;
 public:
-  AbortCompletedPieceRequest(const WeakHandle<BtMessageDispatcher>& dispatcher):
-    _dispatcher(dispatcher) {}
+  AbortCompletedPieceRequest(BtMessageDispatcher* dispatcher):
+    dispatcher_(dispatcher) {}
 
   void operator()(const SharedHandle<Piece>& piece)
   {
     if(piece->pieceComplete()) {
-      _dispatcher->doAbortOutstandingRequestAction(piece);
+      dispatcher_->doAbortOutstandingRequestAction(piece);
     }
   }
 };
+} // namespace
 
 void DefaultBtRequestFactory::removeCompletedPiece() {
-  std::for_each(pieces.begin(), pieces.end(),
-                AbortCompletedPieceRequest(dispatcher));
-  pieces.erase(std::remove_if(pieces.begin(), pieces.end(),
+  std::for_each(pieces_.begin(), pieces_.end(),
+                AbortCompletedPieceRequest(dispatcher_));
+  pieces_.erase(std::remove_if(pieces_.begin(), pieces_.end(),
                               mem_fun_sh(&Piece::pieceComplete)),
-               pieces.end());
+               pieces_.end());
 }
 
-void DefaultBtRequestFactory::removeTargetPiece(const SharedHandle<Piece>& piece) {
-  pieces.erase(std::remove(pieces.begin(), pieces.end(), piece),
-               pieces.end());
-  dispatcher->doAbortOutstandingRequestAction(piece);
-  _pieceStorage->cancelPiece(piece);
+void DefaultBtRequestFactory::removeTargetPiece
+(const SharedHandle<Piece>& piece)
+{
+  pieces_.erase(std::remove_if(pieces_.begin(), pieces_.end(),
+                               derefEqual(piece)),
+                pieces_.end());
+  dispatcher_->doAbortOutstandingRequestAction(piece);
+  pieceStorage_->cancelPiece(piece, cuid_);
 }
 
+namespace {
 class ProcessChokedPiece {
 private:
-  SharedHandle<Peer> _peer;
-  WeakHandle<PieceStorage> _pieceStorage;
+  SharedHandle<Peer> peer_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  cuid_t cuid_;
 public:
   ProcessChokedPiece(const SharedHandle<Peer>& peer,
-                     const WeakHandle<PieceStorage>& pieceStorage):
-    _peer(peer),
-    _pieceStorage(pieceStorage) {}
+                     const SharedHandle<PieceStorage>& pieceStorage,
+                     cuid_t cuid):
+    peer_(peer),
+    pieceStorage_(pieceStorage),
+    cuid_(cuid)
+  {}
 
   void operator()(const SharedHandle<Piece>& piece)
   {
-    if(!_peer->isInPeerAllowedIndexSet(piece->getIndex())) {
-      _pieceStorage->cancelPiece(piece);
+    if(!peer_->isInPeerAllowedIndexSet(piece->getIndex())) {
+      pieceStorage_->cancelPiece(piece, cuid_);
     }
   }
 };
+} // namespace
 
+namespace {
 class FindChokedPiece {
 private:
-  SharedHandle<Peer> _peer;
+  SharedHandle<Peer> peer_;
 public:
-  FindChokedPiece(const SharedHandle<Peer>& peer):_peer(peer) {}
+  FindChokedPiece(const SharedHandle<Peer>& peer):peer_(peer) {}
 
   bool operator()(const SharedHandle<Piece>& piece)
   {
-    return !_peer->isInPeerAllowedIndexSet(piece->getIndex());
+    return !peer_->isInPeerAllowedIndexSet(piece->getIndex());
   }
 };
+} // namespace
 
 void DefaultBtRequestFactory::doChokedAction()
 {
-  std::for_each(pieces.begin(), pieces.end(),
-                ProcessChokedPiece(peer, _pieceStorage));
-  pieces.erase(std::remove_if(pieces.begin(), pieces.end(),
-                              FindChokedPiece(peer)),
-               pieces.end());
+  std::for_each(pieces_.begin(), pieces_.end(),
+                ProcessChokedPiece(peer_, pieceStorage_, cuid_));
+  pieces_.erase(std::remove_if(pieces_.begin(), pieces_.end(),
+                              FindChokedPiece(peer_)),
+               pieces_.end());
 }
 
 void DefaultBtRequestFactory::removeAllTargetPiece() {
-  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces.begin(),
-        eoi = pieces.end(); itr != eoi; ++itr) {
-    dispatcher->doAbortOutstandingRequestAction(*itr);
-    _pieceStorage->cancelPiece(*itr);
+  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces_.begin(),
+        eoi = pieces_.end(); itr != eoi; ++itr) {
+    dispatcher_->doAbortOutstandingRequestAction(*itr);
+    pieceStorage_->cancelPiece(*itr, cuid_);
   }
-  pieces.clear();
+  pieces_.clear();
 }
 
 void DefaultBtRequestFactory::createRequestMessages
@@ -159,22 +165,21 @@ void DefaultBtRequestFactory::createRequestMessages
   size_t getnum = max-requests.size();
   std::vector<size_t> blockIndexes;
   blockIndexes.reserve(getnum);
-  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces.begin(),
-        eoi = pieces.end(); itr != eoi && getnum; ++itr) {
+  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces_.begin(),
+        eoi = pieces_.end(); itr != eoi && getnum; ++itr) {
     SharedHandle<Piece>& piece = *itr;
     if(piece->getMissingUnusedBlockIndex(blockIndexes, getnum)) {
       getnum -= blockIndexes.size();
       for(std::vector<size_t>::const_iterator i = blockIndexes.begin(),
             eoi2 = blockIndexes.end(); i != eoi2; ++i) {
-        if(_logger->debug()) {
-          _logger->debug("Creating RequestMessage index=%u, begin=%u,"
-                         " blockIndex=%u",
-                         piece->getIndex(),
-                         (*i)*piece->getBlockLength(),
-                         (*i));
-        }
+        A2_LOG_DEBUG
+          (fmt("Creating RequestMessage index=%lu, begin=%u,"
+               " blockIndex=%lu",
+               static_cast<unsigned long>(piece->getIndex()),
+               static_cast<unsigned int>((*i)*piece->getBlockLength()),
+               static_cast<unsigned long>(*i)));
         requests.push_back
-          (messageFactory->createRequestMessage(piece, *i));
+          (messageFactory_->createRequestMessage(piece, *i));
       }
       blockIndexes.clear();
     }
@@ -184,8 +189,8 @@ void DefaultBtRequestFactory::createRequestMessages
 void DefaultBtRequestFactory::createRequestMessagesOnEndGame
 (std::vector<SharedHandle<BtMessage> >& requests, size_t max)
 {
-  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces.begin(),
-        eoi = pieces.end(); itr != eoi && requests.size() < max; ++itr) {
+  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces_.begin(),
+        eoi = pieces_.end(); itr != eoi && requests.size() < max; ++itr) {
     SharedHandle<Piece>& piece = *itr;
     const size_t mislen = piece->getBitfieldLength();
     array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
@@ -209,71 +214,74 @@ void DefaultBtRequestFactory::createRequestMessagesOnEndGame
           eoi2 = missingBlockIndexes.end();
         bitr != eoi2 && requests.size() < max; ++bitr) {
       const size_t& blockIndex = *bitr;
-      if(!dispatcher->isOutstandingRequest(piece->getIndex(),
+      if(!dispatcher_->isOutstandingRequest(piece->getIndex(),
                                            blockIndex)) {
-        if(_logger->debug()) {
-          _logger->debug("Creating RequestMessage index=%u, begin=%u,"
-                         " blockIndex=%u",
-                         piece->getIndex(),
-                         blockIndex*piece->getBlockLength(),
-                         blockIndex);
-        }
-        requests.push_back(messageFactory->createRequestMessage(piece, blockIndex));
+        A2_LOG_DEBUG
+          (fmt("Creating RequestMessage index=%lu, begin=%u,"
+               " blockIndex=%lu",
+               static_cast<unsigned long>(piece->getIndex()),
+               static_cast<unsigned int>(blockIndex*piece->getBlockLength()),
+               static_cast<unsigned long>(blockIndex)));
+        requests.push_back(messageFactory_->createRequestMessage
+                           (piece, blockIndex));
       }
     }
   }
 }
 
+namespace {
 class CountMissingBlock
 {
 private:
-  size_t _numMissingBlock;
+  size_t numMissingBlock_;
 public:
-  CountMissingBlock():_numMissingBlock(0) {}
+  CountMissingBlock():numMissingBlock_(0) {}
 
   size_t getNumMissingBlock()
   {
-    return _numMissingBlock;
+    return numMissingBlock_;
   }
 
   void operator()(const SharedHandle<Piece>& piece)
   {
-    _numMissingBlock += piece->countMissingBlock();
+    numMissingBlock_ += piece->countMissingBlock();
   }
 };
+} // namespace
 
 size_t DefaultBtRequestFactory::countMissingBlock()
 {
-  return std::for_each(pieces.begin(), pieces.end(),
+  return std::for_each(pieces_.begin(), pieces_.end(),
                        CountMissingBlock()).getNumMissingBlock();
 }
 
 void DefaultBtRequestFactory::getTargetPieceIndexes
 (std::vector<size_t>& indexes) const
 {
-  std::transform(pieces.begin(), pieces.end(), std::back_inserter(indexes),
+  std::transform(pieces_.begin(), pieces_.end(), std::back_inserter(indexes),
                  mem_fun_sh(&Piece::getIndex));
 }
 
 void DefaultBtRequestFactory::setPieceStorage
 (const SharedHandle<PieceStorage>& pieceStorage)
 {
-  _pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
 void DefaultBtRequestFactory::setPeer(const SharedHandle<Peer>& peer)
 {
-  this->peer = peer;
+  peer_ = peer;
 }
 
-void DefaultBtRequestFactory::setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher)
+void DefaultBtRequestFactory::setBtMessageDispatcher
+(BtMessageDispatcher* dispatcher)
 {
-  this->dispatcher = dispatcher;
+  dispatcher_ = dispatcher;
 }
 
-void DefaultBtRequestFactory::setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory)
+void DefaultBtRequestFactory::setBtMessageFactory(BtMessageFactory* factory)
 {
-  this->messageFactory = factory;
+  messageFactory_ = factory;
 }
 
 } // namespace aria2
