@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DEFAULT_DISK_WRITER_FACTORY_H_
-#define _D_DEFAULT_DISK_WRITER_FACTORY_H_
+#ifndef D_DEFAULT_DISK_WRITER_FACTORY_H
+#define D_DEFAULT_DISK_WRITER_FACTORY_H
 
 #include "DiskWriterFactory.h"
 
@@ -51,4 +51,4 @@ typedef SharedHandle<DefaultDiskWriterFactory> DefaultDiskWriterFactoryHandle;
 
 } // namespace aria2
 
-#endif // _D_DEFAULT_DISK_WRITER_FACTORY_H_
+#endif // D_DEFAULT_DISK_WRITER_FACTORY_H
