@@ -56,8 +56,8 @@ private:
   size_t maxPeerListSize_;
   std::deque<SharedHandle<Peer> > peers_;
   std::deque<SharedHandle<Peer> > droppedPeers_;
-  uint64_t removedPeerSessionDownloadLength_;
-  uint64_t removedPeerSessionUploadLength_;
+  int64_t removedPeerSessionDownloadLength_;
+  int64_t removedPeerSessionUploadLength_;
 
   BtSeederStateChoke* seederStateChoke_;
   BtLeecherStateChoke* leecherStateChoke_;
@@ -68,6 +68,9 @@ private:
 
   TransferStat cachedTransferStat_;
 
+  std::map<std::string, time_t> badPeers_;
+  Timer lastBadPeerCleaned_;
+
   bool isPeerAlreadyAdded(const SharedHandle<Peer>& peer);
 
   void addDroppedPeer(const SharedHandle<Peer>& peer);
@@ -78,7 +81,7 @@ public:
 
   virtual bool addPeer(const SharedHandle<Peer>& peer);
 
-  size_t countPeer() const;
+  virtual size_t countPeer() const;
 
   virtual SharedHandle<Peer> getUnusedPeer();
 
@@ -100,6 +103,10 @@ public:
 
   virtual TransferStat getTransferStatFor(const SharedHandle<Peer>& peer);
 
+  virtual bool isBadPeer(const std::string& ipaddr);
+
+  virtual void addBadPeer(const std::string& ipaddr);
+
   virtual void returnPeer(const SharedHandle<Peer>& peer);
 
   virtual bool chokeRoundIntervalElapsed();
