@@ -63,6 +63,8 @@
 #include "PieceStatMan.h"
 #include "wallclock.h"
 #include "bitfield.h"
+#include "SingletonHolder.h"
+#include "Notifier.h"
 #ifdef ENABLE_BITTORRENT
 # include "bittorrent_helper.h"
 #endif // ENABLE_BITTORRENT
@@ -124,7 +126,7 @@ SharedHandle<Piece> DefaultPieceStorage::checkOutPiece
 SharedHandle<Piece> DefaultPieceStorage::getPiece(size_t index)
 {
   SharedHandle<Piece> piece;
-  if(0 <= index && index <= bitfieldMan_->getMaxIndex()) {
+  if(index <= bitfieldMan_->getMaxIndex()) {
     piece = findUsedPiece(index);
     if(!piece) {
       piece.reset(new Piece(index, bitfieldMan_->getBlockLength(index)));
@@ -138,10 +140,7 @@ SharedHandle<Piece> DefaultPieceStorage::getPiece(size_t index)
 
 void DefaultPieceStorage::addUsedPiece(const SharedHandle<Piece>& piece)
 {
-  std::deque<SharedHandle<Piece> >::iterator i =
-    std::lower_bound(usedPieces_.begin(), usedPieces_.end(), piece,
-                     DerefLess<SharedHandle<Piece> >());
-  usedPieces_.insert(i, piece);
+  usedPieces_.insert(piece);
   A2_LOG_DEBUG(fmt("usedPieces_.size()=%lu",
                    static_cast<unsigned long>(usedPieces_.size())));
 }
@@ -151,14 +150,12 @@ SharedHandle<Piece> DefaultPieceStorage::findUsedPiece(size_t index) const
   SharedHandle<Piece> p(new Piece());
   p->setIndex(index);
 
-  std::deque<SharedHandle<Piece> >::const_iterator i =
-    std::lower_bound(usedPieces_.begin(), usedPieces_.end(), p,
-                     DerefLess<SharedHandle<Piece> >());
-  if(i != usedPieces_.end() && *(*i) == *p) {
-    return *i;
-  } else {
+  UsedPieceSet::iterator i = usedPieces_.find(p);
+  if(i == usedPieces_.end()) {
     p.reset();
     return p;
+  } else {
+    return *i;
   }
 }
 
@@ -236,7 +233,7 @@ void unsetExcludedIndexes(BitfieldMan& bitfield,
 void DefaultPieceStorage::createFastIndexBitfield
 (BitfieldMan& bitfield, const SharedHandle<Peer>& peer)
 {
-  for(std::vector<size_t>::const_iterator itr =
+  for(std::set<size_t>::const_iterator itr =
         peer->getPeerAllowedIndexSet().begin(),
         eoi = peer->getPeerAllowedIndexSet().end(); itr != eoi; ++itr) {
     if(!bitfieldMan_->isBitSet(*itr) && peer->hasPiece(*itr)) {
@@ -403,12 +400,7 @@ void DefaultPieceStorage::deleteUsedPiece(const SharedHandle<Piece>& piece)
   if(!piece) {
     return;
   }
-  std::deque<SharedHandle<Piece> >::iterator i = 
-    std::lower_bound(usedPieces_.begin(), usedPieces_.end(), piece,
-                     DerefLess<SharedHandle<Piece> >());
-  if(i != usedPieces_.end() && *(*i) == *piece) {
-    usedPieces_.erase(i);
-  }
+  usedPieces_.erase(piece);
 }
 
 // void DefaultPieceStorage::reduceUsedPieces(size_t upperBound)
@@ -479,6 +471,9 @@ void DefaultPieceStorage::completePiece(const SharedHandle<Piece>& piece)
       if(!torrentAttrs->metadata.empty()) {
         util::executeHookByOptName(downloadContext_->getOwnerRequestGroup(),
                                    option_, PREF_ON_BT_DOWNLOAD_COMPLETE);
+        SingletonHolder<Notifier>::instance()->
+          notifyDownloadEvent(Notifier::ON_BT_DOWNLOAD_COMPLETE,
+                              downloadContext_->getOwnerRequestGroup());
       }
     }
 #endif // ENABLE_BITTORRENT
@@ -753,9 +748,7 @@ void DefaultPieceStorage::markPieceMissing(size_t index)
 void DefaultPieceStorage::addInFlightPiece
 (const std::vector<SharedHandle<Piece> >& pieces)
 {
-  usedPieces_.insert(usedPieces_.end(), pieces.begin(), pieces.end());
-  std::sort(usedPieces_.begin(), usedPieces_.end(),
-            DerefLess<SharedHandle<Piece> >());
+  usedPieces_.insert(pieces.begin(), pieces.end());
 }
 
 size_t DefaultPieceStorage::countInFlightPiece()
