@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -34,16 +34,12 @@
 /* copyright --> */
 #include "DiskAdaptor.h"
 #include "FileEntry.h"
-#include "LogFactory.h"
-#include "Logger.h"
 
 namespace aria2 {
 
-DiskAdaptor::DiskAdaptor():
-#ifdef HAVE_POSIX_FALLOCATE
-  _fallocate(false),
-#endif // HAVE_POSIX_FALLOCATE
-  logger(LogFactory::getInstance()) {}
+DiskAdaptor::DiskAdaptor()
+  : fallocate_(false)
+{}
 
 DiskAdaptor::~DiskAdaptor() {}
 
