@@ -66,7 +66,7 @@ public:
 
   virtual bool fileExists() = 0;
 
-  virtual uint64_t size() = 0;
+  virtual off_t size() = 0;
 
   template<typename InputIterator>
   void setFileEntries(InputIterator first, InputIterator last)
@@ -81,10 +81,6 @@ public:
 
   virtual SharedHandle<FileAllocationIterator> fileAllocationIterator() = 0;
 
-  virtual void enableDirectIO() {}
-
-  virtual void disableDirectIO() {}
-
   virtual void enableReadOnly() {}
 
   virtual void disableReadOnly() {}
