@@ -49,10 +49,8 @@ class MessageDigest;
 
 class DownloadCommand : public AbstractCommand {
 private:
-  unsigned char* buf_;
-
   time_t startupIdleTime_;
-  unsigned int lowestDownloadSpeedLimit_;
+  int lowestDownloadSpeedLimit_;
   SharedHandle<PeerStat> peerStat_;
 
   bool pieceHashValidationEnabled_;
@@ -85,7 +83,8 @@ public:
                   const SharedHandle<FileEntry>& fileEntry,
                   RequestGroup* requestGroup,
                   DownloadEngine* e,
-                  const SharedHandle<SocketCore>& s);
+                  const SharedHandle<SocketCore>& s,
+                  const SharedHandle<SocketRecvBuffer>& socketRecvBuffer);
   virtual ~DownloadCommand();
 
   const SharedHandle<StreamFilter>& getStreamFilter() const
@@ -100,7 +99,7 @@ public:
     startupIdleTime_ = startupIdleTime;
   }
 
-  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit)
+  void setLowestDownloadSpeedLimit(int lowestDownloadSpeedLimit)
   {
     lowestDownloadSpeedLimit_ = lowestDownloadSpeedLimit;
   }
