@@ -53,17 +53,19 @@ DownloadContext::DownloadContext():
   knowsTotalLength_(true),
   ownerRequestGroup_(0),
   downloadStartTime_(0),
-  downloadStopTime_(downloadStartTime_) {}
+  downloadStopTime_(downloadStartTime_),
+  metalinkServerContacted_(false) {}
 
-DownloadContext::DownloadContext(size_t pieceLength,
-                                 uint64_t totalLength,
+DownloadContext::DownloadContext(int32_t pieceLength,
+                                 off_t totalLength,
                                  const std::string& path):
   pieceLength_(pieceLength),
   checksumVerified_(false),
   knowsTotalLength_(true),
   ownerRequestGroup_(0),
   downloadStartTime_(0),
-  downloadStopTime_(0)
+  downloadStopTime_(0),
+  metalinkServerContacted_(false)
 {
   SharedHandle<FileEntry> fileEntry(new FileEntry(path, totalLength, 0));
   fileEntries_.push_back(fileEntry);
@@ -73,13 +75,13 @@ DownloadContext::~DownloadContext() {}
 
 void DownloadContext::resetDownloadStartTime()
 {
-  downloadStartTime_ = global::wallclock;
+  downloadStartTime_ = global::wallclock();
   downloadStopTime_.reset(0);
 }
 
 void DownloadContext::resetDownloadStopTime()
 {
-  downloadStopTime_ = global::wallclock;
+  downloadStopTime_ = global::wallclock();
 }
 
 int64_t DownloadContext::calculateSessionTime() const
@@ -96,9 +98,7 @@ SharedHandle<FileEntry>
 DownloadContext::findFileEntryByOffset(off_t offset) const
 {
   if(fileEntries_.empty() ||
-     (offset > 0 &&
-      fileEntries_.back()->getOffset()+fileEntries_.back()->getLength() <=
-      static_cast<uint64_t>(offset))){
+     (offset > 0 && fileEntries_.back()->getLastOffset() <= offset)) {
     return SharedHandle<FileEntry>();
   }
 
@@ -126,22 +126,27 @@ void DownloadContext::setFilePathWithIndex
   }
 }
 
-void DownloadContext::setFileFilter(IntSequence seq)
+void DownloadContext::setFileFilter(SegList<int>& sgl)
 {
-  std::vector<int32_t> fileIndexes = seq.flush();
-  std::sort(fileIndexes.begin(), fileIndexes.end());
-  fileIndexes.erase(std::unique(fileIndexes.begin(), fileIndexes.end()),
-                    fileIndexes.end());
-
-  bool selectAll = fileIndexes.empty() || fileEntries_.size() == 1;
-    
-  int32_t index = 1;
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
-        fileEntries_.begin(), eoi = fileEntries_.end();
-      i != eoi; ++i, ++index) {
-    (*i)->setRequested
-      (selectAll ||
-       std::binary_search(fileIndexes.begin(), fileIndexes.end(), index));
+  if(!sgl.hasNext() || fileEntries_.size() == 1) {
+    std::for_each(fileEntries_.begin(), fileEntries_.end(),
+                  std::bind2nd(mem_fun_sh(&FileEntry::setRequested), true));
+    return;
+  }
+  assert(sgl.peek() >= 1);
+  size_t len = fileEntries_.size();
+  size_t i = 0;
+  for(; i < len && sgl.hasNext(); ++i) {
+    size_t idx = sgl.peek()-1;
+    if(i == idx) {
+      fileEntries_[i]->setRequested(true);
+      sgl.next();
+    } else if(i < idx) {
+      fileEntries_[i]->setRequested(false);
+    }
+  }
+  for(; i < len; ++i) {
+    fileEntries_[i]->setRequested(false);
   }
 }
 
@@ -178,6 +183,7 @@ void DownloadContext::releaseRuntimeResource()
 {
   for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
         fileEntries_.begin(), eoi = fileEntries_.end(); i != eoi; ++i) {
+    (*i)->putBackRequest();
     (*i)->releaseRuntimeResource();
   }
 }
@@ -192,7 +198,7 @@ size_t DownloadContext::getNumPieces() const
   }
 }
 
-uint64_t DownloadContext::getTotalLength() const
+off_t DownloadContext::getTotalLength() const
 {
   if(fileEntries_.empty()) {
     return 0;
@@ -237,18 +243,18 @@ size_t DownloadContext::countRequestedFileEntry() const
 
 bool DownloadContext::isChecksumVerificationNeeded() const
 {
-  return pieceHashAlgo_.empty() &&
-    !checksum_.empty() && !checksumHashAlgo_.empty() && !checksumVerified_;
+  return pieceHashType_.empty() &&
+    !digest_.empty() && !hashType_.empty() && !checksumVerified_;
 }
 
 bool DownloadContext::isChecksumVerificationAvailable() const
 {
-  return !checksum_.empty() && !checksumHashAlgo_.empty();
+  return !digest_.empty() && !hashType_.empty();
 }
 
 bool DownloadContext::isPieceHashVerificationAvailable() const
 {
-  return !pieceHashAlgo_.empty() &&
+  return !pieceHashType_.empty() &&
     pieceHashes_.size() > 0 && pieceHashes_.size() == getNumPieces();
 }
 
@@ -261,19 +267,12 @@ const std::string& DownloadContext::getPieceHash(size_t index) const
   }
 }
 
-void DownloadContext::setPieceHashAlgo(const std::string& algo)
+void DownloadContext::setDigest
+(const std::string& hashType,
+ const std::string& digest)
 {
-  pieceHashAlgo_ = algo;
-}
-
-void DownloadContext::setChecksum(const std::string& checksum)
-{
-  checksum_ = checksum;
-}
-
-void DownloadContext::setChecksumHashAlgo(const std::string& algo)
-{
-  checksumHashAlgo_ = algo;
+  hashType_ = hashType;
+  digest_ = digest;
 }
 
 void DownloadContext::setBasePath(const std::string& basePath)
