@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_HANDLER_H_
-#define _D_DOWNLOAD_HANDLER_H_
+#ifndef D_DOWNLOAD_HANDLER_H
+#define D_DOWNLOAD_HANDLER_H
 
 #include "common.h"
 
@@ -44,20 +44,12 @@
 namespace aria2 {
 
 class RequestGroup;
-class Logger;
 class RequestGroupCriteria;
 
 class DownloadHandler
 {
 private:
   SharedHandle<RequestGroupCriteria> criteria_;
-
-  Logger* logger_;
-protected:
-  Logger* getLogger() const
-  {
-    return logger_;
-  }
 public:
   DownloadHandler();
 
@@ -70,4 +62,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_HANDLER_H_
+#endif // D_DOWNLOAD_HANDLER_H
