@@ -54,7 +54,7 @@ class MetadataInfo;
 
 struct DownloadResult
 {
-  gid_t gid;
+  a2_gid_t gid;
  
   std::vector<SharedHandle<FileEntry> > fileEntries;
 
@@ -68,28 +68,28 @@ struct DownloadResult
   error_code::Value result;
 
   // This field contains GIDs. See comment in
-  // RequestGroup.cc::_followedByGIDs.
-  std::vector<gid_t> followedBy;
+  // RequestGroup.cc::followedByGIDs_.
+  std::vector<a2_gid_t> followedBy;
 
   // This field contains GID. See comment in
-  // RequestGroup.cc::_belongsToGID.
-  gid_t belongsTo;
+  // RequestGroup.cc::belongsToGID_.
+  a2_gid_t belongsTo;
 
   SharedHandle<Option> option;
 
   SharedHandle<MetadataInfo> metadataInfo;
 
-  uint64_t totalLength;
+  off_t totalLength;
 
-  uint64_t completedLength;
+  off_t completedLength;
 
-  uint64_t uploadLength;
+  off_t uploadLength;
 
-  std::string bitfieldStr;
+  std::string bitfield;
 
-  std::string infoHashStr;
+  std::string infoHash;
 
-  size_t pieceLength;
+  int32_t pieceLength;
 
   size_t numPieces;
 
