@@ -39,15 +39,16 @@
 #include "RecoverableException.h"
 #include "message.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "DownloadContext.h"
-#include "ServerStatMan.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 FillRequestGroupCommand::FillRequestGroupCommand(cuid_t cuid,
                                                  DownloadEngine* e):
   Command(cuid),
-  _e(e)
+  e_(e)
 {
   setStatusRealtime();
 }
@@ -56,28 +57,30 @@ FillRequestGroupCommand::~FillRequestGroupCommand() {}
 
 bool FillRequestGroupCommand::execute()
 {
-  if(_e->isHaltRequested()) {
+  if(e_->isHaltRequested()) {
     return true;
   }
-  SharedHandle<RequestGroupMan> rgman = _e->_requestGroupMan;
+  SharedHandle<RequestGroupMan> rgman = e_->getRequestGroupMan();
   if(rgman->queueCheckRequested()) {
-    try {
-      // During adding RequestGroup,
-      // RequestGroupMan::requestQueueCheck() might be called, so
-      // first clear it here.
-      rgman->clearQueueCheck();
-      rgman->fillRequestGroupFromReserver(_e);
-    } catch(RecoverableException& ex) {
-      logger->error(EX_EXCEPTION_CAUGHT, ex);
-      // Re-request queue check to fulfill the requests of all
-      // downloads, some might come after this exception.
-      rgman->requestQueueCheck();
+    while(rgman->queueCheckRequested()) {
+      try {
+        // During adding RequestGroup,
+        // RequestGroupMan::requestQueueCheck() might be called, so
+        // first clear it here.
+        rgman->clearQueueCheck();
+        rgman->fillRequestGroupFromReserver(e_);
+      } catch(RecoverableException& ex) {
+        A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, ex);
+        // Re-request queue check to fulfill the requests of all
+        // downloads, some might come after this exception.
+        rgman->requestQueueCheck();
+      }
     }
     if(rgman->downloadFinished()) {
       return true;
     }
   }
-  _e->addRoutineCommand(this);
+  e_->addRoutineCommand(this);
   return false;
 }
 
