@@ -60,10 +60,6 @@
 
 namespace aria2 {
 
-const std::string FtpConnection::A("A");
-
-const std::string FtpConnection::I("I");
-
 FtpConnection::FtpConnection
 (cuid_t cuid,
  const SocketHandle& socket,
@@ -112,14 +108,8 @@ bool FtpConnection::sendPass()
 bool FtpConnection::sendType()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    std::string type;
-    if(option_->get(PREF_FTP_TYPE) == V_ASCII) {
-      type = FtpConnection::A;
-    } else {
-      type = FtpConnection::I;
-    }
     std::string request = "TYPE ";
-    request += type;
+    request += (option_->get(PREF_FTP_TYPE) == V_ASCII ? 'A' : 'I');
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_,request.c_str()));
@@ -145,7 +135,7 @@ bool FtpConnection::sendCwd(const std::string& dir)
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::string request = "CWD ";
-    request += util::percentDecode(dir);
+    request += util::percentDecode(dir.begin(), dir.end());
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_,request.c_str()));
@@ -159,7 +149,8 @@ bool FtpConnection::sendMdtm()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::string request = "MDTM ";
-    request += util::percentDecode(req_->getFile());
+    request +=
+      util::percentDecode(req_->getFile().begin(), req_->getFile().end());
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
@@ -173,7 +164,8 @@ bool FtpConnection::sendSize()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::string request = "SIZE ";
-    request += util::percentDecode(req_->getFile());
+    request +=
+      util::percentDecode(req_->getFile().begin(), req_->getFile().end());
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
@@ -186,7 +178,7 @@ bool FtpConnection::sendSize()
 bool FtpConnection::sendEpsv()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    static const std::string request("EPSV\r\n");
+    std::string request("EPSV\r\n");
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
     socketBuffer_.pushStr(request);
@@ -198,7 +190,7 @@ bool FtpConnection::sendEpsv()
 bool FtpConnection::sendPasv()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    static const std::string request("PASV\r\n");
+    std::string request("PASV\r\n");
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
     socketBuffer_.pushStr(request);
@@ -221,21 +213,17 @@ SharedHandle<SocketCore> FtpConnection::createServerSocket()
 bool FtpConnection::sendEprt(const SharedHandle<SocketCore>& serverSocket)
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    struct sockaddr_storage sockaddr;
+    sockaddr_union sockaddr;
     socklen_t len = sizeof(sockaddr);
     serverSocket->getAddrInfo(sockaddr, len);
-    std::pair<std::string, uint16_t> addrinfo = util::getNumericNameInfo
-      (reinterpret_cast<const struct sockaddr*>(&sockaddr), len);
-    std::string request = "EPRT ";
-    request += "|";
-    request += util::itos(sockaddr.ss_family == AF_INET?1:2);
-    request += "|";
-    request += addrinfo.first;
-    request += "|";
-    request += util::uitos(addrinfo.second);
-    request += "|\r\n";
-    A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
-                    cuid_, request.c_str()));
+    std::pair<std::string, uint16_t> addrinfo =
+      util::getNumericNameInfo(&sockaddr.sa, len);
+    std::string request =
+      fmt("EPRT |%d|%s|%u|\r\n",
+          sockaddr.storage.ss_family == AF_INET ? 1 : 2,
+          addrinfo.first.c_str(),
+          addrinfo.second);
+    A2_LOG_INFO(fmt(MSG_SENDING_REQUEST, cuid_, request.c_str()));
     socketBuffer_.pushStr(request);
   }
   socketBuffer_.send();
@@ -247,23 +235,13 @@ bool FtpConnection::sendPort(const SharedHandle<SocketCore>& serverSocket)
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::pair<std::string, uint16_t> addrinfo;
     socket_->getAddrInfo(addrinfo);
-    unsigned int ipaddr[4]; 
-    sscanf(addrinfo.first.c_str(), "%u.%u.%u.%u",
+    int ipaddr[4];
+    sscanf(addrinfo.first.c_str(), "%d.%d.%d.%d",
            &ipaddr[0], &ipaddr[1], &ipaddr[2], &ipaddr[3]);
     serverSocket->getAddrInfo(addrinfo);
-    std::string request = "PORT ";
-    request += util::uitos(ipaddr[0]);
-    request += ",";
-    request += util::uitos(ipaddr[1]);
-    request += ",";
-    request += util::uitos(ipaddr[2]);
-    request += ",";
-    request += util::uitos(ipaddr[3]);
-    request += ",";
-    request += util::uitos(addrinfo.second/256);
-    request += ",";
-    request += util::uitos(addrinfo.second%256);
-    request += "\r\n";
+    std::string request = fmt("PORT %d,%d,%d,%d,%d,%d\r\n",
+                              ipaddr[0], ipaddr[1], ipaddr[2], ipaddr[3],
+                              addrinfo.second/256, addrinfo.second%256);
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
     socketBuffer_.pushStr(request);
@@ -275,13 +253,10 @@ bool FtpConnection::sendPort(const SharedHandle<SocketCore>& serverSocket)
 bool FtpConnection::sendRest(const SharedHandle<Segment>& segment)
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    std::string request = "REST ";
-    if(!segment) {
-      request += "0";
-    } else {
-      request += util::itos(segment->getPositionToWrite());
-    }
-    request += "\r\n";    
+    std::string request =
+      fmt("REST %lld\r\n",
+          segment ?
+          static_cast<long long int>(segment->getPositionToWrite()) : 0LL);
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
     socketBuffer_.pushStr(request);
@@ -294,7 +269,8 @@ bool FtpConnection::sendRetr()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::string request = "RETR ";
-    request += util::percentDecode(req_->getFile());
+    request +=
+      util::percentDecode(req_->getFile().begin(), req_->getFile().end());
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
@@ -304,16 +280,16 @@ bool FtpConnection::sendRetr()
   return socketBuffer_.sendBufferIsEmpty();
 }
 
-unsigned int FtpConnection::getStatus(const std::string& response) const
+int FtpConnection::getStatus(const std::string& response) const
 {
-  unsigned int status;
-  // When the response is not like "%u %*s",
+  int status;
+  // When the response is not like "%d %*s",
   // we return 0.
   if(response.find_first_not_of("0123456789") != 3
      || !(response.find(" ") == 3 || response.find("-") == 3)) {
     return 0;
   }
-  if(sscanf(response.c_str(), "%u %*s", &status) == 1) {
+  if(sscanf(response.c_str(), "%d %*s", &status) == 1) {
     return status;
   } else {
     return 0;
@@ -324,8 +300,8 @@ unsigned int FtpConnection::getStatus(const std::string& response) const
 // The length includes \r\n.
 // If the whole response has not been received, then returns std::string::npos.
 std::string::size_type
-FtpConnection::findEndOfResponse(unsigned int status,
-                                 const std::string& buf) const
+FtpConnection::findEndOfResponse
+(int status, const std::string& buf) const
 {
   if(buf.size() <= 4) {
     return std::string::npos;
@@ -334,11 +310,7 @@ FtpConnection::findEndOfResponse(unsigned int status,
   if(buf.at(3) == '-') {
     // multi line response
     std::string::size_type p;
-
-    std::string endPattern = A2STR::CRLF;
-    endPattern += util::uitos(status);
-    endPattern += " ";
-    p = buf.find(endPattern);
+    p = buf.find(fmt("\r\n%d ", status));
     if(p == std::string::npos) {
       return std::string::npos;
     }
@@ -359,8 +331,7 @@ FtpConnection::findEndOfResponse(unsigned int status,
   }
 }
 
-bool FtpConnection::bulkReceiveResponse
-(std::pair<unsigned int, std::string>& response)
+bool FtpConnection::bulkReceiveResponse(std::pair<int, std::string>& response)
 {
   char buf[1024];  
   while(1) {
@@ -380,7 +351,7 @@ bool FtpConnection::bulkReceiveResponse
     }
     strbuf_.append(&buf[0], &buf[size]);
   }
-  unsigned int status;
+  int status;
   if(strbuf_.size() >= 4) {
     status = getStatus(strbuf_);
     if(status == 0) {
@@ -393,7 +364,7 @@ bool FtpConnection::bulkReceiveResponse
   std::string::size_type length;
   if((length = findEndOfResponse(status, strbuf_)) != std::string::npos) {
     response.first = status;
-    response.second = strbuf_.substr(0, length);
+    response.second.assign(strbuf_.begin(), strbuf_.begin()+length);
     A2_LOG_INFO(fmt(MSG_RECEIVE_RESPONSE,
                     cuid_,
                     response.second.c_str()));
@@ -405,9 +376,9 @@ bool FtpConnection::bulkReceiveResponse
   }
 }
 
-unsigned int FtpConnection::receiveResponse()
+int FtpConnection::receiveResponse()
 {
-  std::pair<unsigned int, std::string> response;
+  std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     return response.first;
   } else {
@@ -428,14 +399,17 @@ unsigned int FtpConnection::receiveResponse()
 # define ULONGLONG_SCANF "%Lu"
 #endif // __MINGW32__
 
-unsigned int FtpConnection::receiveSizeResponse(uint64_t& size)
+int FtpConnection::receiveSizeResponse(int64_t& size)
 {
-  std::pair<unsigned int, std::string> response;
+  std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 213) {
-      std::pair<std::string, std::string> rp;
-      util::divide(rp, response.second, ' ');
-      size = util::parseULLInt(rp.second);
+      std::pair<Sip, Sip> rp;
+      util::divide(rp, response.second.begin(), response.second.end(), ' ');
+      size = util::parseLLInt(std::string(rp.second.first, rp.second.second));
+      if(size < 0) {
+        throw DL_ABORT_EX("Size must be positive");
+      }
     }
     return response.first;
   } else {
@@ -443,10 +417,10 @@ unsigned int FtpConnection::receiveSizeResponse(uint64_t& size)
   }
 }
 
-unsigned int FtpConnection::receiveMdtmResponse(Time& time)
+int FtpConnection::receiveMdtmResponse(Time& time)
 {
   // MDTM command, specified in RFC3659.
-  std::pair<unsigned int, std::string> response;
+  std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 213) {
       char buf[15]; // YYYYMMDDhhmmss+\0, milli second part is dropped.
@@ -456,17 +430,12 @@ unsigned int FtpConnection::receiveMdtmResponse(Time& time)
         // and included strptime doesn't parse data for this format.
         struct tm tm;
         memset(&tm, 0, sizeof(tm));
-        tm.tm_sec = util::parseInt(&buf[12]);
-        buf[12] = '\0';
-        tm.tm_min = util::parseInt(&buf[10]);
-        buf[10] = '\0';
-        tm.tm_hour = util::parseInt(&buf[8]);
-        buf[8] = '\0';
-        tm.tm_mday = util::parseInt(&buf[6]);
-        buf[6] = '\0';
-        tm.tm_mon = util::parseInt(&buf[4])-1;
-        buf[4] = '\0';
-        tm.tm_year = util::parseInt(&buf[0])-1900;
+        tm.tm_sec = util::parseInt(std::string(&buf[12], &buf[14]));
+        tm.tm_min = util::parseInt(std::string(&buf[10], &buf[12]));
+        tm.tm_hour = util::parseInt(std::string(&buf[8], &buf[10]));
+        tm.tm_mday = util::parseInt(std::string(&buf[6], &buf[8]));
+        tm.tm_mon = util::parseInt(std::string(&buf[4], &buf[6]))-1;
+        tm.tm_year = util::parseInt(std::string(&buf[0], &buf[4]))-1900;
         time = Time(timegm(&tm));
       } else {
         time = Time::null();
@@ -478,9 +447,9 @@ unsigned int FtpConnection::receiveMdtmResponse(Time& time)
   }
 }
 
-unsigned int FtpConnection::receiveEpsvResponse(uint16_t& port)
+int FtpConnection::receiveEpsvResponse(uint16_t& port)
 {
-  std::pair<unsigned int, std::string> response;
+  std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 229) {
       port = 0;
@@ -490,11 +459,14 @@ unsigned int FtpConnection::receiveEpsvResponse(uint16_t& port)
          leftParen > rightParen) {
         return response.first;
       }
-      std::vector<std::string> rd;
-      util::split(response.second.substr(leftParen+1, rightParen-(leftParen+1)),
-                  std::back_inserter(rd), "|", true, true);
+      std::vector<Scip> rd;
+      util::splitIter(response.second.begin()+leftParen+1,
+                      response.second.begin()+rightParen,
+                      std::back_inserter(rd), '|', true, true);
       uint32_t portTemp = 0;
-      if(rd.size() == 5 && util::parseUIntNoThrow(portTemp, rd[3])) {
+      if(rd.size() == 5 &&
+         util::parseUIntNoThrow(portTemp,
+                                std::string(rd[3].first, rd[3].second))) {
         if(0 < portTemp  && portTemp <= UINT16_MAX) {
           port = portTemp;
         }
@@ -506,28 +478,22 @@ unsigned int FtpConnection::receiveEpsvResponse(uint16_t& port)
   }
 }
 
-unsigned int FtpConnection::receivePasvResponse
+int FtpConnection::receivePasvResponse
 (std::pair<std::string, uint16_t>& dest)
 {
-  std::pair<unsigned int, std::string> response;
+  std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 227) {
       // we assume the format of response is "227 Entering Passive
       // Mode (h1,h2,h3,h4,p1,p2)."
-      unsigned int h1, h2, h3, h4, p1, p2;
+      int h1, h2, h3, h4, p1, p2;
       std::string::size_type p = response.second.find("(");
       if(p >= 4) {
-        sscanf(response.second.substr(response.second.find("(")).c_str(),
-               "(%u,%u,%u,%u,%u,%u).",
+        sscanf(response.second.c_str()+p,
+               "(%d,%d,%d,%d,%d,%d).",
                &h1, &h2, &h3, &h4, &p1, &p2);
         // ip address
-        dest.first = util::uitos(h1);
-        dest.first += A2STR::DOT_C;
-        dest.first += util::uitos(h2);
-        dest.first += A2STR::DOT_C;
-        dest.first += util::uitos(h3);
-        dest.first += A2STR::DOT_C;
-        dest.first += util::uitos(h4);
+        dest.first = fmt("%d.%d.%d.%d", h1, h2, h3, h4);
         // port number
         dest.second = 256*p1+p2;
       } else {
@@ -540,9 +506,9 @@ unsigned int FtpConnection::receivePasvResponse
   }
 }
 
-unsigned int FtpConnection::receivePwdResponse(std::string& pwd)
+int FtpConnection::receivePwdResponse(std::string& pwd)
 {
-  std::pair<unsigned int, std::string> response;
+  std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 257) {
       std::string::size_type first;
@@ -550,7 +516,7 @@ unsigned int FtpConnection::receivePwdResponse(std::string& pwd)
 
       if((first = response.second.find("\"")) != std::string::npos &&
          (last = response.second.find("\"", ++first)) != std::string::npos) {
-        pwd = response.second.substr(first, last-first);
+        pwd.assign(response.second.begin()+first, response.second.begin()+last);
       } else {
         throw DL_ABORT_EX2(EX_INVALID_RESPONSE,
                            error_code::FTP_PROTOCOL_ERROR);
