@@ -74,6 +74,9 @@
 #include "CheckIntegrityEntry.h"
 #include "error_code.h"
 #include "SocketRecvBuffer.h"
+#ifdef ENABLE_MESSAGE_DIGEST
+# include "ChecksumCheckIntegrityEntry.h"
+#endif // ENABLE_MESSAGE_DIGEST
 
 namespace aria2 {
 
@@ -86,11 +89,13 @@ FtpNegotiationCommand::FtpNegotiationCommand
  const SocketHandle& socket,
  Seq seq,
  const std::string& baseWorkingDir):
-  AbstractCommand(cuid, req, fileEntry, requestGroup, e, socket), sequence_(seq),
+  AbstractCommand(cuid, req, fileEntry, requestGroup, e, socket),
+  sequence_(seq),
   ftp_(new FtpConnection(cuid, socket, req,
                         e->getAuthConfigFactory()->createAuthConfig
                         (req, requestGroup->getOption().get()),
-                        getOption().get()))
+                         getOption().get())),
+  pasvPort_(0)
 {
   ftp_->setBaseWorkingDir(baseWorkingDir);
   if(seq == SEQ_RECV_GREETING) {
@@ -151,7 +156,7 @@ bool FtpNegotiationCommand::recvGreeting() {
   disableWriteCheckSocket();
   setReadCheckSocket(getSocket());
 
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -174,7 +179,7 @@ bool FtpNegotiationCommand::sendUser() {
 }
 
 bool FtpNegotiationCommand::recvUser() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   switch(status) {
   case 0:
     return false;
@@ -202,7 +207,7 @@ bool FtpNegotiationCommand::sendPass() {
 }
 
 bool FtpNegotiationCommand::recvPass() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -225,7 +230,7 @@ bool FtpNegotiationCommand::sendType() {
 }
 
 bool FtpNegotiationCommand::recvType() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -251,7 +256,7 @@ bool FtpNegotiationCommand::sendPwd()
 bool FtpNegotiationCommand::recvPwd()
 {
   std::string pwd;
-  unsigned int status = ftp_->receivePwdResponse(pwd);
+  int status = ftp_->receivePwdResponse(pwd);
   if(status == 0) {
     return false;
   }
@@ -270,9 +275,9 @@ bool FtpNegotiationCommand::sendCwdPrep()
 {
   // Calling setReadCheckSocket() is needed when the socket is reused, 
   setReadCheckSocket(getSocket());
-  util::split(getRequest()->getDir(), std::back_inserter(cwdDirs_),
-              A2STR::SLASH_C);
   cwdDirs_.push_front(ftp_->getBaseWorkingDir());
+  util::split(getRequest()->getDir().begin(), getRequest()->getDir().end(),
+              std::back_inserter(cwdDirs_), '/');
   sequence_ = SEQ_SEND_CWD;
   return true;
 }
@@ -290,7 +295,7 @@ bool FtpNegotiationCommand::sendCwd()
 
 bool FtpNegotiationCommand::recvCwd()
 {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -331,7 +336,7 @@ bool FtpNegotiationCommand::sendMdtm()
 bool FtpNegotiationCommand::recvMdtm()
 {
   Time lastModifiedTime = Time::null();
-  unsigned int status = ftp_->receiveMdtmResponse(lastModifiedTime);
+  int status = ftp_->receiveMdtmResponse(lastModifiedTime);
   if(status == 0) {
     return false;
   }
@@ -362,14 +367,15 @@ bool FtpNegotiationCommand::sendSize() {
   return false;
 }
 
-bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
+bool FtpNegotiationCommand::onFileSizeDetermined(off_t totalLength)
 {
   getFileEntry()->setLength(totalLength);
   if(getFileEntry()->getPath().empty()) {
     getFileEntry()->setPath
       (util::createSafePath
        (getOption()->get(PREF_DIR),
-        util::percentDecode(getRequest()->getFile())));
+        util::percentDecode(getRequest()->getFile().begin(),
+                            getRequest()->getFile().end())));
   }
   getRequestGroup()->preDownloadProcessing();
   if(getDownloadEngine()->getRequestGroupMan()->
@@ -395,21 +401,32 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 
     if(getDownloadContext()->knowsTotalLength() &&
        getRequestGroup()->downloadFinishedByFileLength()) {
-      // TODO If metalink file does not contain size and it contains
-      // hash and file is not zero length, but remote server says the
-      // file size is 0, no hash check is performed in the current
-      // implementation. See also
+#ifdef ENABLE_MESSAGE_DIGEST
+      // TODO Known issue: if .aria2 file exists, it will not be
+      // deleted on successful verification, because .aria2 file is
+      // not loaded.  See also
       // HttpResponseCommand::handleOtherEncoding()
       getRequestGroup()->initPieceStorage();
-      getPieceStorage()->markAllPiecesDone();
-      getDownloadContext()->setChecksumVerified(true);
-      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
-      A2_LOG_NOTICE
-        (fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
-             util::itos(getRequestGroup()->getGID()).c_str(),
-             getRequestGroup()->getFirstFilePath().c_str()));
+      if(getDownloadContext()->isChecksumVerificationNeeded()) {
+        A2_LOG_DEBUG("Zero length file exists. Verify checksum.");
+        SharedHandle<ChecksumCheckIntegrityEntry> entry
+          (new ChecksumCheckIntegrityEntry(getRequestGroup()));
+        entry->initValidator();
+        getPieceStorage()->getDiskAdaptor()->openExistingFile();
+        getDownloadEngine()->getCheckIntegrityMan()->pushEntry(entry);
+        sequence_ = SEQ_EXIT;
+      } else
+#endif // ENABLE_MESSAGE_DIGEST
+        {
+          getPieceStorage()->markAllPiecesDone();
+          getDownloadContext()->setChecksumVerified(true);
+          sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+          A2_LOG_NOTICE
+            (fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+                 getRequestGroup()->getGID(),
+                 getRequestGroup()->getFirstFilePath().c_str()));
+        }
       poolConnection();
-
       return false;
     }
 
@@ -418,8 +435,25 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
     getPieceStorage()->getDiskAdaptor()->initAndOpenFile();
 
     if(getDownloadContext()->knowsTotalLength()) {
-      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
-      getPieceStorage()->markAllPiecesDone();
+      A2_LOG_DEBUG("File length becomes zero and it means download completed.");
+#ifdef ENABLE_MESSAGE_DIGEST
+      // TODO Known issue: if .aria2 file exists, it will not be
+      // deleted on successful verification, because .aria2 file is
+      // not loaded.  See also
+      // HttpResponseCommand::handleOtherEncoding()
+      if(getDownloadContext()->isChecksumVerificationNeeded()) {
+        A2_LOG_DEBUG("Verify checksum for zero-length file");
+        SharedHandle<ChecksumCheckIntegrityEntry> entry
+          (new ChecksumCheckIntegrityEntry(getRequestGroup()));
+        entry->initValidator();
+        getDownloadEngine()->getCheckIntegrityMan()->pushEntry(entry);
+        sequence_ = SEQ_EXIT;
+      } else
+#endif // ENABLE_MESSAGE_DIGEST
+        {
+          sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+          getPieceStorage()->markAllPiecesDone();
+        }
       poolConnection();
       return false;
     }
@@ -461,17 +495,15 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 }
 
 bool FtpNegotiationCommand::recvSize() {
-  uint64_t size = 0;
-  unsigned int status = ftp_->receiveSizeResponse(size);
+  int64_t size = 0;
+  int status = ftp_->receiveSizeResponse(size);
   if(status == 0) {
     return false;
   }
   if(status == 213) {
-
-    if(size > INT64_MAX) {
+    if(size > std::numeric_limits<off_t>::max()) {
       throw DL_ABORT_EX2
-        (fmt(EX_TOO_LARGE_FILE,
-             util::uitos(size, true).c_str()),
+        (fmt(EX_TOO_LARGE_FILE, static_cast<long long int>(size)),
          error_code::FTP_PROTOCOL_ERROR);
     }
     if(!getPieceStorage()) {
@@ -544,7 +576,7 @@ bool FtpNegotiationCommand::sendEprt() {
 }
 
 bool FtpNegotiationCommand::recvEprt() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -567,7 +599,7 @@ bool FtpNegotiationCommand::sendPort() {
 }
 
 bool FtpNegotiationCommand::recvPort() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -601,15 +633,12 @@ bool FtpNegotiationCommand::sendEpsv() {
 
 bool FtpNegotiationCommand::recvEpsv() {
   uint16_t port;
-  unsigned int status = ftp_->receiveEpsvResponse(port);
+  int status = ftp_->receiveEpsvResponse(port);
   if(status == 0) {
     return false;
   }
   if(status == 229) {
-    std::pair<std::string, uint16_t> peerInfo;
-    getSocket()->getPeerInfo(peerInfo);
-    peerInfo.second = port;
-    dataConnAddr_ = peerInfo;
+    pasvPort_ = port;
     return preparePasvConnect();
   } else {
     sequence_ = SEQ_SEND_PASV;
@@ -629,7 +658,7 @@ bool FtpNegotiationCommand::sendPasv() {
 
 bool FtpNegotiationCommand::recvPasv() {
   std::pair<std::string, uint16_t> dest;
-  unsigned int status = ftp_->receivePasvResponse(dest);
+  int status = ftp_->receivePasvResponse(dest);
   if(status == 0) {
     return false;
   }
@@ -637,27 +666,24 @@ bool FtpNegotiationCommand::recvPasv() {
     throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
                        error_code::FTP_PROTOCOL_ERROR);
   }
-  std::pair<std::string, uint16_t> peerInfo;
-  getSocket()->getPeerInfo(peerInfo);
-  peerInfo.second = dest.second;;
-  dataConnAddr_ = peerInfo;
+  pasvPort_ = dest.second;;
   return preparePasvConnect();
 }
 
 bool FtpNegotiationCommand::preparePasvConnect() {
-  // TODO Should we check to see that dataConnAddr_.first is not in
-  // noProxy list?
   if(isProxyDefined()) {
     sequence_ = SEQ_RESOLVE_PROXY;
     return true;
   } else {
+    std::pair<std::string, uint16_t> dataAddr;
+    getSocket()->getPeerInfo(dataAddr);
     // make a data connection to the server.
     A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
                     getCuid(),
-                    dataConnAddr_.first.c_str(),
-                    dataConnAddr_.second));
+                    dataAddr.first.c_str(),
+                    pasvPort_));
     dataSocket_.reset(new SocketCore());
-    dataSocket_->establishConnection(dataConnAddr_.first, dataConnAddr_.second);
+    dataSocket_->establishConnection(dataAddr.first, pasvPort_);
     disableReadCheckSocket();
     setWriteCheckSocket(dataSocket_);
     sequence_ = SEQ_SEND_REST_PASV;
@@ -722,8 +748,15 @@ bool FtpNegotiationCommand::sendTunnelRequest()
     httpRequest->setUserAgent(getOption()->get(PREF_USER_AGENT));
     SharedHandle<Request> req(new Request());
     // Construct fake URI in order to use HttpRequest
-    req->setUri(strconcat("ftp://", dataConnAddr_.first,
-                          A2STR::COLON_C, util::uitos(dataConnAddr_.second)));
+    std::pair<std::string, uint16_t> dataAddr;
+    uri::UriStruct us;
+    us.protocol = "ftp";
+    us.host = getRequest()->getHost();
+    us.port = pasvPort_;
+    us.ipv6LiteralAddress = getRequest()->isIPv6LiteralAddress();
+    if(!req->setUri(uri::construct(us))) {
+      throw DL_RETRY_EX("Something wrong with FTP URI");
+    }
     httpRequest->setRequest(req);
     httpRequest->setProxyRequest(createProxyRequest());
     http_->sendProxyRequest(httpRequest);
@@ -779,7 +812,7 @@ bool FtpNegotiationCommand::sendRest(const SharedHandle<Segment>& segment) {
 }
 
 bool FtpNegotiationCommand::recvRest(const SharedHandle<Segment>& segment) {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -806,7 +839,7 @@ bool FtpNegotiationCommand::sendRetr() {
 }
 
 bool FtpNegotiationCommand::recvRetr() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
