@@ -52,6 +52,8 @@ private:
   std::string internalBuf_;
 
   std::string encode(const unsigned char* in, size_t length, int flush);
+  // Not implemented
+  GZipEncoder& operator<<(char c);
 public:
   GZipEncoder();
 
@@ -68,6 +70,10 @@ public:
   // in this class.
   GZipEncoder& operator<<(const std::string& s);
 
+  // Feeds binary data in s with size length to deflater.  The
+  // deflated result is kept in this class.
+  GZipEncoder& write(const char* s, size_t length);
+
   // Feeds integer to deflator. Before passed to deflator, i is
   // converted to std::string using util::itos().  The deflated result
   // is kept in this class.
@@ -81,9 +87,6 @@ public:
     return encode(in, length, Z_NO_FLUSH);
   }
 
-  // Returns true if deflator finished.
-  bool finished();
-
   // Releases allocated resources.
   void release();
 
