@@ -2,7 +2,7 @@
 /*
  * aria2 - The high speed download utility
  *
- * Copyright (C) 2006 Tatsuhiro Tsujikawa
+ * Copyright (C) 2009 Tatsuhiro Tsujikawa
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HANDSHAKE_EXTENSION_MESSAGE_H_
-#define _D_HANDSHAKE_EXTENSION_MESSAGE_H_
+#ifndef D_HANDSHAKE_EXTENSION_MESSAGE_H
+#define D_HANDSHAKE_EXTENSION_MESSAGE_H
 
 #include "ExtensionMessage.h"
 
@@ -44,28 +44,27 @@
 namespace aria2 {
 
 class Peer;
-class Logger;
-class HandshakeExtensionMessage;
-typedef SharedHandle<HandshakeExtensionMessage> HandshakeExtensionMessageHandle;
+class DownloadContext;
 
 class HandshakeExtensionMessage:public ExtensionMessage {
 private:
-  std::string _clientVersion;
+  std::string clientVersion_;
 
-  uint16_t _tcpPort;
+  uint16_t tcpPort_;
 
-  std::map<std::string, uint8_t> _extensions;
+  size_t metadataSize_;
 
-  SharedHandle<Peer> _peer;
+  std::map<std::string, uint8_t> extensions_;
 
-  Logger* _logger;
+  SharedHandle<DownloadContext> dctx_;
 
+  SharedHandle<Peer> peer_;
 public:
   HandshakeExtensionMessage();
 
   virtual ~HandshakeExtensionMessage();
 
-  virtual std::string getBencodedData();
+  virtual std::string getPayload();
 
   virtual uint8_t getExtensionMessageID()
   {
@@ -85,44 +84,59 @@ public:
 
   void setClientVersion(const std::string& version)
   {
-    _clientVersion = version;
+    clientVersion_ = version;
   }
 
   const std::string& getClientVersion() const
   {
-    return _clientVersion;
+    return clientVersion_;
   }
 
   void setTCPPort(uint16_t port)
   {
-    _tcpPort = port;
+    tcpPort_ = port;
   }
 
   uint16_t getTCPPort() const
   {
-    return _tcpPort;
+    return tcpPort_;
+  }
+
+  size_t getMetadataSize()
+  {
+    return metadataSize_;
+  }
+
+  void setMetadataSize(size_t size)
+  {
+    metadataSize_ = size;
+  }
+
+  void setDownloadContext(const SharedHandle<DownloadContext>& dctx)
+  {
+    dctx_ = dctx;
   }
 
   void setExtension(const std::string& name, uint8_t id)
   {
-    _extensions[name] = id;
+    extensions_[name] = id;
   }
 
   void setExtensions(const Extensions& extensions)
   {
-    _extensions = extensions;
+    extensions_ = extensions;
   }
 
   uint8_t getExtensionMessageID(const std::string& name) const;
 
   void setPeer(const SharedHandle<Peer>& peer);
 
-  static HandshakeExtensionMessageHandle create(const unsigned char* data,
-						size_t dataLength);
+  static SharedHandle<HandshakeExtensionMessage>
+  create(const unsigned char* data, size_t dataLength);
 };
 
 typedef SharedHandle<HandshakeExtensionMessage> HandshakeExtensionMessageHandle;
 
 } // namespace aria2
 
-#endif // _D_HANDSHAKE_EXTENSION_MESSAGE_H_
+#endif // D_HANDSHAKE_EXTENSION_MESSAGE_H
