@@ -87,12 +87,12 @@ bool HttpDownloadCommand::prepareForNextSegment() {
     getDownloadEngine()->addCommand(command);
     return true;
   } else {
+    const std::string& streamFilterName = getStreamFilter()->getName();
     if(getRequest()->isPipeliningEnabled() ||
        (getRequest()->isKeepAliveEnabled() &&
         (
          // Make sure that all filters are finished to pool socket
-         (!util::endsWith(getStreamFilter()->getName(),
-                          SinkStreamFilter::NAME) &&
+         (!util::endsWith(streamFilterName, SinkStreamFilter::NAME) &&
           getStreamFilter()->finished()) ||
          getRequestEndOffset() ==
          getFileEntry()->gtoloff(getSegments().front()->getPositionToWrite())
