@@ -34,7 +34,6 @@
 /* copyright --> */
 #include "HttpHeaderProcessor.h"
 
-#include <sstream>
 #include <vector>
 
 #include "HttpHeader.h"
@@ -60,7 +59,7 @@ HttpHeaderProcessor::~HttpHeaderProcessor() {}
 void HttpHeaderProcessor::update(const unsigned char* data, size_t length)
 {
   checkHeaderLimit(length);
-  buf_ += std::string(&data[0], &data[length]);
+  buf_.append(&data[0], &data[length]);
 }
 
 void HttpHeaderProcessor::update(const std::string& data)
@@ -113,16 +112,20 @@ SharedHandle<HttpHeader> HttpHeaderProcessor::getHttpResponseHeader()
     throw DL_RETRY_EX(EX_NO_STATUS_HEADER);
   }
   int32_t statusCode;
-  if(!util::parseIntNoThrow(statusCode, buf_.substr(9, 3))) {
+  if(!util::parseIntNoThrow(statusCode,
+                            std::string(buf_.begin()+9, buf_.begin()+12))) {
     throw DL_RETRY_EX("Status code could not be parsed as integer.");
   }
   HttpHeaderHandle httpHeader(new HttpHeader());
-  httpHeader->setVersion(buf_.substr(0, 8));
+  httpHeader->setVersion(buf_.begin(), buf_.begin()+8);
   httpHeader->setStatusCode(statusCode);
-  std::istringstream strm(buf_);
   // TODO 1st line(HTTP/1.1 200...) is also send to HttpHeader, but it should
   // not.
-  httpHeader->fill(strm);
+  if((delimpos = buf_.find("\r\n\r\n")) == std::string::npos &&
+     (delimpos = buf_.find("\n\n")) == std::string::npos) {
+    delimpos = buf_.size();
+  }
+  httpHeader->fill(buf_.begin(), buf_.begin()+delimpos);
   return httpHeader;
 }
 
@@ -137,18 +140,22 @@ SharedHandle<HttpHeader> HttpHeaderProcessor::getHttpRequestHeader()
      delimpos < 14) {
     throw DL_RETRY_EX(EX_NO_STATUS_HEADER);
   }
-  std::vector<std::string> firstLine;
-  util::split(buf_.substr(0, delimpos), std::back_inserter(firstLine)," ",true);
+  std::vector<Scip> firstLine;
+  util::splitIter(buf_.begin(), buf_.begin()+delimpos,
+                  std::back_inserter(firstLine), ' ', true);
   if(firstLine.size() != 3) {
     throw DL_ABORT_EX2("Malformed HTTP request header.",
                        error_code::HTTP_PROTOCOL_ERROR);
   }
   SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpHeader->setMethod(firstLine[0]);
-  httpHeader->setRequestPath(firstLine[1]);
-  httpHeader->setVersion(firstLine[2]);
-  std::istringstream strm(buf_.substr(delimpos));
-  httpHeader->fill(strm);
+  httpHeader->setMethod(firstLine[0].first, firstLine[0].second);
+  httpHeader->setRequestPath(firstLine[1].first, firstLine[1].second);
+  httpHeader->setVersion(firstLine[2].first, firstLine[2].second);
+  if((delimpos = buf_.find("\r\n\r\n")) == std::string::npos &&
+     (delimpos = buf_.find("\n\n")) == std::string::npos) {
+    delimpos = buf_.size();
+  }
+  httpHeader->fill(buf_.begin(), buf_.begin()+delimpos);
   return httpHeader;
 }
 
