@@ -32,22 +32,24 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_HEADER_PROCESSOR_H_
-#define _D_HTTP_HEADER_PROCESSOR_H_
+#ifndef D_HTTP_HEADER_PROCESSOR_H
+#define D_HTTP_HEADER_PROCESSOR_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <utility>
 #include <string>
 
+#include "SharedHandle.h"
+
 namespace aria2 {
 
 class HttpHeader;
 
 class HttpHeaderProcessor {
 private:
-  std::string _buf;
-  size_t _limit;
+  std::string buf_;
+  size_t limit_;
 
   void checkHeaderLimit(size_t incomingLength);
 
@@ -84,7 +86,7 @@ public:
 
   void setHeaderLimit(size_t limit)
   {
-    _limit = limit;
+    limit_ = limit;
   }
 };
 
@@ -92,4 +94,4 @@ typedef SharedHandle<HttpHeaderProcessor> HttpHeaderProcessorHandle;
 
 } // namespace aria2
 
-#endif // _D_HTTP_HEADER_PROCESSOR_H_
+#endif // D_HTTP_HEADER_PROCESSOR_H
