@@ -97,9 +97,7 @@ bool HttpListenCommand::bindPort(uint16_t port)
     e_->deleteSocketForReadCheck(serverSocket_, this);
   }
   serverSocket_.reset(new SocketCore());
-  A2_LOG_INFO(fmt("CUID#%lld - Setting up HttpListenCommand for IPv%d",
-                  getCuid(),
-                  family_ == AF_INET?4:6));
+  const int ipv = (family_ == AF_INET) ? 4 : 6;
   try {
     int flags = 0;
     if(e_->getOption()->getAsBool(PREF_RPC_LISTEN_ALL)) {
@@ -111,16 +109,10 @@ bool HttpListenCommand::bindPort(uint16_t port)
     A2_LOG_INFO(fmt(MSG_LISTENING_PORT,
                     getCuid(), port));
     e_->addSocketForReadCheck(serverSocket_, this);
+    A2_LOG_NOTICE(fmt(_("IPv%d RPC: listening to port %u"), ipv, port));
     return true;
   } catch(RecoverableException& e) {
-    A2_LOG_ERROR(fmt("Failed to setup RPC server for IPv%d",
-                     family_ == AF_INET?4:6));
-    A2_LOG_ERROR_EX(fmt(MSG_BIND_FAILURE,
-                        getCuid(), port),
-                    e);
-    if(serverSocket_) {
-      e_->deleteSocketForReadCheck(serverSocket_, this);
-    }
+    A2_LOG_ERROR_EX(fmt("IPv%d RPC: failed to bind port %u", ipv, port), e);
     serverSocket_->closeConnection();
   }
   return false;
