@@ -58,6 +58,7 @@
 #include "Logger.h"
 #include "LogFactory.h"
 #include "fmt.h"
+#include "SocketRecvBuffer.h"
 
 namespace aria2 {
 
@@ -69,7 +70,8 @@ HttpRequestCommand::HttpRequestCommand
  const HttpConnectionHandle& httpConnection,
  DownloadEngine* e,
  const SocketHandle& s)
-  : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
+  : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s,
+                    httpConnection->getSocketRecvBuffer()),
     httpConnection_(httpConnection)
 {
   setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
@@ -84,7 +86,7 @@ SharedHandle<HttpRequest>
 createHttpRequest(const SharedHandle<Request>& req,
                   const SharedHandle<FileEntry>& fileEntry,
                   const SharedHandle<Segment>& segment,
-                  uint64_t totalLength,
+                  off_t totalLength,
                   const SharedHandle<Option>& option,
                   const RequestGroup* rg,
                   const SharedHandle<CookieStorage>& cookieStorage,
@@ -159,7 +161,8 @@ bool HttpRequestCommand::executeInternal() {
             getFileEntry()->setPath
               (util::createSafePath
                (getOption()->get(PREF_DIR),
-                util::percentDecode(getRequest()->getFile())));
+                util::percentDecode(getRequest()->getFile().begin(),
+                                    getRequest()->getFile().end())));
           }
           File ctrlfile(getFileEntry()->getPath()+
                         DefaultBtProgressInfoFile::getSuffix());
