@@ -60,7 +60,9 @@ size_t IndexBtMessage::getMessageLength()
 
 std::string IndexBtMessage::toString() const
 {
-  return strconcat(getName(), " index=", util::itos(index_));
+  return fmt("%s index=%lu",
+             getName().c_str(),
+             static_cast<unsigned long>(index_));
 }
 
 } // namespace aria2
