@@ -50,7 +50,6 @@
 #include "Option.h"
 #include "MSEHandshake.h"
 #include "ARC4Encryptor.h"
-#include "ARC4Decryptor.h"
 #include "RequestGroup.h"
 #include "DownloadContext.h"
 #include "bittorrent_helper.h"
@@ -157,11 +156,10 @@ bool InitiatorMSEHandshakeCommand::executeInternal() {
           peerConnection->enableEncryption(mseHandshake_->getEncryptor(),
                                            mseHandshake_->getDecryptor());
           size_t buflen = mseHandshake_->getBufferLength();
-          array_ptr<unsigned char> buffer(new unsigned char[buflen]);
-          mseHandshake_->getDecryptor()->decrypt(buffer, buflen,
+          mseHandshake_->getDecryptor()->encrypt(buflen,
                                                  mseHandshake_->getBuffer(),
-                                                 buflen);
-          peerConnection->presetBuffer(buffer, buflen);
+                                                 mseHandshake_->getBuffer());
+          peerConnection->presetBuffer(mseHandshake_->getBuffer(), buflen);
         } else {
           peerConnection->presetBuffer(mseHandshake_->getBuffer(),
                                        mseHandshake_->getBufferLength());
