@@ -53,8 +53,6 @@ private:
   off_t currentOffset_;
 
   SharedHandle<MessageDigest> ctx_;
-
-  unsigned char* buffer_;
 public:
   IteratableChecksumValidator(const SharedHandle<DownloadContext>& dctx,
                               const SharedHandle<PieceStorage>& pieceStorage);
@@ -72,7 +70,7 @@ public:
     return currentOffset_;
   }
 
-  virtual uint64_t getTotalLength() const;
+  virtual off_t getTotalLength() const;
 };
 
 typedef SharedHandle<IteratableChecksumValidator> IteratableChecksumValidatorHandle;
