@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_LIBSSL_TLS_CONTEXT_H_
-#define _D_LIBSSL_TLS_CONTEXT_H_
+#ifndef D_LIBSSL_TLS_CONTEXT_H
+#define D_LIBSSL_TLS_CONTEXT_H
 
 #include "common.h"
 
@@ -45,17 +45,13 @@
 
 namespace aria2 {
 
-class Logger;
-
 class TLSContext {
 private:
-  SSL_CTX* _sslCtx;
+  SSL_CTX* sslCtx_;
 
-  bool _good;
+  bool good_;
 
-  bool _peerVerificationEnabled;
-
-  Logger* _logger;
+  bool peerVerificationEnabled_;
 public:
   TLSContext();
 
@@ -74,7 +70,7 @@ public:
 
   SSL_CTX* getSSLCtx() const
   {
-    return _sslCtx;
+    return sslCtx_;
   }
   
   void enablePeerVerification();
@@ -83,11 +79,11 @@ public:
 
   bool peerVerificationEnabled() const
   {
-    return _peerVerificationEnabled;
+    return peerVerificationEnabled_;
   }
 
 };
 
 } // namespace aria2
 
-#endif // _D_LIBSSL_TLS_CONTEXT_H_
+#endif // D_LIBSSL_TLS_CONTEXT_H
