@@ -38,11 +38,13 @@
 #include "common.h"
 
 #include <string>
-#include <fstream>
+
+#include "SharedHandle.h"
 
 namespace aria2 {
 
 class Exception;
+class OutputFile;
 
 class Logger {
 public:
@@ -55,11 +57,20 @@ public:
   };
 private:
   LEVEL logLevel_;
-  std::ofstream file_;
+  SharedHandle<OutputFile> fpp_;
   int stdoutField_;
   // Don't allow copying
   Logger(const Logger&);
   Logger& operator=(const Logger&);
+
+  void writeLog
+  (Logger::LEVEL level,
+   const char* sourceFile,
+   int lineNum,
+   const char* msg,
+   const std::string& trace,
+   bool toStream,
+   bool toConsole);
 public:
   Logger();
 
