@@ -51,10 +51,6 @@
 
 namespace aria2 {
 
-unsigned int LpdReceiveMessageCommand::numInstance_ = 0;
-
-LpdReceiveMessageCommand* LpdReceiveMessageCommand::instance_ = 0;
-
 LpdReceiveMessageCommand::LpdReceiveMessageCommand
 (cuid_t cuid,
  const SharedHandle<LpdMessageReceiver>& receiver,
@@ -64,16 +60,11 @@ LpdReceiveMessageCommand::LpdReceiveMessageCommand
     e_(e)
 {
   e_->addSocketForReadCheck(receiver_->getSocket(), this);
-  ++numInstance_;
 }
 
 LpdReceiveMessageCommand::~LpdReceiveMessageCommand()
 {
   e_->deleteSocketForReadCheck(receiver_->getSocket(), this);
-  --numInstance_;
-  if(numInstance_ == 0) {
-    instance_ = 0;
-  }
 }
 
 bool LpdReceiveMessageCommand::execute()
@@ -86,16 +77,15 @@ bool LpdReceiveMessageCommand::execute()
     if(!m) {
       break;
     }
-    if(!m->getPeer()) {
+    if(!m->peer) {
       // bad message
       continue;
     }
     SharedHandle<BtRegistry> reg = e_->getBtRegistry();
-    SharedHandle<DownloadContext> dctx =
-      reg->getDownloadContext(m->getInfoHash());
+    SharedHandle<DownloadContext> dctx = reg->getDownloadContext(m->infoHash);
     if(!dctx) {
       A2_LOG_DEBUG(fmt("Download Context is null for infohash=%s.",
-                       util::toHex(m->getInfoHash()).c_str()));
+                       util::toHex(m->infoHash).c_str()));
       continue;
     }
     if(bittorrent::getTorrentAttrs(dctx)->privateTorrent) {
@@ -104,11 +94,11 @@ bool LpdReceiveMessageCommand::execute()
     }
     RequestGroup* group = dctx->getOwnerRequestGroup();
     assert(group);
-    BtObject btobj = reg->get(group->getGID());
-    assert(!btobj.isNull());
-    SharedHandle<PeerStorage> peerStorage = btobj.peerStorage_;
+    const SharedHandle<BtObject>& btobj = reg->get(group->getGID());
+    assert(btobj);
+    const SharedHandle<PeerStorage>& peerStorage = btobj->peerStorage;
     assert(peerStorage);
-    SharedHandle<Peer> peer = m->getPeer();
+    SharedHandle<Peer> peer = m->peer;
     if(peerStorage->addPeer(peer)) {
       A2_LOG_DEBUG(fmt("LPD peer %s:%u local=%d added.",
                        peer->getIPAddress().c_str(), peer->getPort(),
@@ -123,23 +113,4 @@ bool LpdReceiveMessageCommand::execute()
   return false;
 }
 
-LpdReceiveMessageCommand*
-LpdReceiveMessageCommand::getInstance
-(DownloadEngine* e, const SharedHandle<LpdMessageReceiver>& receiver)
-{
-  if(numInstance_ == 0) {
-    instance_ = new LpdReceiveMessageCommand(e->newCUID(), receiver, e);
-  }
-  return instance_;
-}
-
-LpdReceiveMessageCommand* LpdReceiveMessageCommand::getInstance()
-{
-  if(numInstance_ == 0) {
-    return 0;
-  } else {
-    return instance_;
-  }
-}
-
 } // namespace aria2
