@@ -46,9 +46,8 @@
 #include "a2netcompat.h"
 #include "DHKeyExchange.h"
 #include "ARC4Encryptor.h"
-#include "ARC4Decryptor.h"
 #include "MessageDigest.h"
-#include "MessageDigestHelper.h"
+#include "message_digest_helper.h"
 #include "SimpleRandomizer.h"
 #include "util.h"
 #include "DownloadContext.h"
@@ -56,14 +55,20 @@
 #include "Option.h"
 #include "fmt.h"
 #include "bittorrent_helper.h"
+#include "array_fun.h"
 
 namespace aria2 {
 
-const unsigned char* MSEHandshake::PRIME = reinterpret_cast<const unsigned char*>("FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E088A67CC74020BBEA63B139B22514A08798E3404DDEF9519B3CD3A431B302B0A6DF25F14374FE1356D6D51C245E485B576625E7EC6F44C42E9A63A36210000000000090563");
+namespace {
 
-const unsigned char* MSEHandshake::GENERATOR = reinterpret_cast<const unsigned char*>("2");
+const size_t MAX_PAD_LENGTH = 512;
+const size_t CRYPTO_BITFIELD_LENGTH = 4;
+const unsigned char VC[] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 
-const unsigned char MSEHandshake::VC[] = { 0, 0, 0, 0, 0, 0, 0, 0 };
+const unsigned char* PRIME = reinterpret_cast<const unsigned char*>("FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E088A67CC74020BBEA63B139B22514A08798E3404DDEF9519B3CD3A431B302B0A6DF25F14374FE1356D6D51C245E485B576625E7EC6F44C42E9A63A36210000000000090563");
+const unsigned char* GENERATOR = reinterpret_cast<const unsigned char*>("2");
+
+} // namespace
 
 MSEHandshake::MSEHandshake
 (cuid_t cuid,
@@ -123,14 +128,15 @@ void MSEHandshake::sendPublicKey()
 {
   A2_LOG_DEBUG(fmt("CUID#%lld - Sending public key.",
                    cuid_));
-  unsigned char buffer[KEY_LENGTH+MAX_PAD_LENGTH];
-  dh_->getPublicKey(buffer, KEY_LENGTH);
+  unsigned char* buf = new unsigned char[KEY_LENGTH+MAX_PAD_LENGTH];
+  array_ptr<unsigned char> bufp(buf);
+  dh_->getPublicKey(buf, KEY_LENGTH);
 
   size_t padLength =
     SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
-  dh_->generateNonce(buffer+KEY_LENGTH, padLength);
-  socketBuffer_.pushStr(std::string(&buffer[0],
-                                    &buffer[KEY_LENGTH+padLength]));
+  dh_->generateNonce(buf+KEY_LENGTH, padLength);
+  socketBuffer_.pushBytes(buf, KEY_LENGTH+padLength);
+  bufp.reset(0);
 }
 
 void MSEHandshake::read()
@@ -187,47 +193,39 @@ void MSEHandshake::initCipher(const unsigned char* infoHash)
   
   unsigned char localCipherKey[20];
   sha1_->reset();
-  MessageDigestHelper::digest(localCipherKey, sizeof(localCipherKey),
-                              sha1_, s, sizeof(s));
+  message_digest::digest(localCipherKey, sizeof(localCipherKey),
+                         sha1_, s, sizeof(s));
   encryptor_.reset(new ARC4Encryptor());
   encryptor_->init(localCipherKey, sizeof(localCipherKey));
 
   unsigned char peerCipherKey[20];
   memcpy(s, initiator_?"keyB":"keyA", 4);
   sha1_->reset();
-  MessageDigestHelper::digest(peerCipherKey, sizeof(peerCipherKey),
-                              sha1_, s, sizeof(s));
-  decryptor_.reset(new ARC4Decryptor());
+  message_digest::digest(peerCipherKey, sizeof(peerCipherKey),
+                         sha1_, s, sizeof(s));
+  decryptor_.reset(new ARC4Encryptor());
   decryptor_->init(peerCipherKey, sizeof(peerCipherKey));
 
   // discard first 1024 bytes ARC4 output.
-  unsigned char from[1024];
-  unsigned char to[1024];
-  encryptor_->encrypt(to, 1024, from, 1024);
-  decryptor_->decrypt(to, 1024, from, 1024);
+  unsigned char garbage[1024];
+  encryptor_->encrypt(1024, garbage, garbage);
+  decryptor_->encrypt(1024, garbage, garbage);
 
   if(initiator_) {
     ARC4Encryptor enc;
     enc.init(peerCipherKey, sizeof(peerCipherKey));
     // discard first 1024 bytes ARC4 output.
-    enc.encrypt(to, 1024, from, 1024);
-    enc.encrypt(initiatorVCMarker_, sizeof(initiatorVCMarker_), VC, sizeof(VC));
+    enc.encrypt(1024, garbage, garbage);
+    enc.encrypt(VC_LENGTH, initiatorVCMarker_, VC);
   }
 }
 
-void MSEHandshake::encryptAndSendData(const unsigned char* data, size_t length)
+// Given data is pushed to socketBuffer_ and data will be deleted by
+// socketBuffer_.
+void MSEHandshake::encryptAndSendData(unsigned char* data, size_t length)
 {
-  unsigned char temp[4096];
-  const unsigned char* dptr = data;
-  size_t s;
-  size_t r = length;
-  while(r > 0) {
-    s = std::min(r, sizeof(temp));
-    encryptor_->encrypt(temp, s, dptr, s);
-    socketBuffer_.pushStr(std::string(&temp[0], &temp[s]));
-    dptr += s;
-    r -= s;
-  }
+  encryptor_->encrypt(length, data, data);
+  socketBuffer_.pushBytes(data, length);
 }
 
 void MSEHandshake::createReq1Hash(unsigned char* md) const
@@ -236,7 +234,7 @@ void MSEHandshake::createReq1Hash(unsigned char* md) const
   memcpy(buffer, "req1", 4);
   memcpy(buffer+4, secret_, KEY_LENGTH);
   sha1_->reset();
-  MessageDigestHelper::digest(md, 20, sha1_, buffer, 4+KEY_LENGTH);
+  message_digest::digest(md, 20, sha1_, buffer, 4+KEY_LENGTH);
 }
 
 void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoHash) const
@@ -246,14 +244,14 @@ void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoH
   memcpy(x+4, infoHash, INFO_HASH_LENGTH);
   unsigned char xh[20];
   sha1_->reset();
-  MessageDigestHelper::digest(xh, sizeof(xh), sha1_, x, sizeof(x));
+  message_digest::digest(xh, sizeof(xh), sha1_, x, sizeof(x));
 
   unsigned char y[4+96];
   memcpy(y, "req3", 4);
   memcpy(y+4, secret_, KEY_LENGTH);
   unsigned char yh[20];
   sha1_->reset();
-  MessageDigestHelper::digest(yh, sizeof(yh), sha1_, y, sizeof(y));
+  message_digest::digest(yh, sizeof(yh), sha1_, y, sizeof(y));
   
   for(size_t i = 0; i < 20; ++i) {
     md[i] = xh[i]^yh[i];
@@ -263,59 +261,64 @@ void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoH
 uint16_t MSEHandshake::decodeLength16(const unsigned char* buffer)
 {
   uint16_t be;
-  decryptor_->decrypt(reinterpret_cast<unsigned char*>(&be),
-                      sizeof(be),
-                      buffer, sizeof(be));
+  decryptor_->encrypt(sizeof(be),
+                      reinterpret_cast<unsigned char*>(&be),
+                      buffer);
   return ntohs(be);
 }
 
 void MSEHandshake::sendInitiatorStep2()
 {
   A2_LOG_DEBUG(fmt("CUID#%lld - Sending negotiation step2.", cuid_));
-  unsigned char md[20];
+  // Assuming no exception
+  unsigned char* md = new unsigned char[20];
   createReq1Hash(md);
-  socketBuffer_.pushStr(std::string(&md[0], &md[sizeof(md)]));
+  socketBuffer_.pushBytes(md, 20);
+  // Assuming no exception
+  md = new unsigned char[20];
   createReq23Hash(md, infoHash_);
-  socketBuffer_.pushStr(std::string(&md[0], &md[sizeof(md)]));
-
+  socketBuffer_.pushBytes(md, 20);
   // buffer is filled in this order:
   //   VC(VC_LENGTH bytes),
   //   crypto_provide(CRYPTO_BITFIELD_LENGTH bytes),
-  //   len(padC)(2bytes),
-  //   padC(len(padC)bytes <= MAX_PAD_LENGTH),
-  //   len(IA)(2bytes)
-  unsigned char buffer[VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH+2];
-
+  //   len(padC)(2 bytes),
+  //   padC(len(padC) bytes <= MAX_PAD_LENGTH),
+  //   len(IA)(2 bytes)
+  unsigned char* buffer = new unsigned char
+    [40+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH+2];
+  array_ptr<unsigned char> bufp(buffer);
+  unsigned char* ptr = buffer;
   // VC
-  memcpy(buffer, VC, sizeof(VC));
+  memcpy(ptr, VC, sizeof(VC));
+  ptr += sizeof(VC);
   // crypto_provide
-  unsigned char cryptoProvide[CRYPTO_BITFIELD_LENGTH];
-  memset(cryptoProvide, 0, sizeof(cryptoProvide));
+  memset(ptr, 0, CRYPTO_BITFIELD_LENGTH);
   if(option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-    cryptoProvide[3] = CRYPTO_PLAIN_TEXT;
+    ptr[3] = CRYPTO_PLAIN_TEXT;
   }
-  cryptoProvide[3] |= CRYPTO_ARC4;
-  memcpy(buffer+VC_LENGTH, cryptoProvide, sizeof(cryptoProvide));
-
+  ptr[3] |= CRYPTO_ARC4;
+  ptr += CRYPTO_BITFIELD_LENGTH;
   // len(padC)
-  uint16_t padCLength = SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
+  uint16_t padCLength =
+    SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
   {
     uint16_t padCLengthBE = htons(padCLength);
-    memcpy(buffer+VC_LENGTH+CRYPTO_BITFIELD_LENGTH, &padCLengthBE,
-           sizeof(padCLengthBE));
+    memcpy(ptr, &padCLengthBE, sizeof(padCLengthBE));
   }
+  ptr += 2;
   // padC
-  memset(buffer+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2, 0, padCLength);
+  memset(ptr, 0, padCLength);
+  ptr += padCLength;
   // len(IA)
   // currently, IA is zero-length.
   uint16_t iaLength = 0;
   {
     uint16_t iaLengthBE = htons(iaLength);
-    memcpy(buffer+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+padCLength,
-           &iaLengthBE,sizeof(iaLengthBE));
+    memcpy(ptr, &iaLengthBE, sizeof(iaLengthBE));
   }
-  encryptAndSendData(buffer,
-                     VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+padCLength+2);
+  ptr += 2;
+  encryptAndSendData(buffer, ptr-buffer);
+  bufp.reset(0);
 }
 
 // This function reads exactly until the end of VC marker is reached.
@@ -323,9 +326,10 @@ bool MSEHandshake::findInitiatorVCMarker()
 {
   // 616 is synchronization point of initiator
   // find vc
-  std::string buf(&rbuf_[0], &rbuf_[rbufLength_]);
-  std::string vc(&initiatorVCMarker_[0], &initiatorVCMarker_[VC_LENGTH]);
-  if((markerIndex_ = buf.find(vc)) == std::string::npos) {
+  unsigned char* ptr =
+    std::search(&rbuf_[0], &rbuf_[rbufLength_],
+                &initiatorVCMarker_[0], &initiatorVCMarker_[VC_LENGTH]);
+  if(ptr == &rbuf_[rbufLength_]) {
     if(616-KEY_LENGTH <= rbufLength_) {
       throw DL_ABORT_EX("Failed to find VC marker.");
     } else {
@@ -333,6 +337,7 @@ bool MSEHandshake::findInitiatorVCMarker()
       return false;
     }
   }
+  markerIndex_ = ptr-rbuf_;
   A2_LOG_DEBUG(fmt("CUID#%lld - VC marker found at %lu",
                    cuid_,
                    static_cast<unsigned long>(markerIndex_)));
@@ -350,26 +355,22 @@ bool MSEHandshake::receiveInitiatorCryptoSelectAndPadDLength()
   }
   //verifyCryptoSelect
   unsigned char* rbufptr = rbuf_;
-  {
-    unsigned char cryptoSelect[CRYPTO_BITFIELD_LENGTH];
-    decryptor_->decrypt(cryptoSelect, sizeof(cryptoSelect),
-                        rbufptr, sizeof(cryptoSelect));
-    if(cryptoSelect[3]&CRYPTO_PLAIN_TEXT &&
-       option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-      A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers plaintext.",
-                       cuid_));
-      negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
-    }
-    if(cryptoSelect[3]&CRYPTO_ARC4) {
-      A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers ARC4",
-                       cuid_));
-      negotiatedCryptoType_ = CRYPTO_ARC4;
-    }
-    if(negotiatedCryptoType_ == CRYPTO_NONE) {
-      throw DL_ABORT_EX
-        (fmt("CUID#%lld - No supported crypto type selected.",
-             cuid_));
-    }
+  decryptor_->encrypt(CRYPTO_BITFIELD_LENGTH, rbufptr, rbufptr);
+  if(rbufptr[3]&CRYPTO_PLAIN_TEXT &&
+     option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
+    A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers plaintext.",
+                     cuid_));
+    negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
+  }
+  if(rbufptr[3]&CRYPTO_ARC4) {
+    A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers ARC4",
+                     cuid_));
+    negotiatedCryptoType_ = CRYPTO_ARC4;
+  }
+  if(negotiatedCryptoType_ == CRYPTO_NONE) {
+    throw DL_ABORT_EX
+      (fmt("CUID#%lld - No supported crypto type selected.",
+           cuid_));
   }
   // padD length
   rbufptr += CRYPTO_BITFIELD_LENGTH;
@@ -388,8 +389,7 @@ bool MSEHandshake::receivePad()
   if(padLength_ == 0) {
     return true;
   }
-  unsigned char temp[MAX_PAD_LENGTH];
-  decryptor_->decrypt(temp, padLength_, rbuf_, padLength_);
+  decryptor_->encrypt(padLength_, rbuf_, rbuf_);
   // shift rbuf_
   shiftBuffer(padLength_);
   return true;
@@ -399,11 +399,11 @@ bool MSEHandshake::findReceiverHashMarker()
 {
   // 628 is synchronization limit of receiver.
   // find hash('req1', S), S is secret_.
-  std::string buf(&rbuf_[0], &rbuf_[rbufLength_]);
   unsigned char md[20];
   createReq1Hash(md);
-  std::string req1(&md[0], &md[sizeof(md)]);
-  if((markerIndex_ = buf.find(req1)) == std::string::npos) {
+  unsigned char* ptr = std::search
+    (&rbuf_[0], &rbuf_[rbufLength_], &md[0], &md[sizeof(md)]);
+  if(ptr == &rbuf_[rbufLength_]) {
     if(628-KEY_LENGTH <= rbufLength_) {
       throw DL_ABORT_EX("Failed to find hash marker.");
     } else {
@@ -411,6 +411,7 @@ bool MSEHandshake::findReceiverHashMarker()
       return false;
     }
   }
+  markerIndex_ = ptr-rbuf_;
   A2_LOG_DEBUG(fmt("CUID#%lld - Hash marker found at %lu.",
                    cuid_,
                    static_cast<unsigned long>(markerIndex_)));
@@ -454,27 +455,23 @@ bool MSEHandshake::receiveReceiverHashAndPadCLength
   verifyVC(rbufptr);
   // decrypt crypto_provide
   rbufptr += VC_LENGTH;
-  {
-    unsigned char cryptoProvide[CRYPTO_BITFIELD_LENGTH];
-    decryptor_->decrypt(cryptoProvide, sizeof(cryptoProvide),
-                        rbufptr, sizeof(cryptoProvide));
-    // TODO choose the crypto type based on the preference.
-    // For now, choose ARC4.
-    if(cryptoProvide[3]&CRYPTO_PLAIN_TEXT &&
-       option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-      A2_LOG_DEBUG(fmt("CUID#%lld - peer provides plaintext.",
-                       cuid_));
-      negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
-    } else if(cryptoProvide[3]&CRYPTO_ARC4) {
-      A2_LOG_DEBUG(fmt("CUID#%lld - peer provides ARC4.",
-                       cuid_));
-      negotiatedCryptoType_ = CRYPTO_ARC4;
-    }
-    if(negotiatedCryptoType_ == CRYPTO_NONE) {
-      throw DL_ABORT_EX
-        (fmt("CUID#%lld - No supported crypto type provided.",
-             cuid_));
-    }
+  decryptor_->encrypt(CRYPTO_BITFIELD_LENGTH, rbufptr, rbufptr);
+  // TODO choose the crypto type based on the preference.
+  // For now, choose ARC4.
+  if(rbufptr[3]&CRYPTO_PLAIN_TEXT &&
+     option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
+    A2_LOG_DEBUG(fmt("CUID#%lld - peer provides plaintext.",
+                     cuid_));
+    negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
+  } else if(rbufptr[3]&CRYPTO_ARC4) {
+    A2_LOG_DEBUG(fmt("CUID#%lld - peer provides ARC4.",
+                     cuid_));
+    negotiatedCryptoType_ = CRYPTO_ARC4;
+  }
+  if(negotiatedCryptoType_ == CRYPTO_NONE) {
+    throw DL_ABORT_EX
+      (fmt("CUID#%lld - No supported crypto type provided.",
+           cuid_));
   }
   // decrypt PadC length
   rbufptr += CRYPTO_BITFIELD_LENGTH;
@@ -511,7 +508,7 @@ bool MSEHandshake::receiveReceiverIA()
   }
   delete [] ia_;
   ia_ = new unsigned char[iaLength_];
-  decryptor_->decrypt(ia_, iaLength_, rbuf_, iaLength_);
+  decryptor_->encrypt(iaLength_, ia_, rbuf_);
   A2_LOG_DEBUG(fmt("CUID#%lld - IA received.", cuid_));
   // shift rbuf_
   shiftBuffer(iaLength_);
@@ -525,24 +522,28 @@ void MSEHandshake::sendReceiverStep2()
   //   cryptoSelect(CRYPTO_BITFIELD_LENGTH bytes),
   //   len(padD)(2bytes),
   //   padD(len(padD)bytes <= MAX_PAD_LENGTH)
-  unsigned char buffer[VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH];
+  unsigned char* buffer = new unsigned char
+    [VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH];
+  array_ptr<unsigned char> bufp(buffer);
+  unsigned char* ptr = buffer;
   // VC
-  memcpy(buffer, VC, sizeof(VC));
+  memcpy(ptr, VC, sizeof(VC));
+  ptr += sizeof(VC);
   // crypto_select
-  unsigned char cryptoSelect[CRYPTO_BITFIELD_LENGTH];
-  memset(cryptoSelect, 0, sizeof(cryptoSelect));
-  cryptoSelect[3] = negotiatedCryptoType_;
-  memcpy(buffer+VC_LENGTH, cryptoSelect, sizeof(cryptoSelect));
+  memset(ptr, 0, CRYPTO_BITFIELD_LENGTH);
+  ptr[3] = negotiatedCryptoType_;
+  ptr += CRYPTO_BITFIELD_LENGTH;
   // len(padD)
-  uint16_t padDLength = SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
-  {
-    uint16_t padDLengthBE = htons(padDLength);
-    memcpy(buffer+VC_LENGTH+CRYPTO_BITFIELD_LENGTH, &padDLengthBE,
-           sizeof(padDLengthBE));
-  }
+  uint16_t padDLength =
+    SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
+  uint16_t padDLengthBE = htons(padDLength);
+  memcpy(ptr, &padDLengthBE, sizeof(padDLengthBE));
+  ptr += sizeof(padDLengthBE);
   // padD, all zeroed
-  memset(buffer+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2, 0, padDLength);
-  encryptAndSendData(buffer, VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+padDLength);
+  memset(ptr, 0, padDLength);
+  ptr += padDLength;
+  encryptAndSendData(buffer, ptr-buffer);
+  bufp.reset(0);
 }
 
 uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf, const char* padName)
@@ -559,14 +560,13 @@ uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf, const cha
   return padLength;
 }
 
-void MSEHandshake::verifyVC(const unsigned char* vcbuf)
+void MSEHandshake::verifyVC(unsigned char* vcbuf)
 {
   A2_LOG_DEBUG(fmt("CUID#%lld - Verifying VC.", cuid_));
-  unsigned char vc[VC_LENGTH];
-  decryptor_->decrypt(vc, sizeof(vc), vcbuf, sizeof(vc));
-  if(memcmp(VC, vc, sizeof(VC)) != 0) {
+  decryptor_->encrypt(VC_LENGTH, vcbuf, vcbuf);
+  if(memcmp(VC, vcbuf, VC_LENGTH) != 0) {
     throw DL_ABORT_EX
-      (fmt("Invalid VC: %s", util::toHex(vc, VC_LENGTH).c_str()));
+      (fmt("Invalid VC: %s", util::toHex(vcbuf, VC_LENGTH).c_str()));
   }
 }
 
