@@ -50,7 +50,6 @@ class Option;
 class SocketCore;
 class DHKeyExchange;
 class ARC4Encryptor;
-class ARC4Decryptor;
 class DownloadContext;
 class MessageDigest;
 
@@ -69,13 +68,13 @@ public:
   };
 
 private:
-  static const size_t PRIME_BITS = 768;
-  static const size_t KEY_LENGTH = (PRIME_BITS+7)/8;
-  static const size_t VC_LENGTH = 8;
+  static const size_t PRIME_BITS = 768U;
+  static const size_t KEY_LENGTH = (PRIME_BITS+7U)/8U;
+  static const size_t VC_LENGTH = 8U;
   // The largest buffering occurs when receiver receives step2
   // handshake.  We believe that IA is less than or equal to
   // BtHandshakeMessage::MESSAGE_LENGTH
-  static const size_t MAX_BUFFER_LENGTH = 636;
+  static const size_t MAX_BUFFER_LENGTH = 636U;
 
   cuid_t cuid_;
   SharedHandle<SocketCore> socket_;
@@ -90,7 +89,7 @@ private:
   CRYPTO_TYPE negotiatedCryptoType_;
   DHKeyExchange* dh_;
   SharedHandle<ARC4Encryptor> encryptor_;
-  SharedHandle<ARC4Decryptor> decryptor_;
+  SharedHandle<ARC4Encryptor> decryptor_;
   unsigned char infoHash_[INFO_HASH_LENGTH];
   unsigned char secret_[KEY_LENGTH];
   bool initiator_;
@@ -101,7 +100,7 @@ private:
   unsigned char* ia_;
   SharedHandle<MessageDigest> sha1_;
 
-  void encryptAndSendData(const unsigned char* data, size_t length);
+  void encryptAndSendData(unsigned char* data, size_t length);
 
   void createReq1Hash(unsigned char* md) const;
 
@@ -117,7 +116,7 @@ private:
   uint16_t verifyPadLength(const unsigned char* padlenbuf,
                            const char* padName);
 
-  void verifyVC(const unsigned char* vcbuf);
+  void verifyVC(unsigned char* vcbuf);
 
   void verifyReq1Hash(const unsigned char* req1buf);
 
@@ -203,7 +202,7 @@ public:
     return encryptor_;
   }
 
-  const SharedHandle<ARC4Decryptor>& getDecryptor() const
+  const SharedHandle<ARC4Encryptor>& getDecryptor() const
   {
     return decryptor_;
   }
@@ -213,6 +212,11 @@ public:
     return rbuf_;
   }
 
+  unsigned char* getBuffer()
+  {
+    return rbuf_;
+  }
+
   size_t getBufferLength() const
   {
     return rbufLength_;
