@@ -33,9 +33,13 @@
  */
 /* copyright --> */
 #include "MetalinkPostDownloadHandler.h"
+
+#include <deque>
+
 #include "RequestGroup.h"
 #include "Metalink2RequestGroup.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "DiskAdaptor.h"
 #include "PieceStorage.h"
 #include "DownloadHandlerConstants.h"
@@ -44,6 +48,9 @@
 #include "prefs.h"
 #include "Option.h"
 #include "DownloadContext.h"
+#include "download_helper.h"
+#include "fmt.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
@@ -60,23 +67,52 @@ MetalinkPostDownloadHandler::MetalinkPostDownloadHandler()
 
 MetalinkPostDownloadHandler::~MetalinkPostDownloadHandler() {}
 
+namespace {
+const std::string& getBaseUri(RequestGroup* requestGroup)
+{
+  const SharedHandle<DownloadContext>& dctx =
+    requestGroup->getDownloadContext();
+  if(dctx->getFileEntries().empty()) {
+    return A2STR::NIL;
+  } else {
+    // TODO Check download result for each URI
+    const SharedHandle<FileEntry>& entry = dctx->getFirstFileEntry();
+    const std::deque<std::string>& spentUris = entry->getSpentUris();
+    if(spentUris.empty()) {
+      const std::deque<std::string>& remainingUris = entry->getRemainingUris();
+      if(remainingUris.empty()) {
+        return A2STR::NIL;
+      } else {
+        return remainingUris.front();
+      }
+    } else {
+      return spentUris.back();
+    }
+  }
+}
+} // namespace
+
 void MetalinkPostDownloadHandler::getNextRequestGroups
-(std::deque<SharedHandle<RequestGroup> >& groups,
+(std::vector<SharedHandle<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
-  if(_logger->debug()) {
-    _logger->debug("Generating RequestGroups for Metalink file %s",
-                   requestGroup->getFirstFilePath().c_str());
-  }
+  A2_LOG_DEBUG(fmt("Generating RequestGroups for Metalink file %s",
+                   requestGroup->getFirstFilePath().c_str()));
   SharedHandle<DiskAdaptor> diskAdaptor =
     requestGroup->getPieceStorage()->getDiskAdaptor();
   try {
     diskAdaptor->openExistingFile();
     //requestOption.put(PREF_DIR, requestGroup->getDownloadContext()->getDir());
-    std::deque<SharedHandle<RequestGroup> > newRgs;
+    const std::string& baseUri = getBaseUri(requestGroup);
+    std::vector<SharedHandle<RequestGroup> > newRgs;
     Metalink2RequestGroup().generate(newRgs, diskAdaptor,
-                                     requestGroup->getOption());
+                                     requestGroup->getOption(), baseUri);
     requestGroup->followedBy(newRgs.begin(), newRgs.end());
+    SharedHandle<MetadataInfo> mi =
+      createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
+    if(mi) {
+      setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
+    }
     groups.insert(groups.end(), newRgs.begin(), newRgs.end());
     diskAdaptor->closeFile();
   } catch(Exception& e) {
