@@ -56,7 +56,6 @@ namespace aria2 {
 DiskWriterEntry::DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry)
   : fileEntry_(fileEntry),
     open_(false),
-    directIO_(false),
     needsFileAllocation_(false)
 {}
 
@@ -69,9 +68,6 @@ void DiskWriterEntry::initAndOpenFile()
 {
   if(diskWriter_) {
     diskWriter_->initAndOpenFile(fileEntry_->getLength());
-    if(directIO_) {
-      diskWriter_->enableDirectIO();
-    }
     open_ = true;
   }
 }
@@ -80,9 +76,6 @@ void DiskWriterEntry::openFile()
 {
   if(diskWriter_) {
     diskWriter_->openFile(fileEntry_->getLength());
-    if(directIO_) {
-      diskWriter_->enableDirectIO();
-    }
     open_ = true;
   }
 }
@@ -91,9 +84,6 @@ void DiskWriterEntry::openExistingFile()
 {
   if(diskWriter_) {
     diskWriter_->openExistingFile(fileEntry_->getLength());
-    if(directIO_) {
-      diskWriter_->enableDirectIO();
-    }
     open_ = true;
   }
 }
@@ -111,7 +101,7 @@ bool DiskWriterEntry::fileExists()
   return fileEntry_->exists();
 }
 
-uint64_t DiskWriterEntry::size() const
+off_t DiskWriterEntry::size() const
 {
   return File(getFilePath()).size();
 }
@@ -126,26 +116,9 @@ bool DiskWriterEntry::operator<(const DiskWriterEntry& entry) const
   return *fileEntry_ < *entry.fileEntry_;
 }
 
-void DiskWriterEntry::enableDirectIO()
-{
-  if(open_) {
-    diskWriter_->enableDirectIO();
-  }
-  directIO_ = true;
-}
-
-void DiskWriterEntry::disableDirectIO()
-{
-  if(open_) {
-    diskWriter_->disableDirectIO();
-  }
-  directIO_ = false;
-}
-
 MultiDiskAdaptor::MultiDiskAdaptor()
   : pieceLength_(0),
     maxOpenFiles_(DEFAULT_MAX_OPEN_FILES),
-    directIOAllowed_(false),
     readOnly_(false)
 {}
 
@@ -196,8 +169,7 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
               itr-1; true; --i) {
           const SharedHandle<FileEntry>& fileEntry = (*i)->getFileEntry();
           if(pieceStartOffset <= fileEntry->getOffset() ||
-             (uint64_t)pieceStartOffset <
-             fileEntry->getOffset()+fileEntry->getLength()) {
+             pieceStartOffset < fileEntry->getLastOffset()) {
             (*i)->needsFileAllocation(true);
           } else {
             break;
@@ -223,14 +195,16 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
         for(; itr != eoi &&
               (!(*itr)->getFileEntry()->isRequested() ||
                (*itr)->getFileEntry()->getLength() == 0); ++itr) {
-          A2_LOG_DEBUG(fmt("file=%s, offset=%lld",
-                           (*itr)->getFileEntry()->getPath().c_str(),
-                           static_cast<long long int>
-                           ((*itr)->getFileEntry()->getOffset())));
+          A2_LOG_DEBUG
+            (fmt("file=%s, offset=%lld",
+                 (*itr)->getFileEntry()->getPath().c_str(),
+                 static_cast<long long int>
+                 ((*itr)->getFileEntry()->getOffset())));
           if((*itr)->getFileEntry()->getOffset() <
              static_cast<off_t>(lastPieceStartOffset+pieceLength_)) {
-            A2_LOG_DEBUG(fmt("%s needs diskwriter",
-                             (*itr)->getFileEntry()->getPath().c_str()));
+            A2_LOG_DEBUG
+              (fmt("%s needs diskwriter",
+                   (*itr)->getFileEntry()->getPath().c_str()));
             dwreq[(*itr)->getFileEntry()->getPath()] = true;
           } else {
             break;
@@ -253,9 +227,6 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
       A2_LOG_DEBUG(fmt("Creating DiskWriter for filename=%s",
                        (*i)->getFilePath().c_str()));
       (*i)->setDiskWriter(dwFactory.newDiskWriter((*i)->getFilePath()));
-      if(directIOAllowed_) {
-        (*i)->getDiskWriter()->allowDirectIO();
-      }
       if(readOnly_) {
         (*i)->getDiskWriter()->enableReadOnly();
       }
@@ -270,7 +241,7 @@ void MultiDiskAdaptor::openIfNot
     //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache MISS. offset=%s",
     //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
  
-    size_t numOpened = openedDiskWriterEntries_.size();
+    int numOpened = openedDiskWriterEntries_.size();
     (entry.get()->*open)();
     if(numOpened >= maxOpenFiles_) {
       // Cache is full. 
@@ -334,22 +305,19 @@ namespace {
 bool isInRange(const DiskWriterEntryHandle entry, off_t offset)
 {
   return entry->getFileEntry()->getOffset() <= offset &&
-    (uint64_t)offset <
-    entry->getFileEntry()->getOffset()+entry->getFileEntry()->getLength();
+    offset < entry->getFileEntry()->getLastOffset();
 }
 } // namespace
 
 namespace {
-size_t calculateLength(const DiskWriterEntryHandle entry,
-                       off_t fileOffset, size_t rem)
+ssize_t calculateLength(const DiskWriterEntryHandle entry,
+                        off_t fileOffset, ssize_t rem)
 {
-  size_t length;
-  if(entry->getFileEntry()->getLength() < (uint64_t)fileOffset+rem) {
-    length = entry->getFileEntry()->getLength()-fileOffset;
+  if(entry->getFileEntry()->getLength() < fileOffset+rem) {
+    return entry->getFileEntry()->getLength()-fileOffset;
   } else {
-    length = rem;
+    return rem;
   }
-  return length;
 }
 } // namespace
 
@@ -376,8 +344,7 @@ DiskWriterEntries::const_iterator findFirstDiskWriterEntry
   // In case when offset is out-of-range
   if(!isInRange(*first, offset)) {
     throw DL_ABORT_EX
-      (fmt(EX_FILE_OFFSET_OUT_OF_RANGE,
-           util::itos(offset, true).c_str()));
+      (fmt(EX_FILE_OFFSET_OUT_OF_RANGE, static_cast<long long int>(offset)));
   }
   return first;
 }
@@ -388,8 +355,8 @@ void throwOnDiskWriterNotOpened(const SharedHandle<DiskWriterEntry>& e,
                                 off_t offset)
 {
   throw DL_ABORT_EX
-    (fmt("DiskWriter for offset=%s, filename=%s is not opened.",
-         util::itos(offset).c_str(),
+    (fmt("DiskWriter for offset=%lld, filename=%s is not opened.",
+         static_cast<long long int>(offset),
          e->getFilePath().c_str()));  
 }
 } // namespace
@@ -400,11 +367,11 @@ void MultiDiskAdaptor::writeData(const unsigned char* data, size_t len,
   DiskWriterEntries::const_iterator first =
     findFirstDiskWriterEntry(diskWriterEntries_, offset);
 
-  size_t rem = len;
+  ssize_t rem = len;
   off_t fileOffset = offset-(*first)->getFileEntry()->getOffset();
   for(DiskWriterEntries::const_iterator i = first,
         eoi = diskWriterEntries_.end(); i != eoi; ++i) {
-    size_t writeLength = calculateLength(*i, fileOffset, rem);
+    ssize_t writeLength = calculateLength(*i, fileOffset, rem);
 
     openIfNot(*i, &DiskWriterEntry::openFile);
 
@@ -427,12 +394,12 @@ ssize_t MultiDiskAdaptor::readData
   DiskWriterEntries::const_iterator first =
     findFirstDiskWriterEntry(diskWriterEntries_, offset);
 
-  size_t rem = len;
-  size_t totalReadLength = 0;
+  ssize_t rem = len;
+  ssize_t totalReadLength = 0;
   off_t fileOffset = offset-(*first)->getFileEntry()->getOffset();
   for(DiskWriterEntries::const_iterator i = first,
         eoi = diskWriterEntries_.end(); i != eoi; ++i) {
-    size_t readLength = calculateLength(*i, fileOffset, rem);
+    ssize_t readLength = calculateLength(*i, fileOffset, rem);
 
     openIfNot(*i, &DiskWriterEntry::openFile);
 
@@ -458,9 +425,9 @@ bool MultiDiskAdaptor::fileExists()
     getFileEntries().end();
 }
 
-uint64_t MultiDiskAdaptor::size()
+off_t MultiDiskAdaptor::size()
 {
-  uint64_t size = 0;
+  off_t size = 0;
   for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
         getFileEntries().begin(), eoi = getFileEntries().end(); i != eoi; ++i) {
     size += File((*i)->getPath()).size();
@@ -474,18 +441,6 @@ SharedHandle<FileAllocationIterator> MultiDiskAdaptor::fileAllocationIterator()
     (new MultiFileAllocationIterator(this));
 }
 
-void MultiDiskAdaptor::enableDirectIO()
-{
-  std::for_each(diskWriterEntries_.begin(), diskWriterEntries_.end(),
-                mem_fun_sh(&DiskWriterEntry::enableDirectIO));
-}
-
-void MultiDiskAdaptor::disableDirectIO()
-{
-  std::for_each(diskWriterEntries_.begin(), diskWriterEntries_.end(),
-                mem_fun_sh(&DiskWriterEntry::disableDirectIO));
-}
-
 void MultiDiskAdaptor::enableReadOnly()
 {
   readOnly_ = true;
@@ -501,16 +456,16 @@ void MultiDiskAdaptor::cutTrailingGarbage()
   for(std::vector<SharedHandle<DiskWriterEntry> >::const_iterator i =
         diskWriterEntries_.begin(), eoi = diskWriterEntries_.end();
       i != eoi; ++i) {
-    uint64_t length = (*i)->getFileEntry()->getLength();
+    off_t length = (*i)->getFileEntry()->getLength();
     if(File((*i)->getFilePath()).size() > length) {
-      // We need open file before calling DiskWriter::truncate(uint64_t)
+      // We need open file before calling DiskWriter::truncate(off_t)
       openIfNot(*i, &DiskWriterEntry::openFile);
       (*i)->getDiskWriter()->truncate(length);
     }
   }
 }
 
-void MultiDiskAdaptor::setMaxOpenFiles(size_t maxOpenFiles)
+void MultiDiskAdaptor::setMaxOpenFiles(int maxOpenFiles)
 {
   maxOpenFiles_ = maxOpenFiles;
 }
