@@ -48,7 +48,6 @@ private:
   SharedHandle<FileEntry> fileEntry_;
   SharedHandle<DiskWriter> diskWriter_;
   bool open_;
-  bool directIO_;
   bool needsFileAllocation_;
 public:
   DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry);
@@ -70,7 +69,7 @@ public:
 
   bool fileExists();
 
-  uint64_t size() const;
+  off_t size() const;
 
   const SharedHandle<FileEntry>& getFileEntry() const
   {
@@ -86,16 +85,6 @@ public:
 
   bool operator<(const DiskWriterEntry& entry) const;
 
-  // Set directIO_ to true.
-  // Additionally, if diskWriter is opened, diskWriter->enableDirectIO() is
-  // called.
-  void enableDirectIO();
-
-  // Set directIO_ to false.
-  // Additionally, if diskWriter is opened, diskWriter->disableDirectIO() is
-  // called.
-  void disableDirectIO();
-
   bool needsFileAllocation() const
   {
     return needsFileAllocation_;
@@ -115,14 +104,12 @@ typedef std::vector<DiskWriterEntryHandle> DiskWriterEntries;
 class MultiDiskAdaptor : public DiskAdaptor {
   friend class MultiFileAllocationIterator;
 private:
-  size_t pieceLength_;
+  int32_t pieceLength_;
   DiskWriterEntries diskWriterEntries_;
 
   std::vector<SharedHandle<DiskWriterEntry> > openedDiskWriterEntries_;
 
-  size_t maxOpenFiles_;
-
-  bool directIOAllowed_;
+  int maxOpenFiles_;
 
   bool readOnly_;
 
@@ -131,7 +118,7 @@ private:
   void openIfNot(const SharedHandle<DiskWriterEntry>& entry,
                  void (DiskWriterEntry::*f)());
  
-  static const size_t DEFAULT_MAX_OPEN_FILES = 100;
+  static const int DEFAULT_MAX_OPEN_FILES = 100;
 
 public:
   MultiDiskAdaptor();
@@ -152,37 +139,28 @@ public:
 
   virtual bool fileExists();
 
-  virtual uint64_t size();
+  virtual off_t size();
 
   virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
 
-  virtual void enableDirectIO();
-
-  virtual void disableDirectIO();
-
   virtual void enableReadOnly();
 
   virtual void disableReadOnly();
 
   virtual bool isReadOnlyEnabled() const { return readOnly_; }
 
-  void setPieceLength(size_t pieceLength)
+  void setPieceLength(int32_t pieceLength)
   {
     pieceLength_ = pieceLength;
   }
 
-  size_t getPieceLength() const {
+  int32_t getPieceLength() const {
     return pieceLength_;
   }
 
-  void allowDirectIO()
-  {
-    directIOAllowed_ = true;
-  }
-
   virtual void cutTrailingGarbage();
 
-  void setMaxOpenFiles(size_t maxOpenFiles);
+  void setMaxOpenFiles(int maxOpenFiles);
 
   virtual size_t utime(const Time& actime, const Time& modtime);
 
