@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_INITIATE_CONNECTION_H_
-#define _D_PEER_INITIATE_CONNECTION_H_
+#ifndef D_PEER_INITIATE_CONNECTION_H
+#define D_PEER_INITIATE_CONNECTION_H
 
 #include "PeerAbstractCommand.h"
 
@@ -46,15 +46,15 @@ class PieceStorage;
 
 class PeerInitiateConnectionCommand : public PeerAbstractCommand {
 private:
-  RequestGroup* _requestGroup;
+  RequestGroup* requestGroup_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  bool _mseHandshakeEnabled;
+  bool mseHandshakeEnabled_;
 protected:
   virtual bool executeInternal();
   virtual bool prepareForNextPeer(time_t wait);
@@ -78,4 +78,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_PEER_INITIATE_CONNECTION_H_
+#endif // D_PEER_INITIATE_CONNECTION_H
