@@ -75,6 +75,7 @@
 #include "bittorrent_helper.h"
 #include "UTMetadataRequestFactory.h"
 #include "UTMetadataRequestTracker.h"
+#include "BtRegistry.h"
 
 namespace aria2 {
 
@@ -169,6 +170,14 @@ PeerInteractionCommand::PeerInteractionCommand
       getDownloadEngine()->setNoWait(true);
     }
   }
+  // If the number of pieces gets bigger, the length of Bitfield
+  // message payload exceeds the initial buffer capacity of
+  // PeerConnection, which is MAX_PAYLOAD_LEN.  We expand buffer as
+  // necessary so that PeerConnection can receive the Bitfield
+  // message.
+  size_t bitfieldPayloadSize =
+    1+(requestGroup_->getDownloadContext()->getNumPieces()+7)/8;
+  peerConnection->reserveBuffer(bitfieldPayloadSize);
 
   SharedHandle<DefaultBtMessageDispatcher> dispatcher
     (new DefaultBtMessageDispatcher());
@@ -194,6 +203,7 @@ PeerInteractionCommand::PeerInteractionCommand
   reqFactory->setPieceStorage(pieceStorage);
   reqFactory->setBtMessageDispatcher(dispatcher.get());
   reqFactory->setBtMessageFactory(factory.get());
+  reqFactory->setCuid(cuid);
 
   DefaultBtInteractiveHandle btInteractive
     (new DefaultBtInteractive(requestGroup_->getDownloadContext(), getPeer()));
@@ -233,6 +243,7 @@ PeerInteractionCommand::PeerInteractionCommand
   }
   btInteractive->setUTMetadataRequestFactory(utMetadataRequestFactory);
   btInteractive->setUTMetadataRequestTracker(utMetadataRequestTracker);
+  btInteractive->setTcpPort(e->getBtRegistry()->getTcpPort());
   if(metadataGetMode) {
     btInteractive->enableMetadataGetMode();
   }
@@ -248,6 +259,7 @@ PeerInteractionCommand::PeerInteractionCommand
   extensionMessageFactory->setBtMessageFactory(factory.get());
 
   if(metadataGetMode) {
+    utMetadataRequestFactory->setCuid(cuid);
     utMetadataRequestFactory->setDownloadContext
       (requestGroup_->getDownloadContext());
     utMetadataRequestFactory->setBtMessageDispatcher(dispatcher.get());
