@@ -37,7 +37,7 @@
 
 #include "Command.h"
 #include "SharedHandle.h"
-#include "IntSequence.h"
+#include "SegList.h"
 
 namespace aria2 {
 
@@ -49,13 +49,6 @@ private:
   DownloadEngine* e_;
   int family_;
   SharedHandle<SocketCore> socket_;
-  unsigned int lowestSpeedLimit_;
-
-  static unsigned int numInstance_;
-
-  static PeerListenCommand* instance_;
-
-  static PeerListenCommand* instance6_;
 public:
   PeerListenCommand(cuid_t cuid, DownloadEngine* e, int family);
 
@@ -67,23 +60,10 @@ public:
    * Binds port. If successful, the binded port number is assinged to port and
    * returns true, otherwise port is undefined and returns false.
    */
-  bool bindPort(uint16_t& port, IntSequence& seq);
+  bool bindPort(uint16_t& port, SegList<int>& seq);
 
   // Returns binded port
   uint16_t getPort() const;
-
-  void setLowestSpeedLimit(unsigned int speed)
-  {
-    lowestSpeedLimit_ = speed;
-  }
-
-  static PeerListenCommand* getInstance(DownloadEngine* e, int family);
-
-  static unsigned int getNumInstance()
-  {
-    return numInstance_;
-  }
-  
 };
 
 } // namespace aria2 
