@@ -100,7 +100,7 @@ bool PeerReceiveHandshakeCommand::executeInternal()
   if(peerConnection_->getBufferLength() >= 48) {
     const unsigned char* data = peerConnection_->getBuffer();
     // check info_hash
-    std::string infoHash = std::string(&data[28], &data[28+INFO_HASH_LENGTH]);
+    std::string infoHash(&data[28], &data[28+INFO_HASH_LENGTH]);
 
     SharedHandle<DownloadContext> downloadContext =
       getDownloadEngine()->getBtRegistry()->getDownloadContext(infoHash);
@@ -109,11 +109,12 @@ bool PeerReceiveHandshakeCommand::executeInternal()
         (fmt("Unknown info hash %s",
              util::toHex(infoHash).c_str()));
     }
-    BtObject btObject = getDownloadEngine()->getBtRegistry()->get
+    const SharedHandle<BtObject>& btObject =
+      getDownloadEngine()->getBtRegistry()->get
       (downloadContext->getOwnerRequestGroup()->getGID());
-    SharedHandle<BtRuntime> btRuntime = btObject.btRuntime_;
-    SharedHandle<PieceStorage> pieceStorage = btObject.pieceStorage_;
-    SharedHandle<PeerStorage> peerStorage = btObject.peerStorage_;
+    const SharedHandle<BtRuntime>& btRuntime = btObject->btRuntime;
+    const SharedHandle<PieceStorage>& pieceStorage = btObject->pieceStorage;
+    const SharedHandle<PeerStorage>& peerStorage = btObject->peerStorage;
     if(!btRuntime->ready()) {
       throw DL_ABORT_EX
         (fmt("Unknown info hash %s",
@@ -126,9 +127,9 @@ bool PeerReceiveHandshakeCommand::executeInternal()
     }
     TransferStat tstat =
       downloadContext->getOwnerRequestGroup()->calculateStat();
-    const unsigned int maxDownloadLimit =
+    const int maxDownloadLimit =
       downloadContext->getOwnerRequestGroup()->getMaxDownloadSpeedLimit();
-    unsigned int thresholdSpeed =
+    int thresholdSpeed =
       downloadContext->getOwnerRequestGroup()->
       getOption()->getAsInt(PREF_BT_REQUEST_PEER_SPEED_LIMIT);
     if(maxDownloadLimit > 0) {
@@ -155,7 +156,7 @@ bool PeerReceiveHandshakeCommand::executeInternal()
         getDownloadEngine()->addCommand(command);
         A2_LOG_DEBUG(fmt(MSG_INCOMING_PEER_CONNECTION,
                          getCuid(),
-                         util::itos(getPeer()->usedBy()).c_str()));
+                         getPeer()->usedBy()));
       }
     }
     return true;
