@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PIECE_H_
-#define _D_PIECE_H_
+#ifndef D_PIECE_H
+#define D_PIECE_H
 
 #include "common.h"
 
@@ -42,6 +42,7 @@
 #include <string>
 
 #include "SharedHandle.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -49,41 +50,41 @@ class BitfieldMan;
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-class MessageDigestContext;
+class MessageDigest;
 
 #endif // ENABLE_MESSAGE_DIGEST
 
 class Piece {
 private:
   size_t index_;
-  size_t length_;
-  size_t blockLength_;
+  int32_t length_;
+  int32_t blockLength_;
   BitfieldMan* bitfield_;
-
+  std::vector<cuid_t> users_;
+  bool usedBySegment_;
 #ifdef ENABLE_MESSAGE_DIGEST
 
-  size_t nextBegin_;
+  int32_t nextBegin_;
 
-  std::string hashAlgo_;
+  std::string hashType_;
 
-  SharedHandle<MessageDigestContext> mdctx_;
+  SharedHandle<MessageDigest> mdctx_;
 
 #endif // ENABLE_MESSAGE_DIGEST
 
+  Piece(const Piece& piece);
+
+  Piece& operator=(const Piece& piece);  
 public:
 
-  static const size_t BLOCK_LENGTH  = 16*1024;
+  static const int32_t BLOCK_LENGTH  = 16*1024;
 
   Piece();
 
-  Piece(size_t index, size_t length, size_t blockLength = BLOCK_LENGTH);
-
-  Piece(const Piece& piece);
+  Piece(size_t index, int32_t length, int32_t blockLength = BLOCK_LENGTH);
 
   ~Piece();
 
-  Piece& operator=(const Piece& piece);
-  
   bool operator==(const Piece& piece) const
   {
     return index_ == piece.index_;
@@ -124,17 +125,17 @@ public:
 
   size_t countBlock() const;
 
-  size_t getBlockLength(size_t index) const;
+  int32_t getBlockLength(size_t index) const;
 
-  size_t getBlockLength() const;
+  int32_t getBlockLength() const;
 
   size_t getIndex() const { return index_; }
 
   void setIndex(size_t index) { index_ = index; }
 
-  size_t getLength() const { return length_; }
+  int32_t getLength() const { return length_; }
 
-  void setLength(size_t length) { length_ = length; }
+  void setLength(int32_t length) { length_ = length; }
 
   const unsigned char* getBitfield() const;
 
@@ -150,24 +151,24 @@ public:
   bool isBlockUsed(size_t index) const;
 
   // Calculates completed length
-  size_t getCompletedLength();
+  int32_t getCompletedLength();
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-  void setHashAlgo(const std::string& algo);
+  void setHashType(const std::string& hashType);
 
   // Updates hash value. This function compares begin and private variable
   // nextBegin_ and only when they are equal, hash is updated eating data and
   // returns true. Otherwise returns false.
-  bool updateHash(uint32_t begin, const unsigned char* data, size_t dataLength);
+  bool updateHash(int32_t begin, const unsigned char* data, size_t dataLength);
 
   bool isHashCalculated() const;
 
-  // Returns hash value in ASCII hexadecimal form, which is calculated
+  // Returns raw hash value, not hex digest, which is calculated
   // by updateHash().  Please note that this function returns hash
   // value only once. Second invocation without updateHash() returns
   // empty string.
-  std::string getHashString();
+  std::string getDigest();
 
   void destroyHashContext();
 
@@ -176,9 +177,25 @@ public:
   /**
    * Loses current bitfield state.
    */
-  void reconfigure(size_t length);
+  void reconfigure(int32_t length);
+
+  void addUser(cuid_t cuid);
+  void removeUser(cuid_t cuid);
+  bool getUsed() const
+  {
+    return !users_.empty();
+  }
+  bool usedBy(cuid_t cuid) const;
+  bool getUsedBySegment() const
+  {
+    return usedBySegment_;
+  }
+  void setUsedBySegment(bool f)
+  {
+    usedBySegment_ = f;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_PIECE_H_
+#endif // D_PIECE_H
