@@ -39,94 +39,94 @@
 namespace aria2 {
 
 PiecedSegment::PiecedSegment
-(size_t pieceLength, const SharedHandle<Piece>& piece):
-  _pieceLength(pieceLength), _overflowLength(0), _piece(piece)
+(int32_t pieceLength, const SharedHandle<Piece>& piece)
+  : piece_(piece),
+    pieceLength_(pieceLength)
 {
   size_t index;
-  bool t = _piece->getFirstMissingBlockIndexWithoutLock(index);
+  bool t = piece_->getFirstMissingBlockIndexWithoutLock(index);
   assert(t);
-  _writtenLength = index*_piece->getBlockLength();
+  writtenLength_ = index*piece_->getBlockLength();
 }
 
 PiecedSegment::~PiecedSegment() {}
 
 bool PiecedSegment::complete() const
 {
-  return _piece->pieceComplete();
+  return piece_->pieceComplete();
 }
 
 size_t PiecedSegment::getIndex() const
 {
-  return _piece->getIndex();
+  return piece_->getIndex();
 }
 
 off_t PiecedSegment::getPosition() const
 {
-  return ((off_t)_piece->getIndex())*_pieceLength;
+  return ((off_t)piece_->getIndex())*pieceLength_;
 }
 
 off_t PiecedSegment::getPositionToWrite() const
 {
-  return getPosition()+_writtenLength;
+  return getPosition()+writtenLength_;
 }
 
-size_t PiecedSegment::getLength() const
+int32_t PiecedSegment::getLength() const
 {
-  return _piece->getLength();
+  return piece_->getLength();
 }
 
-void PiecedSegment::updateWrittenLength(size_t bytes)
+void PiecedSegment::updateWrittenLength(int32_t bytes)
 {
-  size_t newWrittenLength = _writtenLength+bytes;
-  if(newWrittenLength > _piece->getLength()) {
-    _overflowLength = newWrittenLength-_piece->getLength();
-    newWrittenLength = _piece->getLength();
+  int32_t newWrittenLength = writtenLength_+bytes;
+  assert(newWrittenLength <= piece_->getLength());
+  for(size_t i = writtenLength_/piece_->getBlockLength(),
+        end = newWrittenLength/piece_->getBlockLength(); i < end; ++i) {
+    piece_->completeBlock(i);
   }
-  for(size_t i = _writtenLength/_piece->getBlockLength(); i < newWrittenLength/_piece->getBlockLength(); ++i) {
-    _piece->completeBlock(i);
+  if(newWrittenLength == piece_->getLength()) {
+    piece_->completeBlock(piece_->countBlock()-1);
   }
-  if(newWrittenLength == _piece->getLength()) {
-    _piece->completeBlock(_piece->countBlock()-1);
-  }
-  _writtenLength = newWrittenLength;
+  writtenLength_ = newWrittenLength;
 }
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-bool PiecedSegment::updateHash(uint32_t begin,
-                               const unsigned char* data, size_t dataLength)
+bool PiecedSegment::updateHash
+(int32_t begin,
+ const unsigned char* data,
+ size_t dataLength)
 {
-  return _piece->updateHash(begin, data, dataLength);
+  return piece_->updateHash(begin, data, dataLength);
 }
 
 bool PiecedSegment::isHashCalculated() const
 {
-  return _piece->isHashCalculated();
+  return piece_->isHashCalculated();
 }
 
-std::string PiecedSegment::getHashString()
+std::string PiecedSegment::getDigest()
 {
-  return _piece->getHashString();
+  return piece_->getDigest();
 }
 
 #endif // ENABLE_MESSAGE_DIGEST
 
 void PiecedSegment::clear()
 {
-  _writtenLength = 0;
-  _overflowLength = 0;
-  _piece->clearAllBlock();
+  writtenLength_ = 0;
+  piece_->clearAllBlock();
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-  _piece->destroyHashContext();
+  piece_->destroyHashContext();
 
 #endif // ENABLE_MESSAGE_DIGEST
 }
 
 SharedHandle<Piece> PiecedSegment::getPiece() const
 {
-  return _piece;
+  return piece_;
 }
 
 } // namespace aria2
