@@ -58,6 +58,9 @@
 # include <openssl/err.h>
 # include <openssl/ssl.h>
 #endif // HAVE_OPENSSL
+#ifdef HAVE_LIBGCRYPT
+# include <gcrypt.h>
+#endif // HAVE_LIBGCRYPT
 #ifdef HAVE_LIBGNUTLS
 # include <gnutls/gnutls.h>
 #endif // HAVE_LIBGNUTLS
@@ -68,6 +71,13 @@
 
 #include "DlAbortEx.h"
 #include "message.h"
+#include "fmt.h"
+#include "console.h"
+#ifdef HAVE_LIBGMP
+# include "a2gmp.h"
+#endif // HAVE_LIBGMP
+
+#define A2_MIN_GCRYPT_VERSION "1.2.4"
 
 namespace aria2 {
 
@@ -89,7 +99,9 @@ bool Platform::setUp()
     return false;
   }
   initialized_ = true;
-
+#ifdef HAVE_LIBGMP
+  global::initGmp();
+#endif // HAVE_LIBGMP
 #ifdef ENABLE_NLS
   setlocale (LC_CTYPE, "");
   setlocale (LC_MESSAGES, "");
@@ -102,16 +114,28 @@ bool Platform::setUp()
   SSL_load_error_strings();
   SSL_library_init();
 #endif // HAVE_OPENSSL
+#ifdef HAVE_LIBGCRYPT
+  if(!gcry_check_version(A2_MIN_GCRYPT_VERSION)) {
+    throw DL_ABORT_EX("gcry_check_version() failed.");
+  }
+  gcry_control(GCRYCTL_DISABLE_SECMEM, 0);
+  gcry_control(GCRYCTL_INITIALIZATION_FINISHED, 0);
+#endif // HAVE_LIBGCRYPT
 #ifdef HAVE_LIBGNUTLS
-  gnutls_global_init();
+  {
+    int r = gnutls_global_init();
+    if(r != GNUTLS_E_SUCCESS) {
+      throw DL_ABORT_EX(fmt("gnutls_global_init() failed, cause:%s",
+                            gnutls_strerror(r)));
+    }
+  }
 #endif // HAVE_LIBGNUTLS
 
 #ifdef CARES_HAVE_ARES_LIBRARY_INIT
   int aresErrorCode;
   if((aresErrorCode = ares_library_init(ARES_LIB_INIT_ALL)) != 0) {
-    std::cerr << "ares_library_init() failed:"
-              << ares_strerror(aresErrorCode)
-              << std::endl;
+    global::cerr()->printf("ares_library_init() failed:%s\n",
+                           ares_strerror(aresErrorCode));
   }
 #endif // CARES_HAVE_ARES_LIBRARY_INIT
 
