@@ -32,37 +32,36 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_RECOVERABLE_EXCEPTION_H_
-#define _D_RECOVERABLE_EXCEPTION_H_
+#ifndef D_RECOVERABLE_EXCEPTION_H
+#define D_RECOVERABLE_EXCEPTION_H
 #include "Exception.h"
-#include "DownloadResultCode.h"
 
 namespace aria2 {
 
 class RecoverableException:public Exception {
-private:
-  downloadresultcode::RESULT code_;
-
 protected:
   virtual SharedHandle<Exception> copy() const;
 public:
   RecoverableException(const char* file, int line, const std::string& msg);
 
   RecoverableException(const char* file, int line, const std::string& msg,
+                       error_code::Value errorCode,
                        const Exception& cause);
 
-  RecoverableException(const char* file, int line,
-                       const RecoverableException& e);
+  RecoverableException(const char* file, int line, const std::string& msg,
+                       const Exception& cause);
+
+  RecoverableException(const char* file, int line, const std::string& msg,
+                       error_code::Value errorCode);
 
   RecoverableException
-  (const char* file, int line, int errnoArg, const std::string& msg);
-  
-  RecoverableException(const char* file, int line, const std::string& msg,
-                       downloadresultcode::RESULT result);
+  (const char* file, int line, int errNum, const std::string& msg);
 
-  downloadresultcode::RESULT getCode() const { return code_; }
+  RecoverableException
+  (const char* file, int line, int errNum, const std::string& msg,
+   error_code::Value errorCode);
 };
 
 } // namespace aria2
 
-#endif // _D_RECOVERABLE_EXCEPTION_EX_H_
+#endif // D_RECOVERABLE_EXCEPTION_EX_H
