@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SEED_CHECK_COMMAND_H_
-#define _D_SEED_CHECK_COMMAND_H_
+#ifndef D_SEED_CHECK_COMMAND_H
+#define D_SEED_CHECK_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
@@ -49,17 +49,17 @@ class PieceStorage;
 class SeedCheckCommand : public Command
 {
 private:
-  RequestGroup* _requestGroup;
-  DownloadEngine* e;
-  SharedHandle<PieceStorage> _pieceStorage;
-  SharedHandle<BtRuntime> _btRuntime;
-  SharedHandle<SeedCriteria> seedCriteria;
-  bool checkStarted;
+  RequestGroup* requestGroup_;
+  DownloadEngine* e_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<BtRuntime> btRuntime_;
+  SharedHandle<SeedCriteria> seedCriteria_;
+  bool checkStarted_;
 public:
-  SeedCheckCommand(int cuid,
-		   RequestGroup* requestGroup,
-		   DownloadEngine* e,
-		   const SharedHandle<SeedCriteria>& seedCriteria);
+  SeedCheckCommand(cuid_t cuid,
+                   RequestGroup* requestGroup,
+                   DownloadEngine* e,
+                   const SharedHandle<SeedCriteria>& seedCriteria);
 
   virtual ~SeedCheckCommand();
 
@@ -74,4 +74,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SEED_CHECK_COMMAND_H_
+#endif // D_SEED_CHECK_COMMAND_H
