@@ -41,6 +41,8 @@
 #include "Logger.h"
 #include "LogFactory.h"
 #include "fmt.h"
+#include "a2functional.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -66,12 +68,12 @@ void ServerStat::setLastUpdated(const Time& time)
   lastUpdated_ = time;
 }
 
-void ServerStat::setDownloadSpeed(unsigned int downloadSpeed)
+void ServerStat::setDownloadSpeed(int downloadSpeed)
 {
   downloadSpeed_ = downloadSpeed;
 }
 
-void ServerStat::updateDownloadSpeed(unsigned int downloadSpeed)
+void ServerStat::updateDownloadSpeed(int downloadSpeed)
 {
   downloadSpeed_ = downloadSpeed;
   if(downloadSpeed > 0) {
@@ -80,13 +82,12 @@ void ServerStat::updateDownloadSpeed(unsigned int downloadSpeed)
   lastUpdated_.reset();
 }
 
-void ServerStat::setSingleConnectionAvgSpeed
-(unsigned int singleConnectionAvgSpeed)
+void ServerStat::setSingleConnectionAvgSpeed(int singleConnectionAvgSpeed)
 {
   singleConnectionAvgSpeed_ = singleConnectionAvgSpeed;
 }
 
-void ServerStat::updateSingleConnectionAvgSpeed(unsigned int downloadSpeed)
+void ServerStat::updateSingleConnectionAvgSpeed(int downloadSpeed)
 {
   float avgDownloadSpeed;
   if(counter_ == 0)
@@ -115,13 +116,12 @@ void ServerStat::updateSingleConnectionAvgSpeed(unsigned int downloadSpeed)
   singleConnectionAvgSpeed_ = (int)avgDownloadSpeed;
 }
 
-void ServerStat::setMultiConnectionAvgSpeed
-(unsigned int multiConnectionAvgSpeed)
+void ServerStat::setMultiConnectionAvgSpeed(int multiConnectionAvgSpeed)
 {
   multiConnectionAvgSpeed_ = multiConnectionAvgSpeed;
 }
 
-void ServerStat::updateMultiConnectionAvgSpeed(unsigned int downloadSpeed)
+void ServerStat::updateMultiConnectionAvgSpeed(int downloadSpeed)
 {
   float avgDownloadSpeed;
   if(counter_ == 0)
@@ -149,7 +149,7 @@ void ServerStat::increaseCounter()
   ++counter_;
 }
 
-void ServerStat::setCounter(unsigned int value)
+void ServerStat::setCounter(int value)
 {
   counter_ = value;
 }
@@ -186,17 +186,13 @@ void ServerStat::setOK()
 
 void ServerStat::setError()
 {
-  setStatusInternal(ERROR);
+  setStatusInternal(A2_ERROR);
 }
 
 bool ServerStat::operator<(const ServerStat& serverStat) const
 {
-  int c = hostname_.compare(serverStat.hostname_);
-  if(c == 0) {
-    return protocol_ < serverStat.protocol_;
-  } else {
-    return c < 0;
-  }
+  return hostname_ < serverStat.hostname_ ||
+    (hostname_ == serverStat.hostname_ && protocol_ < serverStat.protocol_);
 }
 
 bool ServerStat::operator==(const ServerStat& serverStat) const
@@ -204,17 +200,18 @@ bool ServerStat::operator==(const ServerStat& serverStat) const
   return hostname_ == serverStat.hostname_ && protocol_ == serverStat.protocol_;
 }
 
-std::ostream& operator<<(std::ostream& o, const ServerStat& serverStat)
+std::string ServerStat::toString() const
 {
-  o << "host=" << serverStat.getHostname() << ", "
-    << "protocol=" << serverStat.getProtocol() << ", "
-    << "dl_speed=" << serverStat.getDownloadSpeed() << ", "
-    << "sc_avg_speed=" << serverStat.getSingleConnectionAvgSpeed() << ", "
-    << "mc_avg_speed=" << serverStat.getMultiConnectionAvgSpeed() << ", "
-    << "last_updated=" << serverStat.getLastUpdated().getTime() << ", "
-    << "counter=" << serverStat.getCounter() << ", "
-    << "status=" << ServerStat::STATUS_STRING[serverStat.getStatus()];
-  return o;
+  return fmt("host=%s, protocol=%s, dl_speed=%d, sc_avg_speed=%d,"
+             " mc_avg_speed=%d, last_updated=%ld, counter=%d, status=%s",
+             getHostname().c_str(),
+             getProtocol().c_str(),
+             getDownloadSpeed(),
+             getSingleConnectionAvgSpeed(),
+             getMultiConnectionAvgSpeed(),
+             getLastUpdated().getTime(),
+             getCounter(),
+             ServerStat::STATUS_STRING[getStatus()].c_str());
 }
 
 } // namespace aria2
