@@ -34,8 +34,9 @@
 /* copyright --> */
 #include "ServerStatMan.h"
 
+#include <cstring>
+#include <cstdio>
 #include <algorithm>
-#include <ostream>
 #include <iterator>
 #include <map>
 #include <vector>
@@ -44,6 +45,11 @@
 #include "util.h"
 #include "RecoverableException.h"
 #include "a2functional.h"
+#include "BufferedFile.h"
+#include "message.h"
+#include "fmt.h"
+#include "LogFactory.h"
+#include "File.h"
 
 namespace aria2 {
 
@@ -55,23 +61,17 @@ SharedHandle<ServerStat> ServerStatMan::find(const std::string& hostname,
                                              const std::string& protocol) const
 {
   SharedHandle<ServerStat> ss(new ServerStat(hostname, protocol));
-  std::deque<SharedHandle<ServerStat> >::const_iterator i =
-    std::lower_bound(serverStats_.begin(), serverStats_.end(), ss,
-                     DerefLess<SharedHandle<ServerStat> >());
-  if(i != serverStats_.end() &&
-     (*i)->getHostname() == hostname && (*i)->getProtocol() == protocol) {
-    return *i;
-  } else {
+  ServerStatSet::iterator i = serverStats_.find(ss);
+  if(i == serverStats_.end()) {
     return SharedHandle<ServerStat>();
+  } else {
+    return *i;
   }
 }
 
 bool ServerStatMan::add(const SharedHandle<ServerStat>& serverStat)
 {
-  std::deque<SharedHandle<ServerStat> >::iterator i =
-    std::lower_bound(serverStats_.begin(), serverStats_.end(), serverStat,
-                     DerefLess<SharedHandle<ServerStat> >());
-
+  ServerStatSet::iterator i = serverStats_.lower_bound(serverStat);
   if(i != serverStats_.end() && *(*i) == *serverStat) {
     return false;
   } else {
@@ -80,17 +80,41 @@ bool ServerStatMan::add(const SharedHandle<ServerStat>& serverStat)
   } 
 }
 
-bool ServerStatMan::save(std::ostream& out) const
+bool ServerStatMan::save(const std::string& filename) const
 {
-  for(std::deque<SharedHandle<ServerStat> >::const_iterator i =
-        serverStats_.begin(), eoi = serverStats_.end(); i != eoi; ++i) {
-    out << *(*i) << "\n";
+  std::string tempfile = filename;
+  tempfile += "__temp";
+  {
+    BufferedFile fp(tempfile, BufferedFile::WRITE);
+    if(!fp) {
+      A2_LOG_ERROR(fmt(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
+                       filename.c_str()));
+      return false;
+    }
+    for(ServerStatSet::iterator i = serverStats_.begin(),
+          eoi = serverStats_.end(); i != eoi; ++i) {
+      std::string l = (*i)->toString();
+      l += "\n";
+      if(fp.write(l.data(), l.size()) != l.size()) {
+        A2_LOG_ERROR(fmt(MSG_WRITING_SERVER_STAT_FILE_FAILED,
+                         filename.c_str()));
+      }
+    }
+    if(fp.close() == EOF) {
+      A2_LOG_ERROR(fmt(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str()));
+      return false;
+    }
+  }
+  if(File(tempfile).renameTo(filename)) {
+    A2_LOG_NOTICE(fmt(MSG_SERVER_STAT_SAVED, filename.c_str()));
+    return true;
+  } else {
+    A2_LOG_ERROR(fmt(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str()));
+    return false;
   }
-  out.flush();
-  return !out.bad();
 }
 
-bool ServerStatMan::load(std::istream& in)
+bool ServerStatMan::load(const std::string& filename)
 {
   static const std::string S_HOST = "host";
   static const std::string S_PROTOCOL = "protocol";
@@ -101,49 +125,73 @@ bool ServerStatMan::load(std::istream& in)
   static const std::string S_COUNTER = "counter";
   static const std::string S_STATUS = "status";
 
-  std::string line;
-  while(getline(in, line)) {
-    line = util::strip(line);
+  BufferedFile fp(filename, BufferedFile::READ);
+  if(!fp) {
+    A2_LOG_ERROR(fmt(MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED,
+                     filename.c_str()));
+    return false;
+  }
+  while(1) {
+    std::string line = fp.getLine();
     if(line.empty()) {
+      if(fp.eof()) {
+        break;
+      } else if(!fp) {
+        A2_LOG_ERROR(fmt(MSG_READING_SERVER_STAT_FILE_FAILED,
+                         filename.c_str()));
+        return false;
+      } else {
+        continue;
+      }
+    }
+    std::pair<std::string::const_iterator,
+              std::string::const_iterator> p =
+      util::stripIter(line.begin(), line.end());
+    if(p.first == p.second) {
       continue;
     }
-    std::vector<std::string> items;
-    util::split(line, std::back_inserter(items), ",");
+    std::vector<Scip> items;
+    util::splitIter(p.first, p.second, std::back_inserter(items), ',');
     std::map<std::string, std::string> m;
-    for(std::vector<std::string>::const_iterator i = items.begin(),
+    for(std::vector<Scip>::const_iterator i = items.begin(),
           eoi = items.end(); i != eoi; ++i) {
-      std::pair<std::string, std::string> p;
-      util::divide(p, *i, '=');
-      p.first = util::strip(p.first);
-      p.second = util::strip(p.second);
-      m[p.first] = p.second;
+      std::pair<Scip, Scip> p;
+      util::divide(p, (*i).first, (*i).second, '=');
+      m[std::string(p.first.first, p.first.second)] =
+        std::string(p.second.first, p.second.second);
     }
     if(m[S_HOST].empty() || m[S_PROTOCOL].empty()) {
       continue;
     }
     SharedHandle<ServerStat> sstat(new ServerStat(m[S_HOST], m[S_PROTOCOL]));
     try {
-      sstat->setDownloadSpeed(util::parseUInt(m[S_DL_SPEED]));
+      const std::string& dlSpeed = m[S_DL_SPEED];
+      sstat->setDownloadSpeed(util::parseUInt(dlSpeed));
       // Old serverstat file doesn't contains SC_AVG_SPEED
       if(m.find(S_SC_AVG_SPEED) != m.end()) {
-        sstat->setSingleConnectionAvgSpeed(util::parseUInt(m[S_SC_AVG_SPEED]));
+        const std::string& s = m[S_SC_AVG_SPEED];
+        sstat->setSingleConnectionAvgSpeed(util::parseUInt(s));
       }
       // Old serverstat file doesn't contains MC_AVG_SPEED
       if(m.find(S_MC_AVG_SPEED) != m.end()) {
-        sstat->setMultiConnectionAvgSpeed(util::parseUInt(m[S_MC_AVG_SPEED]));
+        const std::string& s = m[S_MC_AVG_SPEED];
+        sstat->setMultiConnectionAvgSpeed(util::parseUInt(s));
       }
       // Old serverstat file doesn't contains COUNTER_SPEED
       if(m.find(S_COUNTER) != m.end()) {
-        sstat->setCounter(util::parseUInt(m[S_COUNTER]));
+        const std::string& s = m[S_COUNTER];
+        sstat->setCounter(util::parseUInt(s));
       }
-      sstat->setLastUpdated(Time(util::parseInt(m[S_LAST_UPDATED])));
+      const std::string& lastUpdated = m[S_LAST_UPDATED];
+      sstat->setLastUpdated(Time(util::parseInt(lastUpdated)));
       sstat->setStatus(m[S_STATUS]);
       add(sstat);
     } catch(RecoverableException& e) {
       continue;
     }
   }
-  return !in.bad();
+  A2_LOG_NOTICE(fmt(MSG_SERVER_STAT_LOADED, filename.c_str()));
+  return true;
 }
 
 namespace {
@@ -163,9 +211,15 @@ public:
 
 void ServerStatMan::removeStaleServerStat(time_t timeout)
 {
-  serverStats_.erase(std::remove_if(serverStats_.begin(), serverStats_.end(),
-                                    FindStaleServerStat(timeout)),
-                     serverStats_.end());
+  FindStaleServerStat finder(timeout);
+  for(ServerStatSet::iterator i = serverStats_.begin(),
+        eoi = serverStats_.end(); i != eoi;) {
+    if(finder(*i)) {
+      serverStats_.erase(i++);
+    } else {
+      ++i;
+    }
+  }
 }
 
 } // namespace aria2
