@@ -32,16 +32,16 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SERVER_STAT_MAN_H_
-#define _D_SERVER_STAT_MAN_H_
+#ifndef D_SERVER_STAT_MAN_H
+#define D_SERVER_STAT_MAN_H
 #include "common.h"
 
 #include <string>
-#include <deque>
-#include <iosfwd>
+#include <set>
 
 #include "SharedHandle.h"
 #include "a2time.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
@@ -58,15 +58,17 @@ public:
 
   bool add(const SharedHandle<ServerStat>& serverStat);
 
-  bool load(std::istream& in);
+  bool load(const std::string& filename);
 
-  bool save(std::ostream& out) const;
+  bool save(const std::string& filename) const;
 
   void removeStaleServerStat(time_t timeout);
 private:
-  std::deque<SharedHandle<ServerStat> > _serverStats;
+  typedef std::set<SharedHandle<ServerStat>,
+                   DerefLess<SharedHandle<ServerStat> > > ServerStatSet;
+  ServerStatSet serverStats_;
 };
 
 } // namespace aria2
 
-#endif // _D_SERVER_STAT_MAN_H_
+#endif // D_SERVER_STAT_MAN_H
