@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SIMPLE_BT_MESSAGE_H_
-#define _D_SIMPLE_BT_MESSAGE_H_
+#ifndef D_SIMPLE_BT_MESSAGE_H
+#define D_SIMPLE_BT_MESSAGE_H
 
 #include "AbstractBtMessage.h"
 
@@ -43,8 +43,6 @@ class SimpleBtMessage : public AbstractBtMessage {
 public:
   SimpleBtMessage(uint8_t id, const std::string& name);
 
-  virtual ~SimpleBtMessage();
-
   virtual void send();
 
   virtual unsigned char* createMessage() = 0;
@@ -59,4 +57,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SIMPLE_BT_MESSAGE_H_
+#endif // D_SIMPLE_BT_MESSAGE_H
