@@ -36,6 +36,9 @@
 #include "RequestGroup.h"
 #include "DownloadEngine.h"
 #include "StreamFileAllocationEntry.h"
+#include "prefs.h"
+#include "Option.h"
+#include "PieceStorage.h"
 
 namespace aria2 {
 
@@ -49,6 +52,11 @@ StreamCheckIntegrityEntry::~StreamCheckIntegrityEntry() {}
 void StreamCheckIntegrityEntry::onDownloadIncomplete
 (std::vector<Command*>& commands, DownloadEngine* e)
 {
+  const SharedHandle<PieceStorage>& ps = getRequestGroup()->getPieceStorage();
+  ps->onDownloadIncomplete();
+  if(getRequestGroup()->getOption()->getAsBool(PREF_HASH_CHECK_ONLY)) {
+    return;
+  }
   SharedHandle<FileAllocationEntry> entry
     (new StreamFileAllocationEntry(getRequestGroup(), popNextCommand()));
   proceedFileAllocation(commands, entry, e);
