@@ -121,8 +121,9 @@ UTPexExtensionMessage::createCompactPeerListAndFlag
 
 std::string UTPexExtensionMessage::toString() const
 {
-  return strconcat("ut_pex added=", util::uitos(freshPeers_.size()),
-                   ", dropped=", util::uitos(droppedPeers_.size()));
+  return fmt("ut_pex added=%lu, dropped=%lu",
+             static_cast<unsigned long>(freshPeers_.size()),
+             static_cast<unsigned long>(droppedPeers_.size()));
 }
 
 void UTPexExtensionMessage::doReceivedAction()
@@ -134,7 +135,7 @@ void UTPexExtensionMessage::doReceivedAction()
 bool UTPexExtensionMessage::addFreshPeer(const SharedHandle<Peer>& peer)
 {
   if(!peer->isIncomingPeer() &&
-     peer->getFirstContactTime().difference(global::wallclock) < interval_) {
+     peer->getFirstContactTime().difference(global::wallclock()) < interval_) {
     freshPeers_.push_back(peer);
     return true;
   } else {
@@ -151,7 +152,7 @@ bool UTPexExtensionMessage::addDroppedPeer(const SharedHandle<Peer>& peer)
 {
   if(!peer->isIncomingPeer() &&
      peer->getBadConditionStartTime().
-     difference(global::wallclock) < interval_) {
+     difference(global::wallclock()) < interval_) {
     droppedPeers_.push_back(peer);
     return true;
   } else {
@@ -190,25 +191,25 @@ UTPexExtensionMessage::create(const unsigned char* data, size_t len)
   }
   UTPexExtensionMessageHandle msg(new UTPexExtensionMessage(*data));
 
-  SharedHandle<ValueBase> decoded = bencode2::decode(data+1, len-1);
-  const Dict* dict = asDict(decoded);
+  SharedHandle<ValueBase> decoded = bencode2::decode(data+1, data+len);
+  const Dict* dict = downcast<Dict>(decoded);
   if(dict) {
-    const String* added = asString(dict->get("added"));
+    const String* added = downcast<String>(dict->get("added"));
     if(added) {
       bittorrent::extractPeer
         (added, AF_INET,  std::back_inserter(msg->freshPeers_));
     }
-    const String* dropped = asString(dict->get("dropped"));
+    const String* dropped = downcast<String>(dict->get("dropped"));
     if(dropped) {
       bittorrent::extractPeer
         (dropped, AF_INET, std::back_inserter(msg->droppedPeers_));
     }
-    const String* added6 = asString(dict->get("added6"));
+    const String* added6 = downcast<String>(dict->get("added6"));
     if(added6) {
       bittorrent::extractPeer
         (added6, AF_INET6, std::back_inserter(msg->freshPeers_));
     }
-    const String* dropped6 = asString(dict->get("dropped6"));
+    const String* dropped6 = downcast<String>(dict->get("dropped6"));
     if(dropped6) {
       bittorrent::extractPeer
         (dropped6, AF_INET6, std::back_inserter(msg->droppedPeers_));
