@@ -59,6 +59,8 @@
 #include "prefs.h"
 #include "FileEntry.h"
 #include "error_code.h"
+#include "array_fun.h"
+#include "DownloadFailureException.h"
 
 namespace aria2 {
 
@@ -119,11 +121,10 @@ void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
   std::vector<std::string> pieceHashes;
   pieceHashes.reserve(numPieces);
   for(size_t i = 0; i < numPieces; ++i) {
-    pieceHashes.push_back(util::toHex(hashData.data()+i*hashLength,
-                                      hashLength));
+    const char* p = hashData.data()+i*hashLength;
+    pieceHashes.push_back(std::string(p, p+hashLength));
   }
-  ctx->setPieceHashes(pieceHashes.begin(), pieceHashes.end());
-  ctx->setPieceHashAlgo("sha-1");
+  ctx->setPieceHashes("sha-1", pieceHashes.begin(), pieceHashes.end());
 }
 } // namespace
 
@@ -157,7 +158,7 @@ void extractUrlList
     {
       for(List::ValueType::const_iterator itr = v.begin(), eoi = v.end();
           itr != eoi; ++itr) {
-        const String* uri = asString(*itr);
+        const String* uri = downcast<String>(*itr);
         if(uri) {
           std::string utf8Uri = util::encodeNonUtf8(uri->s());
           uris_.push_back(utf8Uri);
@@ -182,7 +183,7 @@ OutputIterator createUri
  const std::string& filePath)
 {
   for(; first != last; ++first) {
-    if(util::endsWith(*first, "/")) {
+    if(!(*first).empty() && (*first)[(*first).size()-1] == '/') {
       *out++ = (*first)+filePath;
     } else {
       *out++ = (*first)+"/"+filePath;
@@ -210,7 +211,7 @@ void extractFileEntries
     } else {
       nameKey = C_NAME;
     }
-    const String* nameData = asString(infoDict->get(nameKey));
+    const String* nameData = downcast<String>(infoDict->get(nameKey));
     if(nameData) {
       utf8Name = util::encodeNonUtf8(nameData->s());
       if(util::detectDirTraversal(utf8Name)) {
@@ -220,40 +221,45 @@ void extractFileEntries
            error_code::BITTORRENT_PARSE_ERROR);
       }
     } else {
-      utf8Name = strconcat(File(defaultName).getBasename(), ".file");
+      utf8Name = File(defaultName).getBasename();
+      utf8Name += ".file";
     }
   } else {
     utf8Name = overrideName;
   }
   torrent->name = utf8Name;
+  int maxConn = option->getAsInt(PREF_MAX_CONNECTION_PER_SERVER);
   std::vector<SharedHandle<FileEntry> > fileEntries;
-  const List* filesList = asList(infoDict->get(C_FILES));
+  const List* filesList = downcast<List>(infoDict->get(C_FILES));
   if(filesList) {
     fileEntries.reserve(filesList->size());
-    uint64_t length = 0;
+    int64_t length = 0;
     off_t offset = 0;
     // multi-file mode
     torrent->mode = MULTI;
     for(List::ValueType::const_iterator itr = filesList->begin(),
           eoi = filesList->end(); itr != eoi; ++itr) {
-      const Dict* fileDict = asDict(*itr);
+      const Dict* fileDict = downcast<Dict>(*itr);
       if(!fileDict) {
         continue;
       }
-      const Integer* fileLengthData = asInteger(fileDict->get(C_LENGTH));
+      const Integer* fileLengthData = downcast<Integer>(fileDict->get(C_LENGTH));
       if(!fileLengthData) {
         throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_LENGTH.c_str()),
                            error_code::BITTORRENT_PARSE_ERROR);
       }
       length += fileLengthData->i();
-
+      if(length > std::numeric_limits<off_t>::max()) {
+        throw DOWNLOAD_FAILURE_EXCEPTION
+          (fmt(EX_TOO_LARGE_FILE, static_cast<long long int>(length)));
+      }
       std::string pathKey;
       if(fileDict->containsKey(C_PATH_UTF8)) {
         pathKey = C_PATH_UTF8;
       } else {
         pathKey = C_PATH;
       }
-      const List* pathList = asList(fileDict->get(pathKey));
+      const List* pathList = downcast<List>(fileDict->get(pathKey));
       if(!pathList || pathList->empty()) {
         throw DL_ABORT_EX2("Path is empty.",
                            error_code::BITTORRENT_PARSE_ERROR);
@@ -265,7 +271,7 @@ void extractFileEntries
       ++pathelemOutItr;
       for(List::ValueType::const_iterator itr = pathList->begin(),
             eoi = pathList->end(); itr != eoi; ++itr) {
-        const String* elem = asString(*itr);
+        const String* elem = downcast<String>(*itr);
         if(elem) {
           (*pathelemOutItr++) = elem->s();
         } else {
@@ -273,14 +279,14 @@ void extractFileEntries
                              error_code::BITTORRENT_PARSE_ERROR);
         }
       }
-      std::string utf8Path = strjoin(pathelem.begin(), pathelem.end(), '/',
+      std::string utf8Path = strjoin(pathelem.begin(), pathelem.end(), "/",
                                      std::ptr_fun(util::encodeNonUtf8));
       if(util::detectDirTraversal(utf8Path)) {
         throw DL_ABORT_EX2(fmt(MSG_DIR_TRAVERSAL_DETECTED, utf8Path.c_str()),
                            error_code::BITTORRENT_PARSE_ERROR);
       }
       std::string pePath =
-        strjoin(pathelem.begin(), pathelem.end(), '/',
+        strjoin(pathelem.begin(), pathelem.end(), "/",
                 std::ptr_fun(static_cast<std::string (*)(const std::string&)>
                              (util::percentEncode)));
       std::vector<std::string> uris;
@@ -290,25 +296,29 @@ void extractFileEntries
                                       util::escapePath(utf8Path)),
                        fileLengthData->i(), offset, uris));
       fileEntry->setOriginalName(utf8Path);
+      fileEntry->setMaxConnectionPerServer(maxConn);
       fileEntries.push_back(fileEntry);
       offset += fileEntry->getLength();
     }
   } else {
     // single-file mode;
     torrent->mode = SINGLE;
-    const Integer* lengthData = asInteger(infoDict->get(C_LENGTH));
+    const Integer* lengthData = downcast<Integer>(infoDict->get(C_LENGTH));
     if(!lengthData) {
       throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_LENGTH.c_str()),
                          error_code::BITTORRENT_PARSE_ERROR);
     }
-    uint64_t totalLength = lengthData->i();
-
+    int64_t totalLength = lengthData->i();
+    if(totalLength > std::numeric_limits<off_t>::max()) {
+      throw DOWNLOAD_FAILURE_EXCEPTION
+        (fmt(EX_TOO_LARGE_FILE, static_cast<long long int>(totalLength)));
+    }
     // For each uri in urlList, if it ends with '/', then
     // concatenate name to it. Specification just says so.
     std::vector<std::string> uris;
     for(std::vector<std::string>::const_iterator i = urlList.begin(),
           eoi = urlList.end(); i != eoi; ++i) {
-      if(util::endsWith(*i, A2STR::SLASH_C)) {
+      if(!(*i).empty() && (*i)[(*i).size()-1] == '/') {
         uris.push_back((*i)+util::percentEncode(utf8Name));
       } else {
         uris.push_back(*i);
@@ -319,6 +329,7 @@ void extractFileEntries
                                     util::escapePath(utf8Name)),
                      totalLength, 0, uris));
     fileEntry->setOriginalName(utf8Name);
+    fileEntry->setMaxConnectionPerServer(maxConn);
     fileEntries.push_back(fileEntry);
   }
   ctx->setFileEntries(fileEntries.begin(), fileEntries.end());
@@ -333,18 +344,18 @@ namespace {
 void extractAnnounce
 (const SharedHandle<TorrentAttribute>& torrent, const Dict* rootDict)
 {
-  const List* announceList = asList(rootDict->get(C_ANNOUNCE_LIST));
+  const List* announceList = downcast<List>(rootDict->get(C_ANNOUNCE_LIST));
   if(announceList) {
     for(List::ValueType::const_iterator tierIter = announceList->begin(),
           eoi = announceList->end(); tierIter != eoi; ++tierIter) {
-      const List* tier = asList(*tierIter);
+      const List* tier = downcast<List>(*tierIter);
       if(!tier) {
         continue;
       }
       std::vector<std::string> ntier;
       for(List::ValueType::const_iterator uriIter = tier->begin(),
             eoi2 = tier->end(); uriIter != eoi2; ++uriIter) {
-        const String* uri = asString(*uriIter);
+        const String* uri = downcast<String>(*uriIter);
         if(uri) {
           ntier.push_back(util::encodeNonUtf8(util::strip(uri->s())));
         }
@@ -354,7 +365,7 @@ void extractAnnounce
       }
     }
   } else {
-    const String* announce = asString(rootDict->get(C_ANNOUNCE));
+    const String* announce = downcast<String>(rootDict->get(C_ANNOUNCE));
     if(announce) {
       std::vector<std::string> tier;
       tier.push_back(util::encodeNonUtf8(util::strip(announce->s())));
@@ -368,15 +379,15 @@ namespace {
 void extractNodes
 (const SharedHandle<TorrentAttribute>& torrent, const ValueBase* nodesListSrc)
 {
-  const List* nodesList = asList(nodesListSrc);
+  const List* nodesList = downcast<List>(nodesListSrc);
   if(nodesList) {
     for(List::ValueType::const_iterator i = nodesList->begin(),
           eoi = nodesList->end(); i != eoi; ++i) {
-      const List* addrPairList = asList(*i);
+      const List* addrPairList = downcast<List>(*i);
       if(!addrPairList || addrPairList->size() != 2) {
         continue;
       }
-      const String* hostname = asString(addrPairList->get(0));
+      const String* hostname = downcast<String>(addrPairList->get(0));
       if(!hostname) {
         continue;
       }
@@ -385,7 +396,7 @@ void extractNodes
       if(utf8Hostname.empty()) {
         continue;
       }
-      const Integer* port = asInteger(addrPairList->get(1));
+      const Integer* port = downcast<Integer>(addrPairList->get(1));
       if(!port || !(0 < port->i() && port->i() < 65536)) {
         continue;
       }
@@ -404,12 +415,12 @@ void processRootDictionary
  const std::string& overrideName,
  const std::vector<std::string>& uris)
 {
-  const Dict* rootDict = asDict(root);
+  const Dict* rootDict = downcast<Dict>(root);
   if(!rootDict) {
     throw DL_ABORT_EX2("torrent file does not contain a root dictionary.",
                        error_code::BITTORRENT_PARSE_ERROR);
   }
-  const Dict* infoDict = asDict(rootDict->get(C_INFO));
+  const Dict* infoDict = downcast<Dict>(rootDict->get(C_INFO));
   if(!infoDict) {
     throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_INFO.c_str()),
                        error_code::BITTORRENT_PARSE_ERROR);
@@ -423,12 +434,12 @@ void processRootDictionary
                          MessageDigest::sha1(),
                          encodedInfoDict.data(),
                          encodedInfoDict.size());
-  torrent->infoHash = std::string(&infoHash[0], &infoHash[INFO_HASH_LENGTH]);
+  torrent->infoHash.assign(&infoHash[0], &infoHash[INFO_HASH_LENGTH]);
   torrent->metadata = encodedInfoDict;
   torrent->metadataSize = encodedInfoDict.size();
 
   // calculate the number of pieces
-  const String* piecesData = asString(infoDict->get(C_PIECES));
+  const String* piecesData = downcast<String>(infoDict->get(C_PIECES));
   if(!piecesData) {
     throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_PIECES.c_str()),
                        error_code::BITTORRENT_PARSE_ERROR);
@@ -443,7 +454,7 @@ void processRootDictionary
   //     throw DL_ABORT_EX("The number of pieces is 0.");
   //   }
   // retrieve piece length
-  const Integer* pieceLengthData = asInteger(infoDict->get(C_PIECE_LENGTH));
+  const Integer* pieceLengthData = downcast<Integer>(infoDict->get(C_PIECE_LENGTH));
   if(!pieceLengthData) {
     throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_PIECE_LENGTH.c_str()),
                        error_code::BITTORRENT_PARSE_ERROR);
@@ -453,7 +464,7 @@ void processRootDictionary
   // retrieve piece hashes
   extractPieceHash(ctx, piecesData->s(), PIECE_HASH_LENGTH, numPieces);
   // private flag
-  const Integer* privateData = asInteger(infoDict->get(C_PRIVATE));
+  const Integer* privateData = downcast<Integer>(infoDict->get(C_PRIVATE));
   int privatefg = 0;
   if(privateData) {
     if(privateData->i() == 1) {
@@ -484,20 +495,20 @@ void processRootDictionary
   // retrieve nodes
   extractNodes(torrent, rootDict->get(C_NODES).get());
 
-  const Integer* creationDate = asInteger(rootDict->get(C_CREATION_DATE));
+  const Integer* creationDate = downcast<Integer>(rootDict->get(C_CREATION_DATE));
   if(creationDate) {
     torrent->creationDate = creationDate->i();
   }
-  const String* commentUtf8 = asString(rootDict->get(C_COMMENT_UTF8));
+  const String* commentUtf8 = downcast<String>(rootDict->get(C_COMMENT_UTF8));
   if(commentUtf8) {
     torrent->comment = util::encodeNonUtf8(commentUtf8->s());
   } else {
-    const String* comment = asString(rootDict->get(C_COMMENT));
+    const String* comment = downcast<String>(rootDict->get(C_COMMENT));
     if(comment) {
       torrent->comment = util::encodeNonUtf8(comment->s());
     }
   }
-  const String* createdBy = asString(rootDict->get(C_CREATED_BY));
+  const String* createdBy = downcast<String>(rootDict->get(C_CREATED_BY));
   if(createdBy) {
     torrent->createdBy = util::encodeNonUtf8(createdBy->s());
   }
@@ -541,7 +552,7 @@ void loadFromMemory(const unsigned char* content,
                     const std::string& overrideName)
 {
   processRootDictionary(ctx,
-                        bencode2::decode(content, length),
+                        bencode2::decode(content, content+length),
                         option,
                         defaultName,
                         overrideName,
@@ -557,7 +568,7 @@ void loadFromMemory(const unsigned char* content,
                     const std::string& overrideName)
 {
   processRootDictionary(ctx,
-                        bencode2::decode(content, length),
+                        bencode2::decode(content, content+length),
                         option,
                         defaultName,
                         overrideName,
@@ -572,7 +583,7 @@ void loadFromMemory(const std::string& context,
 {
   processRootDictionary
     (ctx,
-     bencode2::decode(context),
+     bencode2::decode(context.begin(), context.end()),
      option,
      defaultName, overrideName,
      std::vector<std::string>());
@@ -587,7 +598,7 @@ void loadFromMemory(const std::string& context,
 {
   processRootDictionary
     (ctx,
-     bencode2::decode(context),
+     bencode2::decode(context.begin(), context.end()),
      option,
      defaultName, overrideName,
      uris);
@@ -612,54 +623,6 @@ getInfoHashString(const SharedHandle<DownloadContext>& dctx)
   return util::toHex(getTorrentAttrs(dctx)->infoHash);
 }
 
-void print(std::ostream& o, const SharedHandle<DownloadContext>& dctx)
-{
-  SharedHandle<TorrentAttribute> torrentAttrs = getTorrentAttrs(dctx);
-  o << "*** BitTorrent File Information ***" << "\n";
-  if(!torrentAttrs->comment.empty()) {
-    o << "Comment: " << torrentAttrs->comment << "\n";
-  }
-  if(torrentAttrs->creationDate) {
-    o << "Creation Date: " << Time(torrentAttrs->creationDate).toHTTPDate()
-      << std::endl;
-  }
-  if(!torrentAttrs->createdBy.empty()) {
-    o << "Created By: " << torrentAttrs->createdBy << "\n";
-  }
-  o << "Mode: " << torrentAttrs->mode << "\n";
-  o << "Announce:" << "\n";
-  for(std::vector<std::vector<std::string> >::const_iterator tierIter =
-        torrentAttrs->announceList.begin(),
-        eoi = torrentAttrs->announceList.end(); tierIter != eoi; ++tierIter) {
-    for(std::vector<std::string>::const_iterator i = (*tierIter).begin(),
-          eoi2 = (*tierIter).end(); i != eoi2; ++i) {
-      o << " " << *i;
-    }
-    o << "\n";
-  }
-  o << "Info Hash: "
-    << util::toHex(torrentAttrs->infoHash) << "\n"
-    << "Piece Length: "
-    << util::abbrevSize(dctx->getPieceLength()) << "B\n"
-    << "The Number of Pieces: "
-    << dctx->getNumPieces() << "\n"
-    << "Total Length: "
-    << util::abbrevSize(dctx->getTotalLength()) << "B ("
-    << util::uitos(dctx->getTotalLength(), true) << ")\n";
-  if(!torrentAttrs->urlList.empty()) {
-    o << "URL List: " << "\n";
-    for(std::vector<std::string>::const_iterator i =
-          torrentAttrs->urlList.begin(),
-          eoi = torrentAttrs->urlList.end(); i != eoi; ++i) {
-      o << " " << *i << "\n";
-    }
-  }
-  o << "Name: " << torrentAttrs->name << "\n"
-    << "Magnet URI: " << torrent2Magnet(torrentAttrs) << "\n";
-  util::toStream
-    (dctx->getFileEntries().begin(), dctx->getFileEntries().end(), o);
-}
-
 void computeFastSet
 (std::vector<size_t>& fastSet, const std::string& ipaddr,
  size_t numPieces, const unsigned char* infoHash, size_t fastSetSize)
@@ -709,7 +672,7 @@ std::string generatePeerId(const std::string& peerIdPrefix)
   int len = 20-peerIdPrefix.size();
   if(len > 0) {
     util::generateRandomData(buf, len);
-    peerId += std::string(&buf[0], &buf[len]);
+    peerId.append(&buf[0], &buf[len]);
   } if(peerId.size() > 20) {
     peerId.erase(20);
   }
@@ -773,42 +736,34 @@ void checkIndex(size_t index, size_t pieces)
   }
 }
 
-void checkBegin(uint32_t begin, size_t pieceLength)
+void checkBegin(int32_t begin, int32_t pieceLength)
 {
   if(!(begin < pieceLength)) {
-    throw DL_ABORT_EX(fmt("Invalid begin: %u", begin));
+    throw DL_ABORT_EX(fmt("Invalid begin: %d", begin));
   }  
 }
 
-void checkLength(size_t length)
+void checkLength(int32_t length)
 {
   if(length > MAX_BLOCK_LENGTH) {
     throw DL_ABORT_EX
-      (fmt("Length too long: %lu > %uKB",
-           static_cast<unsigned long>(length),
-           MAX_BLOCK_LENGTH/1024));
+      (fmt("Length too long: %d > %dKB", length, MAX_BLOCK_LENGTH/1024));
   }
   if(length == 0) {
-    throw DL_ABORT_EX
-      (fmt("Invalid length: %lu",
-           static_cast<unsigned long>(length)));
+    throw DL_ABORT_EX(fmt("Invalid length: %d", length));
   }
 }
 
-void checkRange(uint32_t begin, size_t length, size_t pieceLength)
+void checkRange(int32_t begin, int32_t length, int32_t pieceLength)
 {
   if(!(0 < length)) {
     throw DL_ABORT_EX
-      (fmt("Invalid range: begin=%u, length=%lu",
-           begin,
-           static_cast<unsigned long>(length)));
+      (fmt("Invalid range: begin=%d, length=%d", begin, length));
   }
-  uint32_t end = begin+length;
+  int32_t end = begin+length;
   if(!(end <= pieceLength)) {
     throw DL_ABORT_EX
-      (fmt("Invalid range: begin=%u, length=%lu",
-           begin,
-           static_cast<unsigned long>(length)));
+      (fmt("Invalid range: begin=%d, length=%d", begin, length));
   }
 }
 
@@ -850,57 +805,27 @@ void createPeerMessageString
 int packcompact
 (unsigned char* compact, const std::string& addr, uint16_t port)
 {
-  struct addrinfo* res;
-  int s =
-    callGetaddrinfo(&res, addr.c_str(), 0, AF_UNSPEC, 0, AI_NUMERICHOST, 0);
-  if(s != 0) {
+  size_t len = net::getBinAddr(compact, addr);
+  if(len == 0) {
     return 0;
   }
-  WSAAPI_AUTO_DELETE<struct addrinfo*> resDeleter(res, freeaddrinfo);
   uint16_t portN = htons(port);
-  for(struct addrinfo* rp = res; rp; rp = rp->ai_next) {
-    if(rp->ai_family == AF_INET) {
-      struct sockaddr_in* in =
-        reinterpret_cast<struct sockaddr_in*>(rp->ai_addr);
-      memcpy(compact, &(in->sin_addr), 4);
-      memcpy(compact+4, &portN, sizeof(portN));
-      return COMPACT_LEN_IPV4;
-    } else if(rp->ai_family == AF_INET6) {
-      struct sockaddr_in6* in6 =
-        reinterpret_cast<struct sockaddr_in6*>(rp->ai_addr);
-      memcpy(compact, &(in6->sin6_addr), 16);
-      memcpy(compact+16, &portN, sizeof(portN));
-      return COMPACT_LEN_IPV6;
-    }
-  }
-  return 0;
+  memcpy(compact+len, &portN, sizeof(portN));
+  return len+2;
 }
 
 std::pair<std::string, uint16_t> unpackcompact
 (const unsigned char* compact, int family)
 {
   std::pair<std::string, uint16_t> r;
-#ifdef HAVE_INET_NTOP
   int portOffset = family == AF_INET?4:16;
-  char buf[INET6_ADDRSTRLEN];
-  if(!inet_ntop(family, compact, buf, sizeof(buf))) {
-    return r;
+  char buf[NI_MAXHOST];
+  if(inetNtop(family, compact, buf, sizeof(buf)) == 0) {
+    r.first = buf;
+    uint16_t portN;
+    memcpy(&portN, compact+portOffset, sizeof(portN));
+    r.second = ntohs(portN);
   }
-  r.first = buf;
-  uint16_t portN;
-  memcpy(&portN, compact+portOffset, sizeof(portN));
-  r.second = ntohs(portN);
-#else // !HAVE_INET_NTOP
-  if(family != AF_INET) {
-    return r;
-  }
-  struct in_addr addr;
-  memcpy(&addr, compact, sizeof(in_addr));
-  r.first = inet_ntoa(addr);
-  uint16_t portN;
-  memcpy(&portN, compact+4, sizeof(portN));
-  r.second = ntohs(portN);
-#endif // !HAVE_INET_NTOP
   return r;
 }
 
@@ -943,7 +868,7 @@ SharedHandle<TorrentAttribute> parseMagnet(const std::string& magnet)
     throw DL_ABORT_EX2("Bad BitTorrent Magnet URI.",
                        error_code::MAGNET_PARSE_ERROR);
   }
-  const List* xts = asList(r->get("xt"));
+  const List* xts = downcast<List>(r->get("xt"));
   if(!xts) {
     throw DL_ABORT_EX2("Missing xt parameter in Magnet URI.",
                        error_code::MAGNET_PARSE_ERROR);
@@ -952,17 +877,16 @@ SharedHandle<TorrentAttribute> parseMagnet(const std::string& magnet)
   std::string infoHash;
   for(List::ValueType::const_iterator xtiter = xts->begin(),
         eoi = xts->end(); xtiter != eoi && infoHash.empty(); ++xtiter) {
-    const String* xt = asString(*xtiter);
+    const String* xt = downcast<String>(*xtiter);
     if(util::startsWith(xt->s(), "urn:btih:")) {
-      std::string xtarg = xt->s().substr(9);
-      size_t size = xtarg.size();
+      size_t size = xt->s().end()-xt->s().begin()-9;
       if(size == 32) {
-        std::string rawhash = base32::decode(xtarg);
+        std::string rawhash = base32::decode(xt->s().begin()+9, xt->s().end());
         if(rawhash.size() == 20) {
           infoHash.swap(rawhash);
         }
       } else if(size == 40) {
-        std::string rawhash = util::fromHex(xtarg);
+        std::string rawhash = util::fromHex(xt->s().begin()+9, xt->s().end());
         if(!rawhash.empty()) {
           infoHash.swap(rawhash);
         }
@@ -974,19 +898,19 @@ SharedHandle<TorrentAttribute> parseMagnet(const std::string& magnet)
                        "No valid BitTorrent Info Hash found.",
                        error_code::MAGNET_PARSE_ERROR);
   }
-  const List* trs = asList(r->get("tr"));
+  const List* trs = downcast<List>(r->get("tr"));
   if(trs) {
     for(List::ValueType::const_iterator i = trs->begin(), eoi = trs->end();
         i != eoi; ++i) {
       std::vector<std::string> tier;
-      tier.push_back(util::encodeNonUtf8(asString(*i)->s()));
+      tier.push_back(util::encodeNonUtf8(downcast<String>(*i)->s()));
       attrs->announceList.push_back(tier);
     }
   }
   std::string name = "[METADATA]";
-  const List* dns = asList(r->get("dn"));
+  const List* dns = downcast<List>(r->get("dn"));
   if(dns && !dns->empty()) {
-    const String* dn = asString(dns->get(0));
+    const String* dn = downcast<String>(dns->get(0));
     name += util::encodeNonUtf8(dn->s());
   } else {
     name += util::toHex(infoHash);
@@ -1025,8 +949,9 @@ std::string metadata2Torrent
     torrent += "13:announce-list";
     torrent += bencode2::encode(&announceList);
   }
-  torrent +=
-    strconcat("4:info", metadata, "e");
+  torrent += "4:info";
+  torrent += metadata;
+  torrent += "e";
   return torrent;
 }
 
@@ -1112,10 +1037,12 @@ void adjustAnnounceUri
 {
   std::vector<std::string> excludeUris;
   std::vector<std::string> addUris;
-  util::split(option->get(PREF_BT_EXCLUDE_TRACKER),
-              std::back_inserter(excludeUris), A2STR::COMMA_C, true);
-  util::split(option->get(PREF_BT_TRACKER),
-              std::back_inserter(addUris), A2STR::COMMA_C, true);
+  const std::string& exTracker = option->get(PREF_BT_EXCLUDE_TRACKER);
+  util::split(exTracker.begin(), exTracker.end(),
+              std::back_inserter(excludeUris), ',', true);
+  const std::string& btTracker = option->get(PREF_BT_TRACKER);
+  util::split(btTracker.begin(), btTracker.end(),
+              std::back_inserter(addUris), ',', true);
   removeAnnounceUri(attrs, excludeUris);
   addAnnounceUri(attrs, addUris);
 }
