@@ -35,17 +35,6 @@
 #ifndef D_COMMON_H
 #define D_COMMON_H
 
-#ifdef __MINGW32__
-# undef SIZE_MAX
-# ifndef _OFF_T_
-#  define _OFF_T_
-typedef long long _off_t;
-#  ifndef _NO_OLDNAMES
-typedef _off_t off_t;
-#  endif // !_NO_OLDNAMES
-# endif // !_OFF_T_
-#endif // __MINGW32__
-
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -59,6 +48,14 @@ typedef _off_t off_t;
 #endif
 #endif // __MINGW32__
 
+#ifdef __MINGW32__
+# define WIN32_LEAN_AND_MEAN
+# ifndef WINVER
+#  define WINVER 0x501u
+# endif // WINVER
+# include <windows.h>
+#endif // __MINGW32__
+
 #ifdef ENABLE_NLS
 // If we put #include <gettext.h> outside of #ifdef ENABLE_NLS and
 // --disable-nls is used, gettext(msgid) is defined as ((const char *)
