@@ -34,6 +34,7 @@
 /* copyright --> */
 #include "magnet.h"
 #include "util.h"
+#include "array_fun.h"
 
 namespace aria2 {
 
@@ -46,21 +47,22 @@ SharedHandle<Dict> parse(const std::string& magnet)
     return dict;
   }
   dict.reset(new Dict());
-  std::vector<std::string> queries;
-  util::split(std::string(magnet.begin()+8, magnet.end()),
-              std::back_inserter(queries), "&");
-  for(std::vector<std::string>::const_iterator i = queries.begin(),
+  std::vector<Scip> queries;
+  util::splitIter(magnet.begin()+8, magnet.end(), std::back_inserter(queries),
+                  '&');
+  for(std::vector<Scip>::const_iterator i = queries.begin(),
         eoi = queries.end(); i != eoi; ++i) {
-    std::pair<std::string, std::string> kv;
-    util::divide(kv, *i, '=');
-    std::string value = util::percentDecode(kv.second);
-    List* l = asList(dict->get(kv.first));
+    std::pair<Scip, Scip> p;
+    util::divide(p, (*i).first, (*i).second, '=');
+    std::string name(p.first.first, p.first.second);
+    std::string value(util::percentDecode(p.second.first, p.second.second));
+    List* l = downcast<List>(dict->get(name));
     if(l) {
       l->append(String::g(value));
     } else {
       SharedHandle<List> l = List::g();
       l->append(String::g(value));
-      dict->put(kv.first, l);
+      dict->put(name, l);
     }
   }
   return dict;
