@@ -50,10 +50,10 @@ std::vector<std::vector<std::string> > toVector
   for(List::ValueType::const_iterator tierIter = announceList->begin(),
         eoi = announceList->end(); tierIter != eoi; ++tierIter) {
     std::vector<std::string> ntier;
-    const List* tier = asList(*tierIter);
+    const List* tier = downcast<List>(*tierIter);
     for(List::ValueType::const_iterator uriIter = tier->begin(),
           eoi2 = tier->end(); uriIter != eoi2; ++uriIter) {
-      const String* uri = asString(*uriIter);
+      const String* uri = downcast<String>(*uriIter);
       ntier.push_back(uri->s());
     }
     dest.push_back(ntier);
@@ -64,11 +64,12 @@ std::vector<std::vector<std::string> > toVector
 
 void AnnounceListTest::testSingleElementList() {
   std::string peersString = "ll8:tracker1el8:tracker2el8:tracker3ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1 ], [ tracker2 ], [ tracker3 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
   
   CPPUNIT_ASSERT(!announceList.allTiersFailed());
   std::string url =  announceList.getAnnounce();
@@ -110,11 +111,12 @@ void AnnounceListTest::testSingleElementList() {
 
 void AnnounceListTest::testMultiElementList() {
   std::string peersString = "ll8:tracker18:tracker28:tracker3ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1, tracker2, tracker3 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
   
   CPPUNIT_ASSERT(!announceList.allTiersFailed());
   std::string url = announceList.getAnnounce();
@@ -143,11 +145,12 @@ void AnnounceListTest::testMultiElementList() {
 
 void AnnounceListTest::testSingleAndMulti() {
   std::string peersString = "ll8:tracker18:tracker2el8:tracker3ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1, tracker2 ], [ tracker3 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
 
   std::string url = announceList.getAnnounce();
   CPPUNIT_ASSERT_EQUAL(std::string("tracker1"), url);
@@ -169,18 +172,20 @@ void AnnounceListTest::testSingleAndMulti() {
 
 void AnnounceListTest::testNoGroup() {
   std::string peersString = "llee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
-  AnnounceList announceList(toVector(asList(announcesList)));
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
   CPPUNIT_ASSERT(announceList.countTier() == 0);
 }
 
 void AnnounceListTest::testNextEventIfAfterStarted() {
   std::string peersString = "ll8:tracker1ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
   announceList.setEvent(AnnounceTier::STOPPED);
   announceList.announceFailure();
   announceList.resetTier();
@@ -196,11 +201,12 @@ void AnnounceListTest::testNextEventIfAfterStarted() {
 
 void AnnounceListTest::testEvent() {
   std::string peersString = "ll8:tracker1el8:tracker2el8:tracker3ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1 ], [ tracker2 ], [ tracker3 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
 
   announceList.setEvent(AnnounceTier::STOPPED);
   announceList.announceSuccess();
@@ -220,11 +226,12 @@ void AnnounceListTest::testEvent() {
 
 void AnnounceListTest::testCountStoppedAllowedTier() {
   std::string peersString = "ll8:tracker1el8:tracker2el8:tracker3ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1 ], [ tracker2 ], [ tracker3 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
 
   CPPUNIT_ASSERT_EQUAL((size_t)0, announceList.countStoppedAllowedTier());
   announceList.setEvent(AnnounceTier::STARTED);
@@ -247,11 +254,12 @@ void AnnounceListTest::testCountStoppedAllowedTier() {
 
 void AnnounceListTest::testCountCompletedAllowedTier() {
   std::string peersString = "ll8:tracker1el8:tracker2el8:tracker3ee";
-  SharedHandle<ValueBase> announcesList = bencode2::decode(peersString);
+  SharedHandle<ValueBase> announcesList =
+    bencode2::decode(peersString.begin(), peersString.end());
 
   // ANNOUNCE_LIST
   // [ [ tracker1 ], [ tracker2 ], [ tracker3 ] ]
-  AnnounceList announceList(toVector(asList(announcesList)));
+  AnnounceList announceList(toVector(downcast<List>(announcesList)));
 
   CPPUNIT_ASSERT_EQUAL((size_t)0, announceList.countCompletedAllowedTier());
   announceList.setEvent(AnnounceTier::STARTED);
