@@ -5,10 +5,11 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "bittorrent_helper.h"
-#include "Util.h"
+#include "util.h"
 #include "Peer.h"
 #include "MockPieceStorage.h"
 #include "DlAbortEx.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
@@ -16,7 +17,7 @@ class BtBitfieldMessageTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtBitfieldMessageTest);
   CPPUNIT_TEST(testCreate);
-  CPPUNIT_TEST(testGetMessage);
+  CPPUNIT_TEST(testCreateMessage);
   CPPUNIT_TEST(testDoReceivedAction);
   CPPUNIT_TEST(testDoReceivedAction_goodByeSeeder);
   CPPUNIT_TEST(testToString);
@@ -28,7 +29,7 @@ public:
   }
 
   void testCreate();
-  void testGetMessage();
+  void testCreateMessage();
   void testDoReceivedAction();
   void testDoReceivedAction_goodByeSeeder();
   void testToString();
@@ -65,7 +66,7 @@ void BtBitfieldMessageTest::testCreate() {
   }
 }
 
-void BtBitfieldMessageTest::testGetMessage() {
+void BtBitfieldMessageTest::testCreateMessage() {
   BtBitfieldMessage msg;
   unsigned char bitfield[2];
   memset(bitfield, 0xff, sizeof(bitfield));
@@ -73,7 +74,10 @@ void BtBitfieldMessageTest::testGetMessage() {
   unsigned char data[5+2];
   bittorrent::createPeerMessageString(data, sizeof(data), 3, 5);
   memcpy(&data[5], bitfield, sizeof(bitfield));
-  CPPUNIT_ASSERT(memcmp(msg.getMessage(), data, 7) == 0);
+  unsigned char* rawmsg = msg.createMessage();
+  CPPUNIT_ASSERT(memcmp(rawmsg, data, 7) == 0);
+  delete [] rawmsg;
+  CPPUNIT_ASSERT_EQUAL((size_t)7, msg.getMessageLength());
 }
 
 void BtBitfieldMessageTest::testDoReceivedAction() {
@@ -86,11 +90,11 @@ void BtBitfieldMessageTest::testDoReceivedAction() {
   unsigned char bitfield[] = { 0xff, 0xff };
   msg.setBitfield(bitfield, sizeof(bitfield));
   
-  CPPUNIT_ASSERT_EQUAL(std::string("0000"), Util::toHex(peer->getBitfield(),
-							peer->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(std::string("0000"), util::toHex(peer->getBitfield(),
+                                                        peer->getBitfieldLength()));
   msg.doReceivedAction();
-  CPPUNIT_ASSERT_EQUAL(std::string("ffff"), Util::toHex(peer->getBitfield(),
-							peer->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(std::string("ffff"), util::toHex(peer->getBitfield(),
+                                                        peer->getBitfieldLength()));
 }
 
 void BtBitfieldMessageTest::testDoReceivedAction_goodByeSeeder()
