@@ -17,6 +17,8 @@
 #include "DirectDiskAdaptor.h"
 #include "ByteArrayDiskWriter.h"
 #include "MockPieceStorage.h"
+#include "prefs.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -24,6 +26,7 @@ class BtDependencyTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtDependencyTest);
   CPPUNIT_TEST(testResolve);
+  CPPUNIT_TEST(testResolve_nullDependee);
   CPPUNIT_TEST(testResolve_originalNameNoMatch);
   CPPUNIT_TEST(testResolve_singleFileWithoutOriginalName);
   CPPUNIT_TEST(testResolve_multiFile);
@@ -35,10 +38,9 @@ class BtDependencyTest:public CppUnit::TestFixture {
 
   SharedHandle<RequestGroup> createDependant(const SharedHandle<Option>& option)
   {
-    SharedHandle<RequestGroup> dependant(new RequestGroup(option));
+    SharedHandle<RequestGroup> dependant(new RequestGroup(util::copy(option)));
     SharedHandle<DownloadContext> dctx
       (new DownloadContext(0, 0, "/tmp/outfile.path"));
-    dctx->setDir("/tmp");
     std::vector<std::string> uris;
     uris.push_back("http://localhost/outfile.path");
     SharedHandle<FileEntry> fileEntry = dctx->getFirstFileEntry();
@@ -54,10 +56,9 @@ class BtDependencyTest:public CppUnit::TestFixture {
    const std::string& torrentFile,
    int64_t length)
   {
-    SharedHandle<RequestGroup> dependee(new RequestGroup(option));
+    SharedHandle<RequestGroup> dependee(new RequestGroup(util::copy(option)));
     SharedHandle<DownloadContext> dctx
       (new DownloadContext(1024*1024, length, torrentFile));
-    dctx->setDir(".");
     dependee->setDownloadContext(dctx);
     dependee->initPieceStorage();
     return dependee;
@@ -68,9 +69,11 @@ public:
   void setUp()
   {
     option_.reset(new Option());
+    option_->put(PREF_DIR, "/tmp");
   }
 
   void testResolve();
+  void testResolve_nullDependee();
   void testResolve_originalNameNoMatch();
   void testResolve_singleFileWithoutOriginalName();
   void testResolve_multiFile();
@@ -85,13 +88,14 @@ CPPUNIT_TEST_SUITE_REGISTRATION( BtDependencyTest );
 
 void BtDependencyTest::testResolve()
 {
-  std::string filename = "single.torrent";
+  std::string filename = A2_TEST_DIR"/single.torrent";
   SharedHandle<RequestGroup> dependant = createDependant(option_);
   SharedHandle<RequestGroup> dependee =
     createDependee(option_, filename, File(filename).size());
+  dependee->getPieceStorage()->getDiskAdaptor()->enableReadOnly();
   dependee->getPieceStorage()->markAllPiecesDone();
   
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
 
   CPPUNIT_ASSERT_EQUAL
@@ -105,17 +109,25 @@ void BtDependencyTest::testResolve()
   CPPUNIT_ASSERT(firstFileEntry->isRequested());
 }
 
+void BtDependencyTest::testResolve_nullDependee()
+{
+  SharedHandle<RequestGroup> dependant = createDependant(option_);
+  BtDependency dep(dependant.get(), SharedHandle<RequestGroup>());
+  CPPUNIT_ASSERT(dep.resolve());
+}
+
 void BtDependencyTest::testResolve_originalNameNoMatch()
 {
-  std::string filename = "single.torrent";
+  std::string filename = A2_TEST_DIR"/single.torrent";
   SharedHandle<RequestGroup> dependant = createDependant(option_);
   dependant->getDownloadContext()->getFirstFileEntry()->setOriginalName
     ("aria2-1.1.0.tar.bz2");
   SharedHandle<RequestGroup> dependee =
     createDependee(option_, filename, File(filename).size());
+  dependee->getPieceStorage()->getDiskAdaptor()->enableReadOnly();
   dependee->getPieceStorage()->markAllPiecesDone();
   
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
 
   CPPUNIT_ASSERT(!dependant->getDownloadContext()->hasAttribute
@@ -124,13 +136,14 @@ void BtDependencyTest::testResolve_originalNameNoMatch()
 
 void BtDependencyTest::testResolve_singleFileWithoutOriginalName()
 {
-  std::string filename = "single.torrent";
+  std::string filename = A2_TEST_DIR"/single.torrent";
   SharedHandle<RequestGroup> dependant = createDependant(option_);
   dependant->getDownloadContext()->getFirstFileEntry()->setOriginalName("");
   SharedHandle<RequestGroup> dependee =
     createDependee(option_, filename, File(filename).size());
+  dependee->getPieceStorage()->getDiskAdaptor()->enableReadOnly();
   dependee->getPieceStorage()->markAllPiecesDone();
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
   CPPUNIT_ASSERT(dependant->getDownloadContext()->hasAttribute
                  (bittorrent::BITTORRENT));
@@ -138,15 +151,16 @@ void BtDependencyTest::testResolve_singleFileWithoutOriginalName()
 
 void BtDependencyTest::testResolve_multiFile()
 {
-  std::string filename = "test.torrent";
+  std::string filename = A2_TEST_DIR"/test.torrent";
   SharedHandle<RequestGroup> dependant = createDependant(option_);
   dependant->getDownloadContext()->getFirstFileEntry()->setOriginalName
     ("aria2-test/aria2/src/aria2c");
   SharedHandle<RequestGroup> dependee =
     createDependee(option_, filename, File(filename).size());
+  dependee->getPieceStorage()->getDiskAdaptor()->enableReadOnly();
   dependee->getPieceStorage()->markAllPiecesDone();
   
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
 
   CPPUNIT_ASSERT(dependant->getDownloadContext()->hasAttribute
@@ -182,7 +196,7 @@ void BtDependencyTest::testResolve_metadata()
   SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
   dependee->getDownloadContext()->setAttribute(bittorrent::BITTORRENT, attrs);
 
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
 
   CPPUNIT_ASSERT_EQUAL
@@ -199,7 +213,7 @@ void BtDependencyTest::testResolve_loadError()
     createDependee(option_, "notExist", 40);
   dependee->getPieceStorage()->markAllPiecesDone();
     
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
     
   CPPUNIT_ASSERT
@@ -213,7 +227,7 @@ void BtDependencyTest::testResolve_dependeeFailure()
   SharedHandle<RequestGroup> dependant = createDependant(option_);
   SharedHandle<RequestGroup> dependee = createDependee(option_, "notExist", 40);
     
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(dep.resolve());
   
   CPPUNIT_ASSERT
@@ -224,13 +238,13 @@ void BtDependencyTest::testResolve_dependeeFailure()
 
 void BtDependencyTest::testResolve_dependeeInProgress()
 {
-  std::string filename = "single.torrent";
+  std::string filename = A2_TEST_DIR"/single.torrent";
   SharedHandle<RequestGroup> dependant = createDependant(option_);
   SharedHandle<RequestGroup> dependee =
     createDependee(option_, filename, File(filename).size());
   dependee->increaseNumCommand();
 
-  BtDependency dep(dependant, dependee);
+  BtDependency dep(dependant.get(), dependee);
   CPPUNIT_ASSERT(!dep.resolve());
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp/outfile.path"),
                        dependant->getFirstFilePath());
