@@ -4,7 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "Util.h"
+#include "util.h"
 #include "BtConstants.h"
 
 namespace aria2 {
@@ -13,7 +13,7 @@ class BtHandshakeMessageTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtHandshakeMessageTest);
   CPPUNIT_TEST(testCreate);
-  CPPUNIT_TEST(testGetMessage);
+  CPPUNIT_TEST(testCreateMessage);
   CPPUNIT_TEST(testToString);
   CPPUNIT_TEST(testSetDHTEnabled);
   CPPUNIT_TEST_SUITE_END();
@@ -24,7 +24,7 @@ public:
   }
 
   void testCreate();
-  void testGetMessage();
+  void testCreateMessage();
   void testToString();
   void testSetDHTEnabled();
 
@@ -39,18 +39,18 @@ CPPUNIT_TEST_SUITE_REGISTRATION(BtHandshakeMessageTest);
 void createHandshakeMessageData(unsigned char* msg) {
   msg[0] = 19;
   memcpy(&msg[1], BtHandshakeMessageTest::BTPSTR.c_str(),
-	 BtHandshakeMessageTest::BTPSTR.size());
+         BtHandshakeMessageTest::BTPSTR.size());
   unsigned char reserved[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x04 };
   memcpy(&msg[20], reserved, sizeof(reserved));
   unsigned char infoHash[] = { 0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff };
+                               0xff, 0xff, 0xff, 0xff, 0xff,
+                               0xff, 0xff, 0xff, 0xff, 0xff,
+                               0xff, 0xff, 0xff, 0xff, 0xff };
   memcpy(&msg[28], infoHash, sizeof(infoHash));
   unsigned char peerId[] = { 0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0 };
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0 };
   memcpy(&msg[48], peerId, sizeof(peerId));
 }
 
@@ -60,25 +60,25 @@ void BtHandshakeMessageTest::testCreate() {
   SharedHandle<BtHandshakeMessage> message = BtHandshakeMessage::create(&msg[0], sizeof(msg));
   CPPUNIT_ASSERT_EQUAL((uint8_t)INT8_MAX, message->getId());
   CPPUNIT_ASSERT_EQUAL((uint8_t)19, message->getPstrlen());
-  CPPUNIT_ASSERT_EQUAL(Util::toHex((const unsigned char*)BTPSTR.c_str(), BTPSTR.size()),
-		       Util::toHex(message->getPstr(), BtHandshakeMessage::PSTR_LENGTH));
+  CPPUNIT_ASSERT_EQUAL(util::toHex((const unsigned char*)BTPSTR.c_str(), BTPSTR.size()),
+                       util::toHex(message->getPstr(), BtHandshakeMessage::PSTR_LENGTH));
   CPPUNIT_ASSERT_EQUAL(std::string("0000000000100004"),
-		       Util::toHex(message->getReserved(), BtHandshakeMessage::RESERVED_LENGTH));
+                       util::toHex(message->getReserved(), BtHandshakeMessage::RESERVED_LENGTH));
   CPPUNIT_ASSERT_EQUAL(std::string("ffffffffffffffffffffffffffffffffffffffff"),
-		       Util::toHex(message->getInfoHash(), INFO_HASH_LENGTH));
+                       util::toHex(message->getInfoHash(), INFO_HASH_LENGTH));
   CPPUNIT_ASSERT_EQUAL(std::string("f0f0f0f0f0f0f0f0f0f0f0f0f0f0f0f0f0f0f0f0"),
-		       Util::toHex(message->getPeerId(), PEER_ID_LENGTH));
+                       util::toHex(message->getPeerId(), PEER_ID_LENGTH));
 }
 
-void BtHandshakeMessageTest::testGetMessage() {
+void BtHandshakeMessageTest::testCreateMessage() {
   unsigned char infoHash[] = { 0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff };
+                               0xff, 0xff, 0xff, 0xff, 0xff,
+                               0xff, 0xff, 0xff, 0xff, 0xff,
+                               0xff, 0xff, 0xff, 0xff, 0xff };
   unsigned char peerId[] = { 0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0 };
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0 };
 
   SharedHandle<BtHandshakeMessage> msg(new BtHandshakeMessage());
   msg->setInfoHash(infoHash);
@@ -86,19 +86,21 @@ void BtHandshakeMessageTest::testGetMessage() {
 
   unsigned char data[68];
   createHandshakeMessageData(data);
-  CPPUNIT_ASSERT_EQUAL(Util::toHex((const unsigned char*)data, 68),
-		       Util::toHex((const unsigned char*)msg->getMessage(), 68));
+  unsigned char* rawmsg = msg->createMessage();
+  CPPUNIT_ASSERT_EQUAL(util::toHex((const unsigned char*)data, 68),
+                       util::toHex(rawmsg, 68));
+  delete [] rawmsg;
 }
 
 void BtHandshakeMessageTest::testToString() {
   unsigned char infoHash[] = { 0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff,
-			       0xff, 0xff, 0xff, 0xff, 0xff };
+                               0xff, 0xff, 0xff, 0xff, 0xff,
+                               0xff, 0xff, 0xff, 0xff, 0xff,
+                               0xff, 0xff, 0xff, 0xff, 0xff };
   unsigned char peerId[] = { 0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
-			     0xf0, 0xf0, 0xf0, 0xf0, 0xf0 };
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
+                             0xf0, 0xf0, 0xf0, 0xf0, 0xf0 };
 
   BtHandshakeMessage msg;
   msg.setInfoHash(infoHash);
