@@ -22,7 +22,7 @@ class BtRequestMessageTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtRequestMessageTest);
   CPPUNIT_TEST(testCreate);
-  CPPUNIT_TEST(testGetMessage);
+  CPPUNIT_TEST(testCreateMessage);
   CPPUNIT_TEST(testDoReceivedAction_hasPieceAndAmNotChoking);
   CPPUNIT_TEST(testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionEnabled);
   CPPUNIT_TEST(testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionDisabled);
@@ -40,7 +40,7 @@ private:
 
 public:
   void testCreate();
-  void testGetMessage();
+  void testCreateMessage();
   void testDoReceivedAction_hasPieceAndAmNotChoking();
   void testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionEnabled();
   void testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionDisabled();
@@ -69,7 +69,7 @@ public:
     size_t length;
   public:
     MockBtMessage2(std::string type, size_t index, uint32_t begin,
-		   size_t length)
+                   size_t length)
       :
       type(type), index(index), begin(begin), length(length) {}
   };
@@ -79,47 +79,47 @@ public:
   class MockBtMessageFactory2 : public MockBtMessageFactory {
   public:
     virtual SharedHandle<BtMessage>
-    createPieceMessage(size_t index, uint32_t begin, size_t length) {
+    createPieceMessage(size_t index, int32_t begin, int32_t length) {
       SharedHandle<MockBtMessage2> btMsg
-	(new MockBtMessage2("piece", index, begin, length));
+        (new MockBtMessage2("piece", index, begin, length));
       return btMsg;
     }
 
     virtual SharedHandle<BtMessage>
-    createRejectMessage(size_t index, uint32_t begin, size_t length) {
+    createRejectMessage(size_t index, int32_t begin, int32_t length) {
       SharedHandle<MockBtMessage2> btMsg
-	(new MockBtMessage2("reject", index, begin, length));
+        (new MockBtMessage2("reject", index, begin, length));
       return btMsg;
     }
   };
 
   typedef SharedHandle<MockBtMessageFactory2> MockBtMessageFactory2Handle;
 
-  SharedHandle<MockPieceStorage> _pieceStorage;
-  SharedHandle<Peer> _peer;
-  SharedHandle<MockBtMessageDispatcher> _dispatcher;
-  SharedHandle<MockBtMessageFactory> _messageFactory;
+  SharedHandle<MockPieceStorage> pieceStorage_;
+  SharedHandle<Peer> peer_;
+  SharedHandle<MockBtMessageDispatcher> dispatcher_;
+  SharedHandle<MockBtMessageFactory> messageFactory_;
   SharedHandle<BtRequestMessage> msg;
 
   void setUp() {
-    _pieceStorage.reset(new MockPieceStorage2());
+    pieceStorage_.reset(new MockPieceStorage2());
 
-    _peer.reset(new Peer("host", 6969));
-    _peer->allocateSessionResource(16*1024, 256*1024);
+    peer_.reset(new Peer("host", 6969));
+    peer_->allocateSessionResource(16*1024, 256*1024);
 
-    _dispatcher.reset(new MockBtMessageDispatcher());
+    dispatcher_.reset(new MockBtMessageDispatcher());
 
-    _messageFactory.reset(new MockBtMessageFactory2());
+    messageFactory_.reset(new MockBtMessageFactory2());
 
     msg.reset(new BtRequestMessage());
-    msg->setPeer(_peer);
+    msg->setPeer(peer_);
     msg->setIndex(1);
     msg->setBegin(16);
     msg->setLength(32);
     msg->setBlockIndex(2);
-    msg->setBtMessageDispatcher(_dispatcher);
-    msg->setBtMessageFactory(_messageFactory);
-    msg->setPieceStorage(_pieceStorage);
+    msg->setBtMessageDispatcher(dispatcher_.get());
+    msg->setBtMessageFactory(messageFactory_.get());
+    msg->setPieceStorage(pieceStorage_);
   }
 };
 
@@ -135,8 +135,8 @@ void BtRequestMessageTest::testCreate() {
   SharedHandle<BtRequestMessage> pm = BtRequestMessage::create(&msg[4], 13);
   CPPUNIT_ASSERT_EQUAL((uint8_t)6, pm->getId());
   CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
-  CPPUNIT_ASSERT_EQUAL((uint32_t)256, pm->getBegin());
-  CPPUNIT_ASSERT_EQUAL((size_t)1024, pm->getLength());
+  CPPUNIT_ASSERT_EQUAL(256, pm->getBegin());
+  CPPUNIT_ASSERT_EQUAL(1024, pm->getLength());
 
   // case: payload size is wrong
   try {
@@ -156,7 +156,7 @@ void BtRequestMessageTest::testCreate() {
   }
 }
 
-void BtRequestMessageTest::testGetMessage() {
+void BtRequestMessageTest::testCreateMessage() {
   BtRequestMessage msg;
   msg.setIndex(12345);
   msg.setBegin(256);
@@ -166,16 +166,18 @@ void BtRequestMessageTest::testGetMessage() {
   bittorrent::setIntParam(&data[5], 12345);
   bittorrent::setIntParam(&data[9], 256);
   bittorrent::setIntParam(&data[13], 1024);
-  CPPUNIT_ASSERT(memcmp(msg.getMessage(), data, 17) == 0);
+  unsigned char* rawmsg = msg.createMessage();
+  CPPUNIT_ASSERT(memcmp(rawmsg, data, 17) == 0);
+  delete [] rawmsg;
 }
 
 void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmNotChoking() {
-  _peer->amChoking(false);
+  peer_->amChoking(false);
   msg->doReceivedAction();
   
-  CPPUNIT_ASSERT_EQUAL((size_t)1, _dispatcher->messageQueue.size());
-  MockBtMessage2* pieceMsg =
-    (MockBtMessage2*)_dispatcher->messageQueue.front().get();
+  CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher_->messageQueue.size());
+  SharedHandle<MockBtMessage2> pieceMsg =
+    dynamic_pointer_cast<MockBtMessage2>(dispatcher_->messageQueue.front());
   CPPUNIT_ASSERT_EQUAL(std::string("piece"), pieceMsg->type);
   CPPUNIT_ASSERT_EQUAL((size_t)1, pieceMsg->index);
   CPPUNIT_ASSERT_EQUAL((uint32_t)16, pieceMsg->begin);
@@ -183,13 +185,13 @@ void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmNotChoking() {
 }
 
 void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionEnabled() {
-  _peer->amChoking(true);
-  _peer->setFastExtensionEnabled(true);
+  peer_->amChoking(true);
+  peer_->setFastExtensionEnabled(true);
   msg->doReceivedAction();
   
-  CPPUNIT_ASSERT_EQUAL((size_t)1, _dispatcher->messageQueue.size());
-  MockBtMessage2* pieceMsg =
-    (MockBtMessage2*)_dispatcher->messageQueue.front().get();
+  CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher_->messageQueue.size());
+  SharedHandle<MockBtMessage2> pieceMsg =
+    dynamic_pointer_cast<MockBtMessage2>(dispatcher_->messageQueue.front());
   CPPUNIT_ASSERT_EQUAL(std::string("reject"), pieceMsg->type);
   CPPUNIT_ASSERT_EQUAL((size_t)1, pieceMsg->index);
   CPPUNIT_ASSERT_EQUAL((uint32_t)16, pieceMsg->begin);
@@ -197,21 +199,21 @@ void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmChokingAndFastExten
 }
 
 void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionDisabled() {
-  _peer->amChoking(true);
+  peer_->amChoking(true);
   msg->doReceivedAction();
   
-  CPPUNIT_ASSERT_EQUAL((size_t)0, _dispatcher->messageQueue.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)0, dispatcher_->messageQueue.size());
 }
 
 void BtRequestMessageTest::testDoReceivedAction_doesntHavePieceAndFastExtensionEnabled() {
   msg->setIndex(2);
-  _peer->amChoking(false);
-  _peer->setFastExtensionEnabled(true);
+  peer_->amChoking(false);
+  peer_->setFastExtensionEnabled(true);
   msg->doReceivedAction();
   
-  CPPUNIT_ASSERT_EQUAL((size_t)1, _dispatcher->messageQueue.size());
-  MockBtMessage2* pieceMsg =
-    (MockBtMessage2*)_dispatcher->messageQueue.front().get();
+  CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher_->messageQueue.size());
+  SharedHandle<MockBtMessage2> pieceMsg =
+    dynamic_pointer_cast<MockBtMessage2>(dispatcher_->messageQueue.front());
   CPPUNIT_ASSERT_EQUAL(std::string("reject"), pieceMsg->type);
   CPPUNIT_ASSERT_EQUAL((size_t)2, pieceMsg->index);
   CPPUNIT_ASSERT_EQUAL((uint32_t)16, pieceMsg->begin);
@@ -220,10 +222,10 @@ void BtRequestMessageTest::testDoReceivedAction_doesntHavePieceAndFastExtensionE
 
 void BtRequestMessageTest::testDoReceivedAction_doesntHavePieceAndFastExtensionDisabled() {
   msg->setIndex(2);
-  _peer->amChoking(false);
+  peer_->amChoking(false);
   msg->doReceivedAction();
   
-  CPPUNIT_ASSERT_EQUAL((size_t)0, _dispatcher->messageQueue.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)0, dispatcher_->messageQueue.size());
 }
 
 void BtRequestMessageTest::testHandleAbortRequestEvent() {
@@ -261,7 +263,7 @@ void BtRequestMessageTest::testHandleAbortRequestEvent_sendingInProgress() {
 
 void BtRequestMessageTest::testToString() {
   CPPUNIT_ASSERT_EQUAL(std::string("request index=1, begin=16, length=32"),
-		       msg->toString());
+                       msg->toString());
 }
 
 void BtRequestMessageTest::testValidate() {
@@ -269,9 +271,7 @@ void BtRequestMessageTest::testValidate() {
   msg.setBtMessageValidator
     (SharedHandle<BtMessageValidator>
      (new RangeBtMessageValidator(&msg, 1024, 256*1024)));
-  std::deque<std::string> errors;
-
-  msg.validate(errors);
+  msg.validate();
 }
 
 void BtRequestMessageTest::testValidate_lengthTooLong() {
@@ -279,13 +279,12 @@ void BtRequestMessageTest::testValidate_lengthTooLong() {
   msg.setBtMessageValidator
     (SharedHandle<BtMessageValidator>
      (new RangeBtMessageValidator(&msg, 1024, 256*1024)));
-  std::deque<std::string> errors;
   try {
-    msg.validate(errors);
+    msg.validate();
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(DlAbortEx& e) {
     CPPUNIT_ASSERT_EQUAL(std::string("Length too long: 16385 > 16KB"),
-			 std::string(e.what()));
+                         std::string(e.what()));
   }
 }
 
