@@ -4,6 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
+#include "TestUtil.h"
 #include "Option.h"
 #include "util.h"
 #include "Exception.h"
@@ -391,9 +392,9 @@ void DefaultBtAnnounceTest::testProcessAnnounceResponse()
     "8:completei100e"
     "10:incompletei200e";
   res += "5:peers6:";
-  res += util::fromHex("c0a800011ae1");
+  res += fromHex("c0a800011ae1");
   res += "6:peers618:";
-  res += util::fromHex("100210354527354678541237324732171ae1");
+  res += fromHex("100210354527354678541237324732171ae1");
   res += "e";
   
   DefaultBtAnnounce an(dctx_, option_);
@@ -403,8 +404,8 @@ void DefaultBtAnnounceTest::testProcessAnnounceResponse()
   CPPUNIT_ASSERT_EQUAL(std::string("foo"), an.getTrackerID());
   CPPUNIT_ASSERT_EQUAL((time_t)3000, an.getInterval());
   CPPUNIT_ASSERT_EQUAL((time_t)1800, an.getMinInterval());
-  CPPUNIT_ASSERT_EQUAL((unsigned int)100, an.getComplete());
-  CPPUNIT_ASSERT_EQUAL((unsigned int)200, an.getIncomplete());
+  CPPUNIT_ASSERT_EQUAL(100, an.getComplete());
+  CPPUNIT_ASSERT_EQUAL(200, an.getIncomplete());
   CPPUNIT_ASSERT_EQUAL((size_t)2, peerStorage_->getPeers().size());
   SharedHandle<Peer> peer = peerStorage_->getPeers()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->getIPAddress());
