@@ -4,6 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
+#include "TestUtil.h"
 #include "Exception.h"
 #include "util.h"
 #include "LpdMessageReceiver.h"
@@ -39,7 +40,7 @@ void LpdMessageReceiverTest::testReceiveMessage()
   sendsock->setMulticastTtl(0);
 
   std::string infoHashString = "cd41c7fdddfd034a15a04d7ff881216e01c4ceaf";
-  std::string infoHash = util::fromHex(infoHashString);
+  std::string infoHash = fromHex(infoHashString);
   std::string request =
     bittorrent::createLpdRequest(LPD_MULTICAST_ADDR, LPD_MULTICAST_PORT,
                                  infoHash,
@@ -52,14 +53,14 @@ void LpdMessageReceiverTest::testReceiveMessage()
   SharedHandle<LpdMessage> msg = rcv.receiveMessage();
   CPPUNIT_ASSERT(msg);
   CPPUNIT_ASSERT_EQUAL(std::string("cd41c7fdddfd034a15a04d7ff881216e01c4ceaf"),
-                       util::toHex(msg->getInfoHash()));
-  CPPUNIT_ASSERT_EQUAL((uint16_t)6000, msg->getPeer()->getPort());
+                       util::toHex(msg->infoHash));
+  CPPUNIT_ASSERT_EQUAL((uint16_t)6000, msg->peer->getPort());
 
   // Bad infohash
   std::string badInfoHashString = "cd41c7fdddfd034a15a04d7ff881216e01c4ce";
   request =
     bittorrent::createLpdRequest(LPD_MULTICAST_ADDR, LPD_MULTICAST_PORT,
-                                 util::fromHex(badInfoHashString),
+                                 fromHex(badInfoHashString),
                                  6000);
   sendsock->writeData(request.c_str(), request.size(),
                      LPD_MULTICAST_ADDR, LPD_MULTICAST_PORT);
@@ -67,8 +68,8 @@ void LpdMessageReceiverTest::testReceiveMessage()
   rcv.getSocket()->isReadable(5);
   msg = rcv.receiveMessage();
   CPPUNIT_ASSERT(msg);
-  CPPUNIT_ASSERT(!msg->getPeer());
-  CPPUNIT_ASSERT(msg->getInfoHash().empty());
+  CPPUNIT_ASSERT(!msg->peer);
+  CPPUNIT_ASSERT(msg->infoHash.empty());
 
   // Bad port
   request =
@@ -81,8 +82,8 @@ void LpdMessageReceiverTest::testReceiveMessage()
   rcv.getSocket()->isReadable(5);
   msg = rcv.receiveMessage();
   CPPUNIT_ASSERT(msg);
-  CPPUNIT_ASSERT(!msg->getPeer());
-  CPPUNIT_ASSERT(msg->getInfoHash().empty());
+  CPPUNIT_ASSERT(!msg->peer);
+  CPPUNIT_ASSERT(msg->infoHash.empty());
 
   // No data available
   msg = rcv.receiveMessage();
