@@ -1,4 +1,4 @@
-#include "MetalinkProcessor.h"
+#include "metalink_helper.h"
 
 #include <iostream>
 
@@ -20,6 +20,7 @@
 #include "Signature.h"
 #include "fmt.h"
 #include "RecoverableException.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -30,7 +31,7 @@ class MetalinkProcessorTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testParseFileV4_attrs);
   CPPUNIT_TEST(testParseFile);
   CPPUNIT_TEST(testParseFile_dirtraversal);
-  CPPUNIT_TEST(testParseFromBinaryStream);
+  CPPUNIT_TEST(testParseBinaryStream);
   CPPUNIT_TEST(testMalformedXML);
   CPPUNIT_TEST(testMalformedXML2);
   CPPUNIT_TEST(testBadSize);
@@ -56,7 +57,7 @@ public:
   void testParseFileV4_attrs();
   void testParseFile();
   void testParseFile_dirtraversal();
-  void testParseFromBinaryStream();
+  void testParseBinaryStream();
   void testMalformedXML();
   void testMalformedXML2();
   void testBadSize();
@@ -81,45 +82,44 @@ CPPUNIT_TEST_SUITE_REGISTRATION( MetalinkProcessorTest );
 
 void MetalinkProcessorTest::testParseFileV4()
 {
-  MetalinkProcessor proc;
-  SharedHandle<Metalinker> m = proc.parseFile(A2_TEST_DIR"/metalink4.xml");
+  SharedHandle<Metalinker> m = metalink::parseFile(A2_TEST_DIR"/metalink4.xml");
   SharedHandle<MetalinkEntry> e;
   SharedHandle<MetalinkResource> r;
   SharedHandle<MetalinkMetaurl> mu;
   CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
   e = m->getEntries()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("example.ext"), e->getPath());
-  CPPUNIT_ASSERT_EQUAL((uint64_t)786430LL, e->getLength());
+  CPPUNIT_ASSERT_EQUAL((off_t)786430LL, e->getLength());
   CPPUNIT_ASSERT_EQUAL(-1, e->maxConnections);
 #ifdef ENABLE_MESSAGE_DIGEST
   CPPUNIT_ASSERT_EQUAL(std::string("0beec7b5ea3f0fdbc95d0dd47f3c5bc275da8a33"),
-		       e->checksum->getDigest());
+		       util::toHex(e->checksum->getDigest()));
   CPPUNIT_ASSERT(e->checksum);
   CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), e->checksum->getHashType());
   CPPUNIT_ASSERT(e->chunkChecksum);
   if(MessageDigest::supports("sha-256")) {
     CPPUNIT_ASSERT_EQUAL(std::string("sha-256"), e->chunkChecksum->getHashType());
-    CPPUNIT_ASSERT_EQUAL((size_t)262144, e->chunkChecksum->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(262144, e->chunkChecksum->getPieceLength());
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->chunkChecksum->countPieceHash());
     CPPUNIT_ASSERT_EQUAL(std::string("0245178074fd042e19b7c3885b360fc21064b30e73f5626c7e3b005d048069c5"),
-                         e->chunkChecksum->getPieceHash(0));
+                         util::toHex(e->chunkChecksum->getPieceHash(0)));
     CPPUNIT_ASSERT_EQUAL(std::string("487ba2299be7f759d7c7bf6a4ac3a32cee81f1bb9332fc485947e32918864fb2"),
-                         e->chunkChecksum->getPieceHash(1));
+                         util::toHex(e->chunkChecksum->getPieceHash(1)));
     CPPUNIT_ASSERT_EQUAL(std::string("37290d74ac4d186e3a8e5785d259d2ec04fac91ae28092e7620ec8bc99e830aa"),
-                         e->chunkChecksum->getPieceHash(2));
+                         util::toHex(e->chunkChecksum->getPieceHash(2)));
   } else {
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), e->chunkChecksum->getHashType());
-    CPPUNIT_ASSERT_EQUAL((size_t)262144, e->chunkChecksum->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(262144, e->chunkChecksum->getPieceLength());
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->chunkChecksum->countPieceHash());
     CPPUNIT_ASSERT_EQUAL
       (std::string("5bd9f7248df0f3a6a86ab6c95f48787d546efa14"),
-       e->chunkChecksum->getPieceHash(0));
+       util::toHex(e->chunkChecksum->getPieceHash(0)));
     CPPUNIT_ASSERT_EQUAL
       (std::string("9413ee70957a09d55704123687478e07f18c7b29"),
-       e->chunkChecksum->getPieceHash(1));
+       util::toHex(e->chunkChecksum->getPieceHash(1)));
     CPPUNIT_ASSERT_EQUAL
       (std::string("44213f9f4d59b557314fadcd233232eebcac8012"),
-       e->chunkChecksum->getPieceHash(2));
+       util::toHex(e->chunkChecksum->getPieceHash(2)));
   }
 #endif // ENABLE_MESSAGE_DIGEST
   CPPUNIT_ASSERT(e->getSignature());
@@ -151,9 +151,8 @@ void MetalinkProcessorTest::testParseFileV4()
 
 void MetalinkProcessorTest::testParseFileV4_attrs()
 {
-  MetalinkProcessor proc;
   SharedHandle<Metalinker> m;  
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
+  ByteArrayDiskWriter dw;
   {
     // Testing file@name
     const char* tmpl = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
@@ -162,27 +161,27 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "<url>http://example.org</url>"
       "</file>"
       "</metalink>";
-    dw->setString(fmt(tmpl, "foo"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "foo"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // empty name
-    dw->setString(fmt(tmpl, ""));
+    dw.setString(fmt(tmpl, ""));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
 
     // dir traversing
-    dw->setString(fmt(tmpl, "../doughnuts"));
-    try {
-      m = proc.parseFromBinaryStream(dw);
-      CPPUNIT_FAIL("exception must be thrown.");
-    } catch(RecoverableException& e) {
-      // success
-    }
+    dw.setString(fmt(tmpl, "../doughnuts"));
+     try {
+       m = metalink::parseBinaryStream(&dw);
+       CPPUNIT_FAIL("exception must be thrown.");
+     } catch(RecoverableException& e) {
+       // success
+     }
   }
   {
     // Testing url@priority
@@ -192,36 +191,36 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "<url priority=\"%s\">http://example.org</url>"
       "</file>"
       "</metalink>";
-    dw->setString(fmt(tmpl, "0"));
+    dw.setString(fmt(tmpl, "0"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
 
-    dw->setString(fmt(tmpl, "1"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "1"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(fmt(tmpl, "100"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "100"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(fmt(tmpl, "999999"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "999999"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(fmt(tmpl, "1000000"));
+    dw.setString(fmt(tmpl, "1000000"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
-    dw->setString(fmt(tmpl, "A"));
+    dw.setString(fmt(tmpl, "A"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
   }
@@ -234,36 +233,36 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "<metaurl priority=\"%s\" mediatype=\"torrent\">http://example.org</metaurl>"
       "</file>"
       "</metalink>";
-    dw->setString(fmt(tmpl, "0"));
+    dw.setString(fmt(tmpl, "0"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
 
-    dw->setString(fmt(tmpl, "1"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "1"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(fmt(tmpl, "100"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "100"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(fmt(tmpl, "999999"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "999999"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(fmt(tmpl, "1000000"));
+    dw.setString(fmt(tmpl, "1000000"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
-    dw->setString(fmt(tmpl, "A"));
+    dw.setString(fmt(tmpl, "A"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
   }
@@ -271,14 +270,14 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
     // Testing metaurl@mediatype
 
     // no mediatype
-    dw->setString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
+    dw.setString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                   "<metalink xmlns=\"urn:ietf:params:xml:ns:metalink\">"
                   "<file name=\"example.ext\">"
                   "<metaurl>http://example.org</metaurl>"
                   "</file>"
                   "</metalink>");
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
@@ -292,14 +291,14 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(fmt(tmpl, "torrent"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "torrent"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // empty mediatype
-    dw->setString(fmt(tmpl, ""));
+    dw.setString(fmt(tmpl, ""));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
@@ -315,22 +314,22 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(fmt(tmpl, "foo"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "foo"));
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // dir traversing
-    dw->setString(fmt(tmpl, "../doughnuts"));
+    dw.setString(fmt(tmpl, "../doughnuts"));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
     // empty name
-    dw->setString(fmt(tmpl, ""));
+    dw.setString(fmt(tmpl, ""));
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
@@ -340,7 +339,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
   {
     // Testing pieces@length
     // No pieces@length
-    dw->setString
+    dw.setString
       ("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
        "<metalink xmlns=\"urn:ietf:params:xml:ns:metalink\">"
        "<file name=\"example.ext\">"
@@ -351,7 +350,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
        "</file>"
        "</metalink>");
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
 
@@ -366,25 +365,25 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(fmt(tmpl, "262144"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "262144"));
+    m = metalink::parseBinaryStream(&dw);
     // empty
     try {
-      dw->setString(fmt(tmpl, ""));
-      m = proc.parseFromBinaryStream(dw);
+      dw.setString(fmt(tmpl, ""));
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
     // not a number
     try {
-      dw->setString(fmt(tmpl, "A"));
-      m = proc.parseFromBinaryStream(dw);
+      dw.setString(fmt(tmpl, "A"));
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
   }
   {
     // Testing pieces@type
     // No pieces@type
-    dw->setString
+    dw.setString
       ("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
        "<metalink xmlns=\"urn:ietf:params:xml:ns:metalink\">"
        "<file name=\"example.ext\">"
@@ -395,7 +394,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
        "</file>"
        "</metalink>");
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
 
@@ -410,19 +409,19 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(fmt(tmpl, "sha-1"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "sha-1"));
+    m = metalink::parseBinaryStream(&dw);
     // empty
     try {
-      dw->setString(fmt(tmpl, ""));
-      m = proc.parseFromBinaryStream(dw);
+      dw.setString(fmt(tmpl, ""));
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
   }
   {
     // Testing hash@type
     // No hash@type
-    dw->setString
+    dw.setString
       ("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
        "<metalink xmlns=\"urn:ietf:params:xml:ns:metalink\">"
        "<file name=\"example.ext\">"
@@ -431,7 +430,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
        "</file>"
        "</metalink>");
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
 
@@ -444,12 +443,12 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(fmt(tmpl, "sha-1"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "sha-1"));
+    m = metalink::parseBinaryStream(&dw);
     // empty
     try {
-      dw->setString(fmt(tmpl, ""));
-      m = proc.parseFromBinaryStream(dw);
+      dw.setString(fmt(tmpl, ""));
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
   }
@@ -457,7 +456,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
   {
     // Testing signature@mediatype
     // No hash@type
-    dw->setString
+    dw.setString
       ("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
        "<metalink xmlns=\"urn:ietf:params:xml:ns:metalink\">"
        "<file name=\"example.ext\">"
@@ -466,7 +465,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
        "</file>"
        "</metalink>");
     try {
-      m = proc.parseFromBinaryStream(dw);
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
 
@@ -479,12 +478,12 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(fmt(tmpl, "application/pgp-signature"));
-    m = proc.parseFromBinaryStream(dw);
+    dw.setString(fmt(tmpl, "application/pgp-signature"));
+    m = metalink::parseBinaryStream(&dw);
     // empty
     try {
-      dw->setString(fmt(tmpl, ""));
-      m = proc.parseFromBinaryStream(dw);
+      dw.setString(fmt(tmpl, ""));
+      m = metalink::parseBinaryStream(&dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
   }
@@ -492,39 +491,40 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
 
 void MetalinkProcessorTest::testParseFile()
 {
-  MetalinkProcessor proc;
   try {
-    SharedHandle<Metalinker> metalinker = proc.parseFile(A2_TEST_DIR"/test.xml");
+    SharedHandle<Metalinker> metalinker =
+      metalink::parseFile(A2_TEST_DIR"/test.xml");
 
     std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
       metalinker->getEntries().begin();
 
     SharedHandle<MetalinkEntry> entry1 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), entry1->getPath());
-    CPPUNIT_ASSERT_EQUAL((uint64_t)0ULL, entry1->getLength());
+    CPPUNIT_ASSERT_EQUAL((off_t)0LL, entry1->getLength());
     CPPUNIT_ASSERT_EQUAL(std::string("0.5.2"), entry1->version);
     CPPUNIT_ASSERT_EQUAL(std::string("en-US"), entry1->languages[0]);
     CPPUNIT_ASSERT_EQUAL(std::string("Linux-x86"), entry1->oses[0]);
     CPPUNIT_ASSERT_EQUAL(1, entry1->maxConnections);
 #ifdef ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT_EQUAL(std::string("a96cf3f0266b91d87d5124cf94326422800b627d"),
-                         entry1->checksum->getDigest());
+                         util::toHex(entry1->checksum->getDigest()));
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), entry1->checksum->getHashType());
 #endif // ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT(entry1->getSignature());
     CPPUNIT_ASSERT_EQUAL(std::string("pgp"), entry1->getSignature()->getType());
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2.sig"),
                          entry1->getSignature()->getFile());
-    // Note that last '\n' character is trimmed.
+    // Note that we don't strip anything
     CPPUNIT_ASSERT_EQUAL
       (std::string
-       ("-----BEGIN PGP SIGNATURE-----\n"
+       ("\n-----BEGIN PGP SIGNATURE-----\n"
         "Version: GnuPG v1.4.9 (GNU/Linux)\n"
         "\n"
         "ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff\n"
         "ffffffffffffffffffffffff\n"
         "fffff\n"
-        "-----END PGP SIGNATURE-----"),
+        "-----END PGP SIGNATURE-----\n"
+        "\t"),
        entry1->getSignature()->getBody());
 
     std::vector<SharedHandle<MetalinkResource> >::iterator resourceItr1 =
@@ -550,20 +550,20 @@ void MetalinkProcessorTest::testParseFile()
 
     SharedHandle<MetalinkEntry> entry2 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.1.tar.bz2"), entry2->getPath());
-    CPPUNIT_ASSERT_EQUAL((uint64_t)345689ULL, entry2->getLength());
+    CPPUNIT_ASSERT_EQUAL((off_t)345689LL, entry2->getLength());
     CPPUNIT_ASSERT_EQUAL(std::string("0.5.1"), entry2->version);
     CPPUNIT_ASSERT_EQUAL(std::string("ja-JP"), entry2->languages[0]);
     CPPUNIT_ASSERT_EQUAL(std::string("Linux-m68k"), entry2->oses[0]);
     CPPUNIT_ASSERT_EQUAL(-1, entry2->maxConnections);
 #ifdef ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT_EQUAL(std::string("4c255b0ed130f5ea880f0aa061c3da0487e251cc"),
-                         entry2->checksum->getDigest());
+                         util::toHex(entry2->checksum->getDigest()));
     CPPUNIT_ASSERT_EQUAL((size_t)2, entry2->chunkChecksum->countPieceHash());
-    CPPUNIT_ASSERT_EQUAL((size_t)262144, entry2->chunkChecksum->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(262144, entry2->chunkChecksum->getPieceLength());
     CPPUNIT_ASSERT_EQUAL(std::string("179463a88d79cbf0b1923991708aead914f26142"),
-                         entry2->chunkChecksum->getPieceHash(0));
+                         util::toHex(entry2->chunkChecksum->getPieceHash(0)));
     CPPUNIT_ASSERT_EQUAL(std::string("fecf8bc9a1647505fe16746f94e97a477597dbf3"),
-                         entry2->chunkChecksum->getPieceHash(1));
+                         util::toHex(entry2->chunkChecksum->getPieceHash(1)));
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), entry2->checksum->getHashType());
 #endif // ENABLE_MESSAGE_DIGEST
     // See that signature is null
@@ -587,7 +587,7 @@ void MetalinkProcessorTest::testParseFile()
 #ifdef ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), entry4->checksum->getHashType());
     CPPUNIT_ASSERT_EQUAL(std::string("4c255b0ed130f5ea880f0aa061c3da0487e251cc"),
-                         entry4->checksum->getDigest());
+                         util::toHex(entry4->checksum->getDigest()));
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"),entry4->chunkChecksum->getHashType());
 #endif // ENABLE_MESSAGE_DIGEST
 
@@ -599,9 +599,8 @@ void MetalinkProcessorTest::testParseFile()
 
 void MetalinkProcessorTest::testParseFile_dirtraversal()
 {
-  MetalinkProcessor proc;
   SharedHandle<Metalinker> metalinker =
-    proc.parseFile(A2_TEST_DIR"/metalink3-dirtraversal.xml");
+    metalink::parseFile(A2_TEST_DIR"/metalink3-dirtraversal.xml");
   CPPUNIT_ASSERT_EQUAL((size_t)1, metalinker->getEntries().size());
   SharedHandle<MetalinkEntry> e = metalinker->getEntries()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.3.tar.bz2"), e->getPath());
@@ -609,15 +608,14 @@ void MetalinkProcessorTest::testParseFile_dirtraversal()
   CPPUNIT_ASSERT_EQUAL(std::string(""), e->getSignature()->getFile());
 }
 
-void MetalinkProcessorTest::testParseFromBinaryStream()
+void MetalinkProcessorTest::testParseBinaryStream()
 {
-  MetalinkProcessor proc;
-  DefaultDiskWriterHandle dw(new DefaultDiskWriter(A2_TEST_DIR"/test.xml"));
-  dw->enableReadOnly();
-  dw->openExistingFile();
+  DefaultDiskWriter dw(A2_TEST_DIR"/test.xml");
+  dw.enableReadOnly();
+  dw.openExistingFile();
   
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
 
     std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
       m->getEntries().begin();
@@ -630,12 +628,11 @@ void MetalinkProcessorTest::testParseFromBinaryStream()
 
 void MetalinkProcessorTest::testMalformedXML()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\"><files></file></metalink>");
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\"><files></file></metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
     std::cerr << e.stackTrace() << std::endl;
@@ -644,12 +641,11 @@ void MetalinkProcessorTest::testMalformedXML()
 
 void MetalinkProcessorTest::testMalformedXML2()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\"><files></files>");
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\"><files></files>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
     std::cerr << e.stackTrace() << std::endl;
@@ -658,9 +654,8 @@ void MetalinkProcessorTest::testMalformedXML2()
 
 void MetalinkProcessorTest::testBadSizeV4()
 {
-  MetalinkProcessor proc;
   SharedHandle<Metalinker> m;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
+  ByteArrayDiskWriter dw;
 
   const char* tmpl =
     "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
@@ -671,21 +666,20 @@ void MetalinkProcessorTest::testBadSizeV4()
      "</file>"
     "</metalink>";
 
-  dw->setString(fmt(tmpl, "9223372036854775807"));
-  m = proc.parseFromBinaryStream(dw);
+  dw.setString(fmt(tmpl, "9223372036854775807"));
+  m = metalink::parseBinaryStream(&dw);
 
-  dw->setString(fmt(tmpl, "-1"));
+  dw.setString(fmt(tmpl, "-1"));
   try {
-    m = proc.parseFromBinaryStream(dw);
+    m = metalink::parseBinaryStream(&dw);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(RecoverableException& e) {}
 }
   
 void MetalinkProcessorTest::testBadSize()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file name=\"aria2-0.5.2.tar.bz2\">"
                 "  <size>abc</size>"
@@ -697,13 +691,13 @@ void MetalinkProcessorTest::testBadSize()
                 "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
 
     std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
       m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), e->getPath());
-    CPPUNIT_ASSERT_EQUAL((uint64_t)0ULL, e->getLength());
+    CPPUNIT_ASSERT_EQUAL((off_t)0LL, e->getLength());
     CPPUNIT_ASSERT_EQUAL(std::string("0.5.2"), e->version);
     CPPUNIT_ASSERT_EQUAL(std::string("en-US"), e->languages[0]);
     CPPUNIT_ASSERT_EQUAL(std::string("Linux-x86"), e->oses[0]);
@@ -715,9 +709,8 @@ void MetalinkProcessorTest::testBadSize()
 
 void MetalinkProcessorTest::testBadMaxConn()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file name=\"aria2-0.5.2.tar.bz2\">"
                 "  <size>43743838</size>"
@@ -730,12 +723,12 @@ void MetalinkProcessorTest::testBadMaxConn()
                 "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
 
     std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
       m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
-    CPPUNIT_ASSERT_EQUAL((uint64_t)43743838ULL, e->getLength());
+    CPPUNIT_ASSERT_EQUAL((off_t)43743838LL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -743,9 +736,8 @@ void MetalinkProcessorTest::testBadMaxConn()
 
 void MetalinkProcessorTest::testNoName()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file>"
                 "  <size>1024</size>"
@@ -763,7 +755,7 @@ void MetalinkProcessorTest::testNoName()
                 "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
     std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
       m->getEntries().begin();
@@ -776,9 +768,8 @@ void MetalinkProcessorTest::testNoName()
 
 void MetalinkProcessorTest::testBadURLPrefs()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file name=\"aria2-0.5.2.tar.bz2\">"
                 "  <size>43743838</size>"
@@ -794,7 +785,7 @@ void MetalinkProcessorTest::testBadURLPrefs()
                 "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<MetalinkResource> r = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r->type);
@@ -808,9 +799,8 @@ void MetalinkProcessorTest::testBadURLPrefs()
 
 void MetalinkProcessorTest::testBadURLMaxConn()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file name=\"aria2-0.5.2.tar.bz2\">"
                 "  <size>43743838</size>"
@@ -827,7 +817,7 @@ void MetalinkProcessorTest::testBadURLMaxConn()
                 "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<MetalinkResource> r = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r->type);
@@ -842,9 +832,8 @@ void MetalinkProcessorTest::testBadURLMaxConn()
 #ifdef ENABLE_MESSAGE_DIGEST
 void MetalinkProcessorTest::testUnsupportedType()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file name=\"aria2-0.5.2.tar.bz2\">"
                 "  <size>43743838</size>"
@@ -861,7 +850,7 @@ void MetalinkProcessorTest::testUnsupportedType()
                 "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->resources.size());
     SharedHandle<MetalinkResource> r1 = e->resources[0];
@@ -877,9 +866,8 @@ void MetalinkProcessorTest::testUnsupportedType()
 
 void MetalinkProcessorTest::testMultiplePieces()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
                 "<files>"
                 "<file name=\"aria2.tar.bz2\">"
                 "  <verification>"
@@ -894,12 +882,12 @@ void MetalinkProcessorTest::testMultiplePieces()
 
   try {
     // aria2 prefers sha1
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
  
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getHashType());
-    CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(1024, c->getPieceLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -907,9 +895,8 @@ void MetalinkProcessorTest::testMultiplePieces()
 
 void MetalinkProcessorTest::testBadPieceNo()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString
+  ByteArrayDiskWriter dw;
+  dw.setString
     ("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
      "<files>"
      "<file name=\"aria2.tar.bz2\">"
@@ -927,12 +914,12 @@ void MetalinkProcessorTest::testBadPieceNo()
      "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
 
     CPPUNIT_ASSERT(c);
-    CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(1024, c->getPieceLength());
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getHashType());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -941,9 +928,8 @@ void MetalinkProcessorTest::testBadPieceNo()
 
 void MetalinkProcessorTest::testBadPieceLength()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString
+  ByteArrayDiskWriter dw;
+  dw.setString
     ("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
      "<files>"
      "<file name=\"aria2.tar.bz2\">"
@@ -960,12 +946,12 @@ void MetalinkProcessorTest::testBadPieceLength()
      "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
     CPPUNIT_ASSERT(c);
-    CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(1024, c->getPieceLength());
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getHashType());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -974,9 +960,8 @@ void MetalinkProcessorTest::testBadPieceLength()
 
 void MetalinkProcessorTest::testUnsupportedType_piece()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString
+  ByteArrayDiskWriter dw;
+  dw.setString
     ("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
      "<files>"
      "<file name=\"aria2.tar.bz2\">"
@@ -993,12 +978,12 @@ void MetalinkProcessorTest::testUnsupportedType_piece()
      "</metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
  
     CPPUNIT_ASSERT(c);
-    CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getPieceLength());
+    CPPUNIT_ASSERT_EQUAL(1024, c->getPieceLength());
     CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getHashType());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -1008,23 +993,22 @@ void MetalinkProcessorTest::testUnsupportedType_piece()
 
 void MetalinkProcessorTest::testLargeFileSize()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
-                "<files>"
-                "<file name=\"dvd.iso\">"
-                "  <size>9223372036854775807</size>"
-                "  <resources>"
-                "    <url type=\"http\">ftp://mirror/</url>"
-                "  </resources>"                
-                "</file>"
-                "</files>"
-                "</metalink>");
-
+  ByteArrayDiskWriter dw;
+  dw.setString
+    ("<metalink version=\"3.0\" xmlns=\"http://www.metalinker.org/\">"
+     "<files>"
+     "<file name=\"dvd.iso\">"
+     "  <size>9223372036854775807</size>"
+     "  <resources>"
+     "    <url type=\"http\">ftp://mirror/</url>"
+     "  </resources>"
+     "</file>"
+     "</files>"
+     "</metalink>");
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
-    CPPUNIT_ASSERT_EQUAL((uint64_t)9223372036854775807ULL, e->getLength());
+    CPPUNIT_ASSERT_EQUAL((off_t)9223372036854775807LL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -1032,9 +1016,8 @@ void MetalinkProcessorTest::testLargeFileSize()
 
 void MetalinkProcessorTest::testXmlPrefixV3()
 {
-  MetalinkProcessor proc;
-  SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
-  dw->setString("<m:metalink version=\"3.0\" xmlns:m=\"http://www.metalinker.org/\">"
+  ByteArrayDiskWriter dw;
+  dw.setString("<m:metalink version=\"3.0\" xmlns:m=\"http://www.metalinker.org/\">"
                 "<m:files>"
                 "<m:file name=\"dvd.iso\">"
                 "  <m:size>9223372036854775807</m:size>"
@@ -1046,10 +1029,10 @@ void MetalinkProcessorTest::testXmlPrefixV3()
                 "</m:metalink>");
 
   try {
-    SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
+    SharedHandle<Metalinker> m = metalink::parseBinaryStream(&dw);
     CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
     SharedHandle<MetalinkEntry> e = m->getEntries()[0];
-    CPPUNIT_ASSERT_EQUAL((uint64_t)9223372036854775807ULL, e->getLength());
+    CPPUNIT_ASSERT_EQUAL((off_t)9223372036854775807LL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
