@@ -1,5 +1,5 @@
-#ifndef _D_MOCK_BT_PROGRESS_INFO_FILE_H_
-#define _D_MOCK_BT_PROGRESS_INFO_FILE_H_
+#ifndef D_MOCK_BT_PROGRESS_INFO_FILE_H
+#define D_MOCK_BT_PROGRESS_INFO_FILE_H
 
 #include "BtProgressInfoFile.h"
 
@@ -35,4 +35,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_MOCK_BT_PROGRESS_INFO_FILE_H_
+#endif // D_MOCK_BT_PROGRESS_INFO_FILE_H
