@@ -1,13 +1,14 @@
 #include "ServerStatMan.h"
 
 #include <iostream>
-#include <sstream>
 
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "ServerStat.h"
 #include "Exception.h"
 #include "util.h"
+#include "BufferedFile.h"
+#include "TestUtil.h"
 
 namespace aria2 {
 
@@ -47,13 +48,13 @@ void ServerStatManTest::testAddAndFind()
 
   {
     SharedHandle<ServerStat> r = ssm.find("localhost", "http");
-    CPPUNIT_ASSERT(!r.isNull());
+    CPPUNIT_ASSERT(r);
     CPPUNIT_ASSERT_EQUAL(std::string("localhost"), r->getHostname());
     CPPUNIT_ASSERT_EQUAL(std::string("http"), r->getProtocol());
   }
   {
     SharedHandle<ServerStat> r = ssm.find("mirror", "ftp");
-    CPPUNIT_ASSERT(r.isNull());
+    CPPUNIT_ASSERT(!r);
   }
 }
 
@@ -70,7 +71,7 @@ void ServerStatManTest::testSave()
   localhost_ftp->setLastUpdated(Time(1210000001));
   SharedHandle<ServerStat> mirror(new ServerStat("mirror", "http"));
   mirror->setDownloadSpeed(0);
-  mirror->setStatus(ServerStat::ERROR);
+  mirror->setStatus(ServerStat::A2_ERROR);
   mirror->setLastUpdated(Time(1210000002));
 
   ServerStatMan ssm;
@@ -78,9 +79,8 @@ void ServerStatManTest::testSave()
   CPPUNIT_ASSERT(ssm.add(localhost_ftp));
   CPPUNIT_ASSERT(ssm.add(mirror));
 
-  std::stringstream ss;
-  CPPUNIT_ASSERT(ssm.save(ss));
-  std::string out = ss.str();
+  std::string filename = A2_TEST_OUT_DIR"/aria2_ServerStatManTest_testSave";
+  CPPUNIT_ASSERT(ssm.save(filename));
   CPPUNIT_ASSERT_EQUAL
     (std::string
      ("host=localhost, protocol=ftp,"
@@ -106,40 +106,38 @@ void ServerStatManTest::testSave()
       " last_updated=1210000002,"
       " counter=0,"
       " status=ERROR\n"),
-     out);                         
+     readFile(filename));
 }
 
 void ServerStatManTest::testLoad()
 {
+  std::string filename = A2_TEST_OUT_DIR"/aria2_ServerStatManTest_testLoad";
   std::string in =
     "host=localhost, protocol=ftp, dl_speed=30000, last_updated=1210000001, status=OK\n"
     "host=localhost, protocol=http, dl_speed=25000, sc_avg_speed=101, mc_avg_speed=102, last_updated=1210000000, counter=6, status=OK\n"
     "host=mirror, protocol=http, dl_speed=0, last_updated=1210000002, status=ERROR\n";
-
-  std::stringstream ss(in);
+  BufferedFile fp(filename, BufferedFile::WRITE);
+  CPPUNIT_ASSERT_EQUAL((size_t)in.size(), fp.write(in.data(), in.size()));
+  CPPUNIT_ASSERT(fp.close() != EOF);
 
   ServerStatMan ssm;
-  CPPUNIT_ASSERT(ssm.load(ss));
+  CPPUNIT_ASSERT(ssm.load(filename));
 
   SharedHandle<ServerStat> localhost_http = ssm.find("localhost", "http");
-  CPPUNIT_ASSERT(!localhost_http.isNull());
+  CPPUNIT_ASSERT(localhost_http);
   CPPUNIT_ASSERT_EQUAL(std::string("localhost"), localhost_http->getHostname());
   CPPUNIT_ASSERT_EQUAL(std::string("http"), localhost_http->getProtocol());
-  CPPUNIT_ASSERT_EQUAL(static_cast<unsigned int>(25000),
-                       localhost_http->getDownloadSpeed());
-  CPPUNIT_ASSERT_EQUAL(static_cast<unsigned int>(101),
-                       localhost_http->getSingleConnectionAvgSpeed());
-  CPPUNIT_ASSERT_EQUAL(static_cast<unsigned int>(102),
-                       localhost_http->getMultiConnectionAvgSpeed());
-  CPPUNIT_ASSERT_EQUAL(static_cast<unsigned int>(6),
-                       localhost_http->getCounter());
+  CPPUNIT_ASSERT_EQUAL(25000, localhost_http->getDownloadSpeed());
+  CPPUNIT_ASSERT_EQUAL(101, localhost_http->getSingleConnectionAvgSpeed());
+  CPPUNIT_ASSERT_EQUAL(102, localhost_http->getMultiConnectionAvgSpeed());
+  CPPUNIT_ASSERT_EQUAL(6, localhost_http->getCounter());
   CPPUNIT_ASSERT_EQUAL(static_cast<time_t>(1210000000),
                        localhost_http->getLastUpdated().getTime());
   CPPUNIT_ASSERT_EQUAL(ServerStat::OK, localhost_http->getStatus());
 
   SharedHandle<ServerStat> mirror = ssm.find("mirror", "http");
-  CPPUNIT_ASSERT(!mirror.isNull());
-  CPPUNIT_ASSERT_EQUAL(ServerStat::ERROR, mirror->getStatus());
+  CPPUNIT_ASSERT(mirror);
+  CPPUNIT_ASSERT_EQUAL(ServerStat::A2_ERROR, mirror->getStatus());
 }
 
 void ServerStatManTest::testRemoveStaleServerStat()
@@ -153,7 +151,7 @@ void ServerStatManTest::testRemoveStaleServerStat()
   localhost_ftp->setLastUpdated(Time(1210000001));
   SharedHandle<ServerStat> mirror(new ServerStat("mirror", "http"));
   mirror->setDownloadSpeed(0);
-  mirror->setStatus(ServerStat::ERROR);
+  mirror->setStatus(ServerStat::A2_ERROR);
   mirror->setLastUpdated(Time(1210000002));
 
   ServerStatMan ssm;
@@ -163,9 +161,9 @@ void ServerStatManTest::testRemoveStaleServerStat()
 
   ssm.removeStaleServerStat(24*60*60);
 
-  CPPUNIT_ASSERT(!ssm.find("localhost", "http").isNull());
-  CPPUNIT_ASSERT(ssm.find("localhost", "ftp").isNull());
-  CPPUNIT_ASSERT(ssm.find("mirror", "http").isNull());
+  CPPUNIT_ASSERT(ssm.find("localhost", "http"));
+  CPPUNIT_ASSERT(!ssm.find("localhost", "ftp"));
+  CPPUNIT_ASSERT(!ssm.find("mirror", "http"));
 }
 
 } // namespace aria2
