@@ -14,8 +14,9 @@
 #include "Cookie.h"
 #include "DefaultDiskWriter.h"
 #include "fmt.h"
+#include "util.h"
 #ifdef ENABLE_MESSAGE_DIGEST
-# include "MessageDigestHelper.h"
+# include "message_digest_helper.h"
 #endif // ENABLE_MESSAGE_DIGEST
 
 namespace aria2 {
@@ -75,13 +76,18 @@ Cookie createCookie
     (name, value, expiryTime, true, domain, hostOnly, path, secure, false, 0);
 }
 
+std::string fromHex(const std::string& s)
+{
+  return util::fromHex(s.begin(), s.end());
+}
+
 #ifdef ENABLE_MESSAGE_DIGEST
 std::string fileHexDigest
 (const SharedHandle<MessageDigest>& ctx, const std::string& filename)
 {
   SharedHandle<DiskWriter> writer(new DefaultDiskWriter(filename));
   writer->openExistingFile();
-  return MessageDigestHelper::hexDigest(ctx, writer, 0, writer->size());
+  return util::toHex(message_digest::digest(ctx, writer, 0, writer->size()));
 }
 #endif // ENABLE_MESSAGE_DIGEST
 
