@@ -4,6 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
+#include "TestUtil.h"
 #include "Peer.h"
 #include "a2netcompat.h"
 #include "util.h"
@@ -35,7 +36,7 @@ public:
   void setUp()
   {
     peerStorage_.reset(new MockPeerStorage());
-    global::wallclock.reset();
+    global::wallclock().reset();
   }
 
   void testGetExtensionMessageID();
@@ -103,9 +104,9 @@ void UTPexExtensionMessageTest::testGetBencodedData()
 
   std::string expected = "d5:added12:"+
     std::string(&c1[0], &c1[6])+std::string(&c2[0], &c2[6])+
-    "7:added.f2:"+util::fromHex("0200")+
+    "7:added.f2:"+fromHex("0200")+
     "6:added618:"+std::string(&c5[0], &c5[COMPACT_LEN_IPV6])+
-    "8:added6.f1:"+util::fromHex("00")+
+    "8:added6.f1:"+fromHex("00")+
     "7:dropped12:"+std::string(&c3[0], &c3[6])+std::string(&c4[0], &c4[6])+
     "8:dropped618:"+std::string(&c6[0], &c6[COMPACT_LEN_IPV6])+
     "e";
@@ -194,9 +195,9 @@ void UTPexExtensionMessageTest::testCreate()
 
   std::string data = std::string(&id[0], &id[1])+"d5:added12:"+
     std::string(&c1[0], &c1[6])+std::string(&c2[0], &c2[6])+
-    "7:added.f2:"+util::fromHex("0200")+
+    "7:added.f2:"+fromHex("0200")+
     "6:added618:"+std::string(&c5[0], &c5[COMPACT_LEN_IPV6])+
-    "8:added6.f1:"+util::fromHex("00")+
+    "8:added6.f1:"+fromHex("00")+
     "7:dropped12:"+std::string(&c3[0], &c3[6])+std::string(&c4[0], &c4[6])+
     "8:dropped618:"+std::string(&c6[0], &c6[COMPACT_LEN_IPV6])+
     "e";
@@ -205,7 +206,6 @@ void UTPexExtensionMessageTest::testCreate()
     UTPexExtensionMessage::create
     (reinterpret_cast<const unsigned char*>(data.c_str()), data.size());
   CPPUNIT_ASSERT_EQUAL((uint8_t)1, msg->getExtensionMessageID());
-#ifdef HAVE_INET_NTOP
   CPPUNIT_ASSERT_EQUAL((size_t)3, msg->getFreshPeers().size());
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"),
                        msg->getFreshPeers()[0]->getIPAddress());
@@ -229,24 +229,6 @@ void UTPexExtensionMessageTest::testCreate()
                        msg->getDroppedPeers()[2]->getIPAddress());
   CPPUNIT_ASSERT_EQUAL((uint16_t)6998,
                        msg->getDroppedPeers()[2]->getPort());
-#else // !HAVE_INET_NTOP
-  CPPUNIT_ASSERT_EQUAL((size_t)2, msg->getFreshPeers().size());
-  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"),
-                       msg->getFreshPeers()[0]->getIPAddress());
-  CPPUNIT_ASSERT_EQUAL((uint16_t)6881, msg->getFreshPeers()[0]->getPort());
-  CPPUNIT_ASSERT_EQUAL(std::string("10.1.1.2"),
-                       msg->getFreshPeers()[1]->getIPAddress());
-  CPPUNIT_ASSERT_EQUAL((uint16_t)9999, msg->getFreshPeers()[1]->getPort());
-
-  CPPUNIT_ASSERT_EQUAL((size_t)2, msg->getDroppedPeers().size());
-  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"),
-                       msg->getDroppedPeers()[0]->getIPAddress());
-  CPPUNIT_ASSERT_EQUAL((uint16_t)6882, msg->getDroppedPeers()[0]->getPort());
-  CPPUNIT_ASSERT_EQUAL(std::string("10.1.1.3"),
-                       msg->getDroppedPeers()[1]->getIPAddress());
-  CPPUNIT_ASSERT_EQUAL((uint16_t)10000,
-                       msg->getDroppedPeers()[1]->getPort());
-#endif // !HAVE_INET_NTOP
   try {
     // 0 length data
     std::string in = "";
